local HBDP = LibStub("HereBeDragons-Pins-2.0")
local AceLocale = LibStub("AceLocale-3.0")
local L = AceLocale:GetLocale("Spy")
local _

function Spy:RefreshCurrentList(player, source)
	local MainWindow = Spy.MainWindow
	if not MainWindow:IsShown() then
		return
	end

	local mode = Spy.db.profile.CurrentList
	local manageFunction = Spy.ListTypes[mode][2]
	if manageFunction then
		manageFunction()
	end

	local button = 1
	for index, data in pairs(Spy.CurrentList) do
		if button <= Spy.ButtonLimit then
			local description = ""
			local level = "??"
			local class = "UNKNOWN"
			local guild = "??"
			local opacity = 1

			local playerData = SpyPerCharDB.PlayerData[data.player]
			if playerData then
				if playerData.level then
					level = playerData.level
					if playerData.isGuess == true and tonumber(playerData.level) < Spy.MaximumPlayerLevel then
						level = level.."+"
					end
				end
				if playerData.class then
					class = playerData.class
				end
				if playerData.guild then
					guild = playerData.guild
				end
			end
			
			if Spy.db.profile.DisplayListData == "NameLevelClass" then
				description = level.." "
				if L[class] and type(L[class]) == "string" then
					description = description..L[class]
				end
			elseif Spy.db.profile.DisplayListData == "NameLevelGuild" then
				description = level.." "..guild
			elseif Spy.db.profile.DisplayListData == "NameLevelOnly" then
				description = level.." "
			elseif Spy.db.profile.DisplayListData == "NameGuild" then
				description = guild
			end
			
			if mode == 1 and Spy.InactiveList[data.player] then
				opacity = 0.5
			end
			if player == data.player then
				if not source or source ~= Spy.CharacterName then
					Spy:AlertPlayer(player, source)
					if not source then
						Spy:AnnouncePlayer(player)
					end
				end
			end

			Spy:SetBar(button, data.player, description, 100, "Class", class, nil, opacity)
			Spy.ButtonName[button] = data.player
			button = button + 1
		end
	end
	Spy.ListAmountDisplayed = button - 1

	if Spy.db.profile.ResizeSpy then
		Spy:AutomaticallyResize()
	else
		if not Spy.db.profile.InvertSpy then
			if not InCombatLockdown() and Spy.MainWindow:GetHeight()< 34 then
				Spy:RestoreMainWindowPosition(Spy.MainWindow:GetLeft(), Spy.MainWindow:GetTop(), Spy.MainWindow:GetWidth(), 34)
			end
		else
			if not InCombatLockdown() and Spy.MainWindow:GetHeight()< 34 then 
				Spy:RestoreMainWindowPosition(Spy.MainWindow:GetLeft(), Spy.MainWindow:GetBottom(), Spy.MainWindow:GetWidth(), 34)
			end
		end	
	end
	Spy:ManageBarsDisplayed()
end

function Spy:ManageNearbyList()
	local prioritiseKoS = Spy.db.profile.PrioritiseKoS

	local activeKoS = {}
	local active = {}
	for player in pairs(Spy.ActiveList) do
		local position = Spy.NearbyList[player]
		if position ~= nil then
			if prioritiseKoS and SpyPerCharDB.KOSData[player] then
				table.insert(activeKoS, { player = player, time = position })
			else
				table.insert(active, { player = player, time = position })
			end
		end
	end

	local inactiveKoS = {}
	local inactive = {}
	for player in pairs(Spy.InactiveList) do
		local position = Spy.NearbyList[player]
		if position ~= nil then
			if prioritiseKoS and SpyPerCharDB.KOSData[player] then
				table.insert(inactiveKoS, { player = player, time = position })
			else
				table.insert(inactive, { player = player, time = position })
			end
		end
	end

	table.sort(activeKoS, function(a, b) return a.time < b.time end)
	table.sort(inactiveKoS, function(a, b) return a.time < b.time end)
	table.sort(active, function(a, b) return a.time < b.time end)
	table.sort(inactive, function(a, b) return a.time < b.time end)

	local list = {}
	for player in pairs(activeKoS) do table.insert(list, activeKoS[player]) end
	for player in pairs(inactiveKoS) do table.insert(list, inactiveKoS[player]) end
	for player in pairs(active) do table.insert(list, active[player]) end
	for player in pairs(inactive) do table.insert(list, inactive[player]) end
	Spy.CurrentList = list
end

function Spy:ManageLastHourList()
	local list = {}
	for player in pairs(Spy.LastHourList) do
		table.insert(list, { player = player, time = Spy.LastHourList[player] })
	end
	table.sort(list, function(a, b) return a.time > b.time end)
	Spy.CurrentList = list
end

function Spy:ManageIgnoreList()
	local list = {}
	for player in pairs(SpyPerCharDB.IgnoreData) do
		local playerData = SpyPerCharDB.PlayerData[player]
		local position = time()
		if playerData then position = playerData.time end
		table.insert(list, { player = player, time = position })
	end
	table.sort(list, function(a, b) return a.time > b.time end)
	Spy.CurrentList = list
end

function Spy:ManageKillOnSightList()
	local list = {}
	for player in pairs(SpyPerCharDB.KOSData) do
		local playerData = SpyPerCharDB.PlayerData[player]
		local position = time()
		if playerData then position = playerData.time end
		table.insert(list, { player = player, time = position })
	end
	table.sort(list, function(a, b) return a.time > b.time end)
	Spy.CurrentList = list
end

function Spy:GetNearbyListSize()
	local entries = 0
	for v in pairs(Spy.NearbyList) do
		entries = entries + 1
	end
	return entries
end

function Spy:UpdateActiveCount()
    local activeCount = 0
    for k in pairs(Spy.ActiveList) do
        activeCount = activeCount + 1
    end
	local theFrame = Spy.MainWindow
    if activeCount > 0 then 
		theFrame.CountFrame.Text:SetText("|cFF0070DE" .. activeCount .. "|r") 
    else 
        theFrame.CountFrame.Text:SetText("|cFF0070DE0|r")
    end
end

function Spy:ManageExpirations()
	local mode = Spy.db.profile.CurrentList
	local expirationFunction = Spy.ListTypes[mode][3]
	if expirationFunction then
		expirationFunction()
	end
end

function Spy:ManageNearbyListExpirations()
	local expired = false
	local currentTime = time()
	for player in pairs(Spy.ActiveList) do
		if (currentTime - Spy.ActiveList[player]) > Spy.ActiveTimeout then
			Spy.InactiveList[player] = Spy.ActiveList[player]
			Spy.ActiveList[player] = nil
			expired = true
		end
	end
	if Spy.db.profile.RemoveUndetected ~= "Never" then
		for player in pairs(Spy.InactiveList) do
			if (currentTime - Spy.InactiveList[player]) > Spy.InactiveTimeout then
				if Spy.PlayerCommList[player] ~= nil then
					Spy.MapNoteList[Spy.PlayerCommList[player]].displayed = false
					Spy.MapNoteList[Spy.PlayerCommList[player]].worldIcon:Hide()
					HBDP:RemoveMinimapIcon(self, Spy.MapNoteList[Spy.PlayerCommList[player]].miniIcon)
					Spy.PlayerCommList[player] = nil
				end
				Spy.InactiveList[player] = nil
				Spy.NearbyList[player] = nil
				expired = true
			end
		end
	end
	if expired then
		Spy:RefreshCurrentList()
		Spy:UpdateActiveCount()
		if Spy.db.profile.HideSpy and Spy:GetNearbyListSize() == 0 then 
			if not InCombatLockdown() then
				Spy.MainWindow:Hide()
			else	
				Spy:HideSpyCombatCheck()
			end
		end
	end
end

function Spy:ManageLastHourListExpirations()
	local expired = false
	local currentTime = time()
	for player in pairs(Spy.LastHourList) do
		if (currentTime - Spy.LastHourList[player]) > 3600 then
			Spy.LastHourList[player] = nil
			expired = true
		end
	end
	if expired then
		Spy:RefreshCurrentList()
	end
end

function Spy:RemovePlayerFromList(player)
	Spy.NearbyList[player] = nil
	Spy.ActiveList[player] = nil
	Spy.InactiveList[player] = nil
	if Spy.PlayerCommList[player] ~= nil then
		Spy.MapNoteList[Spy.PlayerCommList[player]].displayed = false
		Spy.MapNoteList[Spy.PlayerCommList[player]].worldIcon:Hide()
		HBDP:RemoveMinimapIcon(self, Spy.MapNoteList[Spy.PlayerCommList[player]].miniIcon)
		Spy.PlayerCommList[player] = nil
	end
	Spy:RefreshCurrentList()
	Spy:UpdateActiveCount()	
end

function Spy:ClearList()
	if IsShiftKeyDown () then
		Spy:EnableSound(not Spy.db.profile.EnableSound, false)
	else	
		Spy.NearbyList = {}
		Spy.ActiveList = {}
		Spy.InactiveList = {}
		Spy.PlayerCommList = {}
		Spy.ListAmountDisplayed = 0
		for i = 1, Spy.MapNoteLimit do
			Spy.MapNoteList[i].displayed = false
			Spy.MapNoteList[i].worldIcon:Hide()
			HBDP:RemoveMinimapIcon(self, Spy.MapNoteList[i].miniIcon)
		end
		Spy:SetCurrentList(1)
		if IsControlKeyDown() then
			Spy:EnableSpy(not Spy.db.profile.Enabled, false)
		end
		Spy:UpdateActiveCount()
	end	
end

function Spy:AddPlayerData(name, class, level, race, guild, isEnemy, isGuess)
	local info = {}
	info.name = name  --++ added to normalize data
	info.class = class
	if type(level) == "number" then info.level = level end
	info.race = race
	info.guild = guild
	info.isEnemy = isEnemy
	info.isGuess = isGuess
	SpyPerCharDB.PlayerData[name] = info
	return SpyPerCharDB.PlayerData[name]
end

function Spy:UpdatePlayerData(name, class, level, race, guild, isEnemy, isGuess)
	local detected = true
	local playerData = SpyPerCharDB.PlayerData[name]
	if not playerData then
		playerData = Spy:AddPlayerData(name, class, level, race, guild, isEnemy, isGuess)
	else
		if name ~= nil then playerData.name = name end  
		if class ~= nil then playerData.class = class end
		if type(level) == "number" then playerData.level = level end
		if race ~= nil then playerData.race = race end
		if guild ~= nil then playerData.guild = guild end
		if isEnemy ~= nil then playerData.isEnemy = isEnemy end
		if isGuess ~= nil then playerData.isGuess = isGuess end
	end
	if playerData then
		playerData.time = time()
		if not Spy.ActiveList[name] then
			if (WorldMapFrame:IsVisible() and Spy.db.profile.SwitchToZone) then
				WorldMapFrame:SetMapID(C_Map.GetBestMapForUnit("player"))
			end
			if (nil == C_Map.GetBestMapForUnit("player")) or (nil == C_Map.GetPlayerMapPosition(C_Map.GetBestMapForUnit("player"), "player")) then
				local x,y = 0,0
				local InsName = GetInstanceInfo()
				playerData.zone = InsName
				playerData.subZone = ""
			else
				local mapX, mapY = C_Map.GetPlayerMapPosition(C_Map.GetBestMapForUnit("player"), "player"):GetXY()			
				if mapX ~= 0 and mapY ~= 0 then
					mapX = math.floor(tonumber(mapX) * 100) / 100
					mapY = math.floor(tonumber(mapY) * 100) / 100
					playerData.mapX = mapX
					playerData.mapY = mapY
					playerData.zone = GetZoneText()
					playerData.mapID = C_Map.GetBestMapForUnit("player") --++8.0
					playerData.subZone = GetSubZoneText()
				else
					detected = false
				end
			end
		end	
	end
	return detected
end

function Spy:UpdatePlayerStatus(name, class, level, race, guild, isEnemy, isGuess)
	local playerData = SpyPerCharDB.PlayerData[name]
	if not playerData then
		playerData = Spy:AddPlayerData(name, class, level, race, guild, isEnemy, isGuess)
	else
		if name ~= nil then playerData.name = name end  
		if class ~= nil then playerData.class = class end
		if type(level) == "number" then playerData.level = level end
		if race ~= nil then playerData.race = race end
		if guild ~= nil then playerData.guild = guild end
		if isEnemy ~= nil then playerData.isEnemy = isEnemy end
		if isGuess ~= nil then playerData.isGuess = isGuess end
	end
	if playerData.time == nil then
		playerData.time = time()
	end	
end

function Spy:RemovePlayerData(name)
	SpyPerCharDB.PlayerData[name] = nil
end

function Spy:AddIgnoreData(name)
	SpyPerCharDB.IgnoreData[name] = true
end

function Spy:RemoveIgnoreData(name)
	if SpyPerCharDB.IgnoreData[name] then
		SpyPerCharDB.IgnoreData[name] = nil
	end
end

function Spy:AddKOSData(name)
	SpyPerCharDB.KOSData[name] = time()
--	SpyPerCharDB.PlayerData[name].kos = 1 
	if Spy.db.profile.ShareKOSBetweenCharacters then
		SpyDB.removeKOSData[Spy.RealmName][Spy.FactionName][name] = nil
	end
end

function Spy:RemoveKOSData(name)
	if SpyPerCharDB.KOSData[name] then
		local playerData = SpyPerCharDB.PlayerData[name]
		if playerData and playerData.reason then
			playerData.reason = nil
		end
		SpyPerCharDB.KOSData[name] = nil
		if SpyPerCharDB.PlayerData[name] then
			SpyPerCharDB.PlayerData[name].kos = nil
		end
		if Spy.db.profile.ShareKOSBetweenCharacters then
			SpyDB.removeKOSData[Spy.RealmName][Spy.FactionName][name] = time()
		end
	end
end

function Spy:SetKOSReason(name, reason, other)
	local playerData = SpyPerCharDB.PlayerData[name]
	if playerData then
		if not reason then
			playerData.reason = nil
		else
			if not playerData.reason then playerData.reason = {} end
			if reason == L["KOSReasonOther"] then
				if not other then 
					local dialog = StaticPopup_Show("Spy_SetKOSReasonOther", name)
					if dialog then
						dialog.playerName = name
					end
				else
					if other == "" then
						playerData.reason[L["KOSReasonOther"]] = nil
					else
						playerData.reason[L["KOSReasonOther"]] = other
					end
					Spy:RegenerateKOSCentralList(name)
				end
			else
				if playerData.reason[reason] then
					playerData.reason[reason] = nil
				else
					playerData.reason[reason] = true
				end
				Spy:RegenerateKOSCentralList(name)
			end
		end
	end
end

function Spy:AlertPlayer(player, source)
	local playerData = SpyPerCharDB.PlayerData[player]
	if SpyPerCharDB.KOSData[player] and Spy.db.profile.WarnOnKOS then
--		if Spy.db.profile.DisplayWarningsInErrorsFrame then
		if Spy.db.profile.DisplayWarnings == "ErrorFrame" then
			local text = Spy.db.profile.Colors.Warning["Warning Text"]
			local msg = L["KOSWarning"]..player
			UIErrorsFrame:AddMessage(msg, text.r, text.g, text.b, 1.0, UIERRORS_HOLD_TIME)
		else
			if source ~= nil and source ~= Spy.CharacterName then
				Spy:ShowAlert("kosaway", player, source, Spy:GetPlayerLocation(playerData))
			else
				local reasonText = ""
				if playerData.reason then
					for reason in pairs(playerData.reason) do
						if reasonText ~= "" then reasonText = reasonText..", " end
						if reason == L["KOSReasonOther"] then
							reasonText = reasonText..playerData.reason[reason]
						else
							reasonText = reasonText..reason
						end
					end
				end
				Spy:ShowAlert("kos", player, nil, reasonText)
			end
		end
		if Spy.db.profile.EnableSound then
			if source ~= nil and source ~= Spy.CharacterName then
				PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-kosaway.mp3", Spy.db.profile.SoundChannel)
			else
				PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-kos.mp3", Spy.db.profile.SoundChannel)
			end
		end
		if Spy.db.profile.ShareKOSBetweenCharacters then Spy:RegenerateKOSCentralList(player) end
	elseif Spy.db.profile.WarnOnKOSGuild then
		if playerData and playerData.guild and Spy.KOSGuild[playerData.guild] then
--			if Spy.db.profile.DisplayWarningsInErrorsFrame then
			if Spy.db.profile.DisplayWarnings == "ErrorFrame" then
				local text = Spy.db.profile.Colors.Warning["Warning Text"]
				local msg = L["KOSGuildWarning"].."<"..playerData.guild..">"
				UIErrorsFrame:AddMessage(msg, text.r, text.g, text.b, 1.0, UIERRORS_HOLD_TIME)				
			else
				if source ~= nil and source ~= Spy.CharacterName then
					Spy:ShowAlert("kosguildaway", "<"..playerData.guild..">", source, Spy:GetPlayerLocation(playerData))
				else
					Spy:ShowAlert("kosguild", "<"..playerData.guild..">")
				end
			end
			if Spy.db.profile.EnableSound then
				if source ~= nil and source ~= Spy.CharacterName then
					PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-kosaway.mp3", Spy.db.profile.SoundChannel)
				else
					PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-kosguild.mp3", Spy.db.profile.SoundChannel)
				end
			end
		else
			if Spy.db.profile.EnableSound and not Spy.db.profile.OnlySoundKoS then 
				if source == nil or source == Spy.CharacterName then
					if playerData and Spy.db.profile.WarnOnRace and playerData.race == Spy.db.profile.SelectWarnRace then --++
						PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-race.mp3", Spy.db.profile.SoundChannel) 
					else
						PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-nearby.mp3", Spy.db.profile.SoundChannel)
					end
				end
			end
		end 
	elseif Spy.db.profile.EnableSound and not Spy.db.profile.OnlySoundKoS then 
		if source == nil or source == Spy.CharacterName then
			if playerData and Spy.db.profile.WarnOnRace and playerData.race == Spy.db.profile.SelectWarnRace then
				PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-race.mp3", Spy.db.profile.SoundChannel) 
			else
				PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-nearby.mp3", Spy.db.profile.SoundChannel)
			end
		end
	elseif Spy.db.profile.EnableSound and not Spy.db.profile.OnlySoundKoS then
		if source == nil or source == Spy.CharacterName then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-nearby.mp3", Spy.db.profile.SoundChannel)
		end
	end
end

function Spy:AlertStealthPlayer(player)
	if Spy.db.profile.WarnOnStealth then
--		if Spy.db.profile.DisplayWarningsInErrorsFrame then
		if Spy.db.profile.DisplayWarnings == "ErrorFrame" then
			local text = Spy.db.profile.Colors.Warning["Warning Text"]
			local msg = L["StealthWarning"]..player
			UIErrorsFrame:AddMessage(msg, text.r, text.g, text.b, 1.0, UIERRORS_HOLD_TIME)
		else
			Spy:ShowAlert("stealth", player)
		end
		if Spy.db.profile.EnableSound then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-stealth.mp3", Spy.db.profile.SoundChannel)
		end
	end
end

function Spy:AlertProwlPlayer(player)
	if Spy.db.profile.WarnOnStealth then
--		if Spy.db.profile.DisplayWarningsInErrorsFrame then
		if Spy.db.profile.DisplayWarnings == "ErrorFrame" then
			local text = Spy.db.profile.Colors.Warning["Warning Text"]
			local msg = L["StealthWarning"]..player
			UIErrorsFrame:AddMessage(msg, text.r, text.g, text.b, 1.0, UIERRORS_HOLD_TIME)
		else
			Spy:ShowAlert("prowl", player)
		end
		if Spy.db.profile.EnableSound then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\detected-stealth.mp3", Spy.db.profile.SoundChannel)
		end
	end
end

function Spy:AnnouncePlayer(player, channel)
	if not Spy_IgnoreList[player] then
		local msg = ""
		local isKOS = SpyPerCharDB.KOSData[player]
		local playerData = SpyPerCharDB.PlayerData[player]

		local announce = Spy.db.profile.Announce  
		if channel or announce == "Self" or announce == "LocalDefense" or (announce == "Guild" and GetGuildInfo("player") ~= nil and not Spy.InInstance) or (announce == "Party" and GetNumGroupMembers() > 0) or (announce == "Raid" and UnitInRaid("player")) then --++
			if announce == "Self" and not channel then
				if isKOS then
					msg = msg..L["SpySignatureColored"]..L["KillOnSightDetectedColored"]..player.." "
				else
					msg = msg..L["SpySignatureColored"]..L["PlayerDetectedColored"]..player.." "
				end
			else
				if isKOS then
					msg = msg..L["KillOnSightDetected"]..player.." "
				else
					msg = msg..L["PlayerDetected"]..player.." "
				end
			end
			if playerData then
				if playerData.guild and playerData.guild ~= "" then
					msg = msg.."<"..playerData.guild.."> "
				end
				if playerData.level or playerData.race or (playerData.class and playerData.class ~= "") then
					msg = msg.."- "
					if playerData.level and playerData.isGuess == false then
						msg = msg..L["Level"].." "..playerData.level.." "
					end
					if playerData.race and playerData.race ~= "" then
						msg = msg..playerData.race.." "
					end
					if playerData.class and playerData.class ~= "" then
						msg = msg..L[playerData.class].." "
					end
				end
				if playerData.zone then
					if playerData.subZone and playerData.subZone ~= "" and playerData.subZone ~= playerData.zone then
						msg = msg.."- "..playerData.subZone..", "..playerData.zone
					else
						msg = msg.."- "..playerData.zone
					end
				end
				if playerData.mapX and playerData.mapY then
					msg = msg.." ("..math.floor(tonumber(playerData.mapX) * 100)..","..math.floor(tonumber(playerData.mapY) * 100)..")"
				end
			end

			if channel then
				-- announce to selected channel
				if (channel == "PARTY" and GetNumGroupMembers() > 0) or (channel == "RAID" and UnitInRaid("player")) or (channel == "GUILD" and GetGuildInfo("player") ~= nil) then
					SendChatMessage(msg, channel)
				elseif channel == "LOCAL" then
					SendChatMessage(msg, "CHANNEL", nil, GetChannelName(L["LocalDefenseChannelName"].." - "..GetZoneText()))
				end
			else
				-- announce to standard channel
				if isKOS or not Spy.db.profile.OnlyAnnounceKoS then
					if announce == "Self" then
						DEFAULT_CHAT_FRAME:AddMessage(msg)
					elseif announce == "LocalDefense" then
						SendChatMessage(msg, "CHANNEL", nil, GetChannelName(L["LocalDefenseChannelName"].." - "..GetZoneText()))
					else
						SendChatMessage(msg, strupper(announce))
					end
				end
			end
		end

		-- announce to other Spy users
		if Spy.db.profile.ShareData then
			local class, level, race, zone, subZone, mapX, mapY, guild, mapID = "", "", "", "", "", "", "", "", ""
			if playerData then
				if playerData.class then class = playerData.class end
				if playerData.level and playerData.isGuess == false then level = playerData.level end
				if playerData.race then race = playerData.race end
				if playerData.zone then zone = playerData.zone end
				if playerData.mapID then mapID = playerData.mapID end
				if playerData.subZone then subZone = playerData.subZone end
				if playerData.mapX then mapX = playerData.mapX end
				if playerData.mapY then mapY = playerData.mapY end
				if playerData.guild then guild = playerData.guild end
			end
			local details = Spy.Version.."|"..player.."|"..class.."|"..level.."|"..race.."|"..zone.."|"..subZone.."|"..mapX.."|"..mapY.."|"..guild.."|"..mapID
			if strlen(details) < 240 then
				if channel then
					if (channel == "PARTY" and GetNumGroupMembers() > 0) or (channel == "RAID" and UnitInRaid("player")) or (channel == "GUILD" and GetGuildInfo("player") ~= nil) then
						Spy:SendCommMessage(Spy.Signature, details, channel)
					end
				else
					if GetNumGroupMembers() > 0 then
						Spy:SendCommMessage(Spy.Signature, details, "PARTY")
					end
					if UnitInRaid("player") then
						Spy:SendCommMessage(Spy.Signature, details, "RAID")
					end
					if Spy.InInstance == false and GetGuildInfo("player") ~= nil then
						Spy:SendCommMessage(Spy.Signature, details, "GUILD")
					end
				end
			end
		end
	end	
end

function Spy:SendKoStoGuild(player)
	local playerData = SpyPerCharDB.PlayerData[player]
	local class, level, race, zone, subZone, mapX, mapY, guild, mapID = "", "", "", "", "", "", "", "", ""	 			
	if playerData then
		if playerData.class then class = playerData.class end
		if playerData.level and playerData.isGuess == false then level = playerData.level end
		if playerData.race then race = playerData.race end
		if playerData.zone then zone = playerData.zone end
		if playerData.mapID then mapID = playerData.mapID end
		if playerData.subZone then subZone = playerData.subZone end
		if playerData.mapX then mapX = playerData.mapX end
		if playerData.mapY then mapY = playerData.mapY end
		if playerData.guild then guild = playerData.guild end
	end
	local details = Spy.Version.."|"..player.."|"..class.."|"..level.."|"..race.."|"..zone.."|"..subZone.."|"..mapX.."|"..mapY.."|"..guild.."|"..mapID
	if strlen(details) < 240 then
		if Spy.InInstance == false and GetGuildInfo("player") ~= nil then
			Spy:SendCommMessage(Spy.Signature, details, "GUILD")
		end
	end
end

function Spy:ToggleIgnorePlayer(ignore, player)
	if ignore then
		Spy:AddIgnoreData(player)
		Spy:RemoveKOSData(player)
		if Spy.db.profile.EnableSound then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\list-add.mp3", Spy.db.profile.SoundChannel)
		end
		DEFAULT_CHAT_FRAME:AddMessage(L["SpySignatureColored"]..L["PlayerAddedToIgnoreColored"]..player)
	else
		Spy:RemoveIgnoreData(player)
		if Spy.db.profile.EnableSound then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\list-remove.mp3", Spy.db.profile.SoundChannel)
		end
		DEFAULT_CHAT_FRAME:AddMessage(L["SpySignatureColored"]..L["PlayerRemovedFromIgnoreColored"]..player)
	end
	Spy:RegenerateKOSGuildList()
	if Spy.db.profile.ShareKOSBetweenCharacters then
		Spy:RegenerateKOSCentralList()
	end
	Spy:RefreshCurrentList()
end

function Spy:ToggleKOSPlayer(kos, player)
	if kos then
		Spy:AddKOSData(player)
		Spy:RemoveIgnoreData(player)
		if player ~= SpyPerCharDB.PlayerData[name] then
--			Spy:UpdatePlayerData(player, nil, nil, nil, nil, true, nil)
			Spy:UpdatePlayerStatus(player, nil, nil, nil, nil, true, nil)
			SpyPerCharDB.PlayerData[player].kos = 1
		end	
		if Spy.db.profile.EnableSound then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\list-add.mp3", Spy.db.profile.SoundChannel)
		end
		DEFAULT_CHAT_FRAME:AddMessage(L["SpySignatureColored"]..L["PlayerAddedToKOSColored"]..player)
	else
		Spy:RemoveKOSData(player)
		if Spy.db.profile.EnableSound then
			PlaySoundFile("Interface\\AddOns\\Spy\\Sounds\\list-remove.mp3", Spy.db.profile.SoundChannel)
		end
		DEFAULT_CHAT_FRAME:AddMessage(L["SpySignatureColored"]..L["PlayerRemovedFromKOSColored"]..player)
	end
	Spy:RegenerateKOSGuildList()
	if Spy.db.profile.ShareKOSBetweenCharacters then
		Spy:RegenerateKOSCentralList()
	end
	Spy:RefreshCurrentList()
end

function Spy:PurgeUndetectedData()
	local secondsPerDay = 60 * 60 * 24
	local timeout = 90 * secondsPerDay
	if Spy.db.profile.PurgeData == "OneDay" then
		timeout = secondsPerDay
	elseif Spy.db.profile.PurgeData == "FiveDays" then
		timeout = 5 * secondsPerDay
	elseif Spy.db.profile.PurgeData == "TenDays" then
		timeout = 10 * secondsPerDay
	elseif Spy.db.profile.PurgeData == "ThirtyDays" then
		timeout = 30 * secondsPerDay
	elseif Spy.db.profile.PurgeData == "SixtyDays" then
		timeout = 60 * secondsPerDay
	elseif Spy.db.profile.PurgeData == "NinetyDays" then
		timeout = 90 * secondsPerDay
	end

	-- remove expired players held in character data
	local currentTime = time()
	for player in pairs(SpyPerCharDB.PlayerData) do
		local playerData = SpyPerCharDB.PlayerData[player]
		if Spy.db.profile.PurgeWinLossData then
			if not playerData.time or (currentTime - playerData.time) > timeout or not playerData.isEnemy then
				Spy:RemoveIgnoreData(player)
				Spy:RemoveKOSData(player)
				SpyPerCharDB.PlayerData[player] = nil
			end
		else
			if ((playerData.loses == nil) and (playerData.wins == nil)) then
				if not playerData.time or (currentTime - playerData.time) > timeout or not playerData.isEnemy then
					Spy:RemoveIgnoreData(player)
					if Spy.db.profile.PurgeKoS then
						Spy:RemoveKOSData(player)
						SpyPerCharDB.PlayerData[player] = nil
					else
						if (playerData.kos == nil) then
							SpyPerCharDB.PlayerData[player] = nil
						end	
					end	
				end
			end
		end
	end
	
	-- remove expired kos players held in central data
	local kosData = SpyDB.kosData[Spy.RealmName][Spy.FactionName]
	for characterName in pairs(kosData) do
		local characterKosData = kosData[characterName]
		for player in pairs(characterKosData) do
			local kosPlayerData = characterKosData[player]
			if Spy.db.profile.PurgeKoS then
				if not kosPlayerData.time or (currentTime - kosPlayerData.time) > timeout or not kosPlayerData.isEnemy then
					SpyDB.kosData[Spy.RealmName][Spy.FactionName][characterName][player] = nil
					SpyDB.removeKOSData[Spy.RealmName][Spy.FactionName][player] = nil
				end
			end
		end
	end
	if not Spy.db.profile.AppendUnitNameCheck then 	
		Spy:AppendUnitNames() end
	if not Spy.db.profile.AppendUnitKoSCheck then
		Spy:AppendUnitKoS() end
end

function Spy:RegenerateKOSGuildList()
	Spy.KOSGuild = {}
	for player in pairs(SpyPerCharDB.KOSData) do
		local playerData = SpyPerCharDB.PlayerData[player]
		if playerData and playerData.guild then
			Spy.KOSGuild[playerData.guild] = true
		end
	end
end

function Spy:RemoveLocalKOSPlayers()
	for player in pairs(SpyPerCharDB.KOSData) do
		if SpyDB.removeKOSData[Spy.RealmName][Spy.FactionName][player] then
			Spy:RemoveKOSData(player)
		end
	end
end

function Spy:RegenerateKOSCentralList(player)
	if player then
		local playerData = SpyPerCharDB.PlayerData[player]
		SpyDB.kosData[Spy.RealmName][Spy.FactionName][Spy.CharacterName][player] = {}
		if playerData then
			SpyDB.kosData[Spy.RealmName][Spy.FactionName][Spy.CharacterName][player] = playerData
		end
		SpyDB.kosData[Spy.RealmName][Spy.FactionName][Spy.CharacterName][player].added = SpyPerCharDB.KOSData[player]
	else
		for player in pairs(SpyPerCharDB.KOSData) do
			local playerData = SpyPerCharDB.PlayerData[player]
			SpyDB.kosData[Spy.RealmName][Spy.FactionName][Spy.CharacterName][player] = {}
			if playerData then
				SpyDB.kosData[Spy.RealmName][Spy.FactionName][Spy.CharacterName][player] = playerData
			end
			SpyDB.kosData[Spy.RealmName][Spy.FactionName][Spy.CharacterName][player].added = SpyPerCharDB.KOSData[player]
		end
	end
end

function Spy:RegenerateKOSListFromCentral()
	local kosData = SpyDB.kosData[Spy.RealmName][Spy.FactionName]
	for characterName in pairs(kosData) do
		if characterName ~= Spy.CharacterName then
			local characterKosData = kosData[characterName]
			for player in pairs(characterKosData) do
				if not SpyDB.removeKOSData[Spy.RealmName][Spy.FactionName][player] then
					local playerData = SpyPerCharDB.PlayerData[player]
					if not playerData then
						playerData = Spy:AddPlayerData(player, class, level, race, guild, isEnemy, isGuess)
					end
					local kosPlayerData = characterKosData[player]
					if kosPlayerData.time and (not playerData.time or (playerData.time and playerData.time < kosPlayerData.time)) then
						playerData.time = kosPlayerData.time
						if kosPlayerData.class then
							playerData.class = kosPlayerData.class
						end
						if type(kosPlayerData.level) == "number" and (type(playerData.level) ~= "number" or playerData.level < kosPlayerData.level) then
							playerData.level = kosPlayerData.level
						end
						if kosPlayerData.race then
							playerData.race = kosPlayerData.race
						end
						if kosPlayerData.guild then
							playerData.guild = kosPlayerData.guild
						end
						if kosPlayerData.isEnemy then
							playerData.isEnemy = kosPlayerData.isEnemy
						end
						if kosPlayerData.isGuess then
							playerData.isGuess = kosPlayerData.isGuess
						end
						if type(kosPlayerData.wins) == "number" and (type(playerData.wins) ~= "number" or playerData.wins < kosPlayerData.wins) then
							playerData.wins = kosPlayerData.wins
						end
						if type(kosPlayerData.loses) == "number" and (type(playerData.loses) ~= "number" or playerData.loses < kosPlayerData.loses) then
							playerData.loses = kosPlayerData.loses
						end
						if kosPlayerData.mapX then
							playerData.mapX = kosPlayerData.mapX
						end
						if kosPlayerData.mapY then
							playerData.mapY = kosPlayerData.mapY
						end
						if kosPlayerData.zone then
							playerData.zone = kosPlayerData.zone
						end
						if kosPlayerData.mapID then
							playerData.mapID = kosPlayerData.mapID
						end
						if kosPlayerData.subZone then
							playerData.subZone = kosPlayerData.subZone
						end
						if kosPlayerData.reason then
							playerData.reason = {}
							for reason in pairs(kosPlayerData.reason) do
								playerData.reason[reason] = kosPlayerData.reason[reason]
							end
						end
					end
					local characterKOSPlayerData = SpyPerCharDB.KOSData[player]
					if kosPlayerData.added and (not characterKOSPlayerData or characterKOSPlayerData < kosPlayerData.added) then
						SpyPerCharDB.KOSData[player] = kosPlayerData.added
					end
				end
			end
		end
	end
end

function Spy:ButtonClicked(self, button)
	local name = Spy.ButtonName[self.id]
	if name and name ~= "" then
		if button == "LeftButton" then
			if IsShiftKeyDown() then
				if SpyPerCharDB.KOSData[name] then
					Spy:ToggleKOSPlayer(false, name)
				else
					Spy:ToggleKOSPlayer(true, name)
				end
			elseif IsControlKeyDown() then
				if SpyPerCharDB.IgnoreData[name] then
					Spy:ToggleIgnorePlayer(false, name)
				else
					Spy:ToggleIgnorePlayer(true, name)
				end
			else
				if not InCombatLockdown() then
					self:SetAttribute("macrotext", "/targetexact "..name)
				end
			end
		elseif button == "RightButton" then
			Spy:BarDropDownOpen(self)
			CloseDropDownMenus(1)
			ToggleDropDownMenu(1, nil, Spy_BarDropDownMenu)
		end
	end
end

function Spy:ParseMinimapTooltip(tooltip)
	local newTooltip = ""
	local newLine = false
	for text in string.gmatch(tooltip, "[^\n]*") do
		local name = text
		if string.len(text) > 0 then
			if strsub(text, 1, 2) == "|T" then
			name = strtrim(gsub(gsub(text, "|T.-|t", ""), "|r", ""))
			end
			local playerData = SpyPerCharDB.PlayerData[name]
			if not playerData then
				for index, v in pairs(Spy.LastHourList) do
					local realmSeparator = strfind(index, "-")
					if realmSeparator and realmSeparator > 1 and strsub(index, 1, realmSeparator - 1) == strsub(name, 1, realmSeparator - 1) then
						playerData = SpyPerCharDB.PlayerData[index]
						break
					end
				end
			end
			if playerData and playerData.isEnemy then
				local desc = ""
				if playerData.class and playerData.level then
					desc = L["MinimapClassText"..playerData.class].." ["..playerData.level.." "..L[playerData.class].."]|r"
				elseif playerData.class then
					desc = L["MinimapClassText"..playerData.class].." ["..L[playerData.class].."]|r"
				elseif playerData.level then
					desc = " ["..playerData.level.."]|r"
				end
				if (newTooltip and desc == "") then
					newTooltip = text 
				elseif (newTooltip == "") then	
					newTooltip = text.."|r"..desc
				else
					newTooltip = newTooltip.."\r"..text.."|r"..desc
				end	
				if not SpyPerCharDB.IgnoreData[name] and not Spy.InInstance then
					local detected = Spy:UpdatePlayerData(name, nil, nil, nil, nil, true, nil)
					if detected and Spy.db.profile.MinimapDetection then
						Spy:AddDetected(name, time(), false)
					end
				end
			else
				if (newTooltip == "") then
					newTooltip = text
				else	
					newTooltip = newTooltip.."\n"..text
				end
			end
			newLine = false
		elseif not newLine then
			newTooltip = newTooltip
			newLine = true
		end
	end
	return newTooltip
end

function Spy:ParseUnitAbility(analyseSpell, event, player, class, race, spellId, spellName)
	local learnt = false
	if player then
--		local class = nil
		local level = nil
--		local race = nil
		local isEnemy = true
		local isGuess = true

		local playerData = SpyPerCharDB.PlayerData[player]
		if not playerData or playerData.isEnemy == nil then
			learnt = true
		end

		if analyseSpell then
			local abilityType = strsub(event, 1, 5)
			if abilityType == "SWING" or abilityType == "SPELL" or abilityType == "RANGE" then
--				local ability = Spy_AbilityList[spellName]
				local ability = Spy_AbilityList[spellId]
				if ability then
					if class == nil then
						if ability.class and not (playerData and playerData.class) then
							class = ability.class
							learnt = true
						end
					end
					if ability.level then
						local playerLevelNumber = nil
						if playerData and playerData.level then
							playerLevelNumber = tonumber(playerData.level)
						end
						if type(playerLevelNumber) ~= "number" or playerLevelNumber < ability.level then
							level = ability.level
							learnt = true
						end
					end
					if race == nil then
						if ability.race and not (playerData and playerData.race) then
							race = ability.race
							learnt = true
						end
					end	
				else	
--					print(spellId, " - ", spellName)
				end
				if class and race and level == Spy.MaximumPlayerLevel then
					isGuess = false
					learnt = true
				end
			end
		end

		Spy:UpdatePlayerData(player, class, level, race, nil, isEnemy, isGuess)
		return learnt, playerData
	end
	return learnt, nil
end

function Spy:ParseUnitDetails(player, class, level, race, zone, subZone, mapX, mapY, guild, mapID)
	if player then
		local playerData = SpyPerCharDB.PlayerData[player]
		if not playerData then
			playerData = Spy:AddPlayerData(player, class, level, race, guild, true, true)
		else
			if not playerData.class then playerData.class = class end
			if level then
				local levelNumber = tonumber(level)
				if type(levelNumber) == "number" then
					if playerData.level then
						local playerLevelNumber = tonumber(playerData.level)
						if type(playerLevelNumber) == "number" and playerLevelNumber < levelNumber then playerData.level = levelNumber end
					else
						playerData.level = levelNumber
					end
				end
			end
			if not playerData.race then
				playerData.race = race
			end
			if not playerData.guild then
				playerData.guild = guild
			end
		end
		playerData.isEnemy = true
		playerData.time = time()
		playerData.zone = zone
		playerData.mapID = mapID
		playerData.subZone = subZone
		playerData.mapX = mapX
		playerData.mapY = mapY

		return true, playerData
	end
	return true, nil
end

function Spy:AddDetected(player, timestamp, learnt, source)
	if Spy.db.profile.StopAlertsOnTaxi then
		if not UnitOnTaxi("player") then 
			Spy:AddDetectedToLists(player, timestamp, learnt, source)
		end
	else
		Spy:AddDetectedToLists(player, timestamp, learnt, source)
	end
--[[if Spy.db.profile.ShowOnlyPvPFlagged then
		if UnitIsPVP("target") then
			Spy:AddDetectedToLists(player, timestamp, learnt, source)
		end	
	else
		Spy:AddDetectedToLists(player, timestamp, learnt, source)
	end ]]--
end

function Spy:AddDetectedToLists(player, timestamp, learnt, source)
	if not Spy.NearbyList[player] then
		if Spy.db.profile.ShowOnDetection and not Spy.db.profile.MainWindowVis then
			Spy:SetCurrentList(1)
			Spy:EnableSpy(true, true, true)
		end
		if Spy.db.profile.CurrentList ~= 1 and Spy.db.profile.MainWindowVis and Spy.db.profile.ShowNearbyList then
			Spy:SetCurrentList(1)
		end

		if source and source ~= Spy.CharacterName and not Spy.ActiveList[player] then
			Spy.NearbyList[player] = timestamp
			Spy.LastHourList[player] = timestamp
			Spy.InactiveList[player] = timestamp
		else
			Spy.NearbyList[player] = timestamp
			Spy.LastHourList[player] = timestamp
			Spy.ActiveList[player] = timestamp
			Spy.InactiveList[player] = nil
		end

		if Spy.db.profile.CurrentList == 1 then
			Spy:RefreshCurrentList(player, source)
			Spy:UpdateActiveCount()			
		else
			if not source or source ~= Spy.CharacterName then
				Spy:AlertPlayer(player, source)
				if not source then Spy:AnnouncePlayer(player) end
			end
		end
	elseif not Spy.ActiveList[player] then
		if Spy.db.profile.ShowOnDetection and not Spy.db.profile.MainWindowVis then
			Spy:SetCurrentList(1)
			Spy:EnableSpy(true, true, true)
		end
		if Spy.db.profile.CurrentList ~= 1 and Spy.db.profile.MainWindowVis and Spy.db.profile.ShowNearbyList then
			Spy:SetCurrentList(1)
		end

		Spy.LastHourList[player] = timestamp
		Spy.ActiveList[player] = timestamp
		Spy.InactiveList[player] = nil

		if Spy.PlayerCommList[player] ~= nil then
			if Spy.db.profile.CurrentList == 1 then
				Spy:RefreshCurrentList(player, source)
			else
				if not source or source ~= Spy.CharacterName then
					Spy:AlertPlayer(player, source)
					if not source then Spy:AnnouncePlayer(player) end
				end
			end
		else
			if Spy.db.profile.CurrentList == 1 then
				Spy:RefreshCurrentList()
				Spy:UpdateActiveCount()
			end
		end
	else
		Spy.ActiveList[player] = timestamp
		Spy.LastHourList[player] = timestamp
		if learnt and Spy.db.profile.CurrentList == 1 then
			Spy:RefreshCurrentList()
			Spy:UpdateActiveCount()
		end
	end
end

function Spy:AppendUnitNames()
	for key, unit in pairs(SpyPerCharDB.PlayerData) do	
		-- find any units without a name
		if not unit.name then
			local name = key
		-- if unit.name does not exist update info
			if (not unit.name) and name then
				unit.name = key
			end
		end
    end
	-- set profile so it only runs once
	Spy.db.profile.AppendUnitNameCheck=true
end

function Spy:AppendUnitKoS()
	for kosName, value in pairs(SpyPerCharDB.KOSData) do
		if kosName then	
			local playerData = SpyPerCharDB.PlayerData[kosName]
			if not playerData then 
				Spy:UpdatePlayerData(kosName, nil, nil, nil, nil, true, nil) 
				SpyPerCharDB.PlayerData[kosName].kos = 1
				SpyPerCharDB.PlayerData[kosName].time = value
			end
		end
    end
	-- set profile so it only runs once
	Spy.db.profile.AppendUnitKoSCheck=true
end

Spy.ListTypes = {
	{L["Nearby"], Spy.ManageNearbyList, Spy.ManageNearbyListExpirations},
	{L["LastHour"], Spy.ManageLastHourList, Spy.ManageLastHourListExpirations},
	{L["Ignore"], Spy.ManageIgnoreList},
	{L["KillOnSight"], Spy.ManageKillOnSightList},
}

Spy_AbilityList = {
--++ Racial Traits ++	
	[68976]={ race = "Worgen", level = 1, },
	[317795]={ race = "Vulpera", level = 1, },
	[94293]={ race = "Worgen", level = 1, },
	[274738]={ race = "Mag'har Orc", level = 1, },
	[255663]={ race = "Nightborne", level = 1, },
	[154742]={ race = "Blood Elf", level = 1, },
	[28877]={ race = "Blood Elf", level = 1, },
	[260364]={ race = "Nightborne", level = 1, },
	[822]={ race = "Blood Elf", level = 1, },
	[20592]={ race = "Gnome", level = 1, },
	[255664]={ race = "Nightborne", level = 1, },
	[25046]={ race = "Blood Elf", level = 1, },
	[28730]={ race = "Blood Elf", level = 1, },
	[50613]={ race = "Blood Elf", level = 1, },
	[69179]={ race = "Blood Elf", level = 1, },
	[80483]={ race = "Blood Elf", level = 1, },
	[129597]={ race = "Blood Elf", level = 1, },
	[155145]={ race = "Blood Elf", level = 1, },
	[202719]={ race = "Blood Elf", level = 1, },
	[232633]={ race = "Blood Elf", level = 1, },
	[365575]={ race = "Dracthyr", level = 1, },
	[312411]={ race = "Vulpera", level = 1, },
	[20557]={ race = "Troll", level = 1, },
	[26297]={ race = "Troll", level = 1, },
	[69044]={ race = "Goblin", level = 1, },
	[69045]={ race = "Goblin", level = 1, },
	[20572]={ race = "Orc", level = 1, },
	[33697]={ race = "Orc", level = 1, },
	[33702]={ race = "Orc", level = 1, },
	[107076]={ race = "Pandaren", level = 1, },
	[154743]={ race = "Tauren", level = 1, },
	[291628]={ race = "Kul Tiran", level = 1, },
	[255654]={ race = "Highmountain Tauren", level = 1, },
	[20577]={ race = "Undead", level = 1, },
	[255661]={ race = "Nightborne", level = 1, },
	[291622]={ race = "Kul Tiran", level = 1, },
	[255668]={ race = "Void Elf", level = 1, },
	[360022]={ race = "Dracthyr", level = 1, },
	[291619]={ race = "Zandalari Troll", level = 1, },
	[312923]={ race = "Mechagnome", level = 1, },
	[20552]={ race = "Tauren", level = 1, },
	[58943]={ race = "Troll", level = 1, },
	[68992]={ race = "Worgen", level = 1, },
	[255653]={ race = "Lightforged Draenei", level = 1, },
	[20599]={ race = "Human", level = 1, },
	[366489]={ race = "Dracthyr", level = 1, },
	[265223]={ race = "Dark Iron Dwarf", level = 1, },
	[292751]={ race = "Zandalari Troll", level = 1, },
	[292752]={ race = "Zandalari Troll", level = 1, },
	[312916]={ race = "Mechagnome", level = 1, },
	[20550]={ race = "Tauren", level = 1, },
	[20593]={ race = "Gnome", level = 1, },
	[255669]={ race = "Void Elf", level = 1, },
	[256374]={ race = "Void Elf", level = 1, },
	[259756]={ race = "Void Elf", level = 1, },
	[259760]={ race = "Void Elf", level = 1, },
	[107072]={ race = "Pandaren", level = 1, },
	[20589]={ race = "Gnome", level = 1, },
	[255667]={ race = "Void Elf", level = 1, },
	[20591]={ race = "Gnome", level = 1, },
	[154744]={ race = "Gnome", level = 1, },
	[154746]={ race = "Gnome", level = 1, },
	[154747]={ race = "Gnome", level = 1, },
	[227057]={ race = "Gnome", level = 1, },
	[92682]={ race = "Dwarf", level = 1, },
	[360009]={ race = "Dracthyr", level = 1, },
	[312198]={ race = "Vulpera", level = 1, },
	[265221]={ race = "Dark Iron Dwarf", level = 1, },
	[68978]={ race = "Worgen", level = 1, },
	[255650]={ race = "Lightforged Draenei", level = 1, },
	[259930]={ race = "Lightforged Draenei", level = 1, },
	[265224]={ race = "Dark Iron Dwarf", level = 1, },
	[20596]={ race = "Dwarf", level = 1, },
	[28875]={ race = "Draenei", level = 1, },
	[28880]={ race = "Draenei", level = 1, },
	[59542]={ race = "Draenei", level = 1, },
	[59543]={ race = "Draenei", level = 1, },
	[59544]={ race = "Draenei", level = 1, },
	[59545]={ race = "Draenei", level = 1, },
	[59547]={ race = "Draenei", level = 1, },
	[59548]={ race = "Draenei", level = 1, },
	[121093]={ race = "Draenei", level = 1, },
	[370626]={ race = "Draenei", level = 1, },
	[358733]={ race = "Dracthyr", level = 1, },
	[107073]={ race = "Pandaren", level = 1, },
	[20573]={ race = "Orc", level = 1, },
	[287712]={ race = "Kul Tiran", level = 1, },
	[6562]={ race = "Draenei", level = 1, },
	[255651]={ race = "Lightforged Draenei", level = 1, },
	[312924]={ race = "Mechagnome", level = 1, },
	[107074]={ race = "Pandaren", level = 1, },
	[291442]={ race = "Kul Tiran", level = 1, },
	[131701]={ race = "Pandaren", level = 1, },
	[262438]={ race = "Nightborne", level = 1, },
	[262486]={ race = "Void Elf", level = 1, },
	[273105]={ race = "Dark Iron Dwarf", level = 1, },
	[274743]={ race = "Mag'har Orc", level = 1, },
	[292489]={ race = "Zandalari Troll", level = 1, },
	[292495]={ race = "Kul Tiran", level = 1, },
	[312766]={ race = "Mechagnome", level = 1, },
	[312769]={ race = "Vulpera", level = 1, },
	[255647]={ race = "Lightforged Draenei", level = 1, },
	[255652]={ race = "Lightforged Draenei", level = 1, },
	[255665]={ race = "Nightborne", level = 1, },
	[312370]={ race = "Vulpera", level = 1, },
	[265222]={ race = "Dark Iron Dwarf", level = 1, },
	[312896]={ race = "Mechagnome", level = 1, },
	[265225]={ race = "Dark Iron Dwarf", level = 1, },
	[255658]={ race = "Highmountain Tauren", level = 1, },
	[20551]={ race = "Tauren", level = 1, },
	[20583]={ race = "Night Elf", level = 1, },
	[92680]={ race = "Gnome", level = 1, },
	[312215]={ race = "Vulpera", level = 1, },
	[273216]={ race = "Mag'har Orc", level = 1, },
	[69046]={ race = "Goblin", level = 1, },
	[255670]={ race = "Void Elf", level = 1, },
	[255655]={ race = "Highmountain Tauren", level = 1, },
	[281954]={ race = "Zandalari Troll", level = 1, },
	[107079]={ race = "Pandaren", level = 1, },
	[20582]={ race = "Night Elf", level = 1, },
	[291944]={ race = "Zandalari Troll", level = 1, },
	[20555]={ race = "Troll", level = 1, },
	[312372]={ race = "Vulpera", level = 1, },
	[291417]={ race = "Kul Tiran", level = 1, },
	[69041]={ race = "Goblin", level = 1, },
	[69070]={ race = "Goblin", level = 1, },
	[255659]={ race = "Highmountain Tauren", level = 1, },
	[312425]={ race = "Vulpera", level = 1, },
	[87840]={ race = "Worgen", level = 1, },
	[273220]={ race = "Mag'har Orc", level = 1, },
	[20579]={ race = "Undead", level = 1, },
	[59221]={ race = "Draenei", level = 1, },
	[58984]={ race = "Night Elf", level = 1, },
	[312890]={ race = "Mechagnome", level = 1, },
	[376744]={ race = "Dracthyr", level = 1, },
	[369536]={ race = "Dracthyr", level = 1, },
	[256948]={ race = "Void Elf", level = 1, },
	[20594]={ race = "Dwarf", level = 1, },
	[376743]={ race = "Dracthyr", level = 1, },
	[273217]={ race = "Mag'har Orc", level = 1, },
	[20598]={ race = "Human", level = 1, },
	[69042]={ race = "Goblin", level = 1, },
	[154748]={ race = "Night Elf", level = 1, },
	[154796]={ race = "Night Elf", level = 1, },
	[154797]={ race = "Night Elf", level = 1, },
	[5227]={ race = "Undead", level = 1, },
	[68996]={ race = "Worgen", level = 1, },
	[68975]={ race = "Worgen", level = 1, },
	[372014]={ race = "Dracthyr", level = 1, },
	[20549]={ race = "Tauren", level = 1, },
	[255656]={ race = "Highmountain Tauren", level = 1, },
	[7744]={ race = "Undead", level = 1, },
	[59752]={ race = "Human", level = 1, },
	[20585]={ race = "Night Elf", level = 1, },
--++ Death Knight Abliities ++	
	[137005]={ class = "DEATHKNIGHT", level = 10, },
	[82246]={ class = "DEATHKNIGHT", level = 10, },
	[278107]={ class = "DEATHKNIGHT", level = 10, },
	[197147]={ class = "DEATHKNIGHT", level = 10, },
	[195757]={ class = "DEATHKNIGHT", level = 10, },
	[194311]={ class = "DEATHKNIGHT", level = 10, },
	[316239]={ class = "DEATHKNIGHT", level = 10, },
	[47541]={ class = "DEATHKNIGHT", level = 10, },
	[43265]={ class = "DEATHKNIGHT", level = 10, },
	[49576]={ class = "DEATHKNIGHT", level = 10, },
	[53428]={ class = "DEATHKNIGHT", level = 10, },
	[48778]={ class = "DEATHKNIGHT", level = 10, },
	[53343]={ class = "DEATHKNIGHT", level = 10, },
	[50401]={ class = "DEATHKNIGHT", level = 10, },
	[53344]={ class = "DEATHKNIGHT", level = 10, },
	[53365]={ class = "DEATHKNIGHT", level = 10, },
	[62158]={ class = "DEATHKNIGHT", level = 10, },
	[48265]={ class = "DEATHKNIGHT", level = 10, },
	[49039]={ class = "DEATHKNIGHT", level = 10, },
	[127344]={ class = "DEATHKNIGHT", level = 10, },
	[50977]={ class = "DEATHKNIGHT", level = 10, },
	[61999]={ class = "DEATHKNIGHT", level = 19, },
	[326977]={ class = "DEATHKNIGHT", level = 20, },
	[51986]={ class = "DEATHKNIGHT", level = 22, },
	[326805]={ class = "DEATHKNIGHT", level = 32, },
	[327082]={ class = "DEATHKNIGHT", level = 44, },
	[326911]={ class = "DEATHKNIGHT", level = 46, },
	[326855]={ class = "DEATHKNIGHT", level = 48, },
	[343257]={ class = "DEATHKNIGHT", level = 49, },
--++ Death Knight Artifact Traits ++	
	[192464]={ class = "DEATHKNIGHT", level = 40, },
	[189092]={ class = "DEATHKNIGHT", level = 40, },
	[220143]={ class = "DEATHKNIGHT", level = 40, },
	[191731]={ class = "DEATHKNIGHT", level = 40, },
	[189147]={ class = "DEATHKNIGHT", level = 40, },
	[238116]={ class = "DEATHKNIGHT", level = 40, },
	[218931]={ class = "DEATHKNIGHT", level = 40, },
	[189086]={ class = "DEATHKNIGHT", level = 40, },
	[192548]={ class = "DEATHKNIGHT", level = 40, },
	[192538]={ class = "DEATHKNIGHT", level = 40, },
	[238042]={ class = "DEATHKNIGHT", level = 40, },
	[205209]={ class = "DEATHKNIGHT", level = 40, },
	[192460]={ class = "DEATHKNIGHT", level = 40, },
	[189080]={ class = "DEATHKNIGHT", level = 40, },
	[205223]={ class = "DEATHKNIGHT", level = 40, },
	[205224]={ class = "DEATHKNIGHT", level = 40, },
	[189186]={ class = "DEATHKNIGHT", level = 40, },
	[241050]={ class = "DEATHKNIGHT", level = 40, },
	[192514]={ class = "DEATHKNIGHT", level = 40, },
	[189164]={ class = "DEATHKNIGHT", level = 40, },
	[191419]={ class = "DEATHKNIGHT", level = 40, },
	[191565]={ class = "DEATHKNIGHT", level = 40, },
	[238080]={ class = "DEATHKNIGHT", level = 40, },
	[191741]={ class = "DEATHKNIGHT", level = 40, },
	[208598]={ class = "DEATHKNIGHT", level = 40, },
	[218280]={ class = "DEATHKNIGHT", level = 40, },
	[241047]={ class = "DEATHKNIGHT", level = 40, },
	[214906]={ class = "DEATHKNIGHT", level = 40, },
	[241018]={ class = "DEATHKNIGHT", level = 40, },
	[189179]={ class = "DEATHKNIGHT", level = 40, },
	[204875]={ class = "DEATHKNIGHT", level = 40, },
	[189184]={ class = "DEATHKNIGHT", level = 40, },
	[191721]={ class = "DEATHKNIGHT", level = 40, },
	[192447]={ class = "DEATHKNIGHT", level = 40, },
	[189185]={ class = "DEATHKNIGHT", level = 40, },
	[189154]={ class = "DEATHKNIGHT", level = 40, },
	[192450]={ class = "DEATHKNIGHT", level = 40, },
	[238044]={ class = "DEATHKNIGHT", level = 40, },
	[192453]={ class = "DEATHKNIGHT", level = 40, },
	[189180]={ class = "DEATHKNIGHT", level = 40, },
	[192570]={ class = "DEATHKNIGHT", level = 40, },
	[189144]={ class = "DEATHKNIGHT", level = 40, },
	[189097]={ class = "DEATHKNIGHT", level = 40, },
	[191485]={ class = "DEATHKNIGHT", level = 40, },
	[191637]={ class = "DEATHKNIGHT", level = 40, },
	[192557]={ class = "DEATHKNIGHT", level = 40, },
	[191442]={ class = "DEATHKNIGHT", level = 40, },
	[238043]={ class = "DEATHKNIGHT", level = 40, },
	[238079]={ class = "DEATHKNIGHT", level = 40, },
	[191592]={ class = "DEATHKNIGHT", level = 40, },
	[191593]={ class = "DEATHKNIGHT", level = 40, },
	[191594]={ class = "DEATHKNIGHT", level = 40, },
	[224466]={ class = "DEATHKNIGHT", level = 40, },
	[224467]={ class = "DEATHKNIGHT", level = 40, },
	[224468]={ class = "DEATHKNIGHT", level = 40, },
	[239106]={ class = "DEATHKNIGHT", level = 40, },
	[239107]={ class = "DEATHKNIGHT", level = 40, },
	[221775]={ class = "DEATHKNIGHT", level = 40, },
	[191747]={ class = "DEATHKNIGHT", level = 40, },
	[191494]={ class = "DEATHKNIGHT", level = 40, },
	[190778]={ class = "DEATHKNIGHT", level = 40, },
	[192558]={ class = "DEATHKNIGHT", level = 40, },
	[214904]={ class = "DEATHKNIGHT", level = 40, },
	[238114]={ class = "DEATHKNIGHT", level = 40, },
	[191488]={ class = "DEATHKNIGHT", level = 40, },
	[214903]={ class = "DEATHKNIGHT", level = 40, },
	[191760]={ class = "DEATHKNIGHT", level = 40, },
	[238115]={ class = "DEATHKNIGHT", level = 40, },
	[193213]={ class = "DEATHKNIGHT", level = 40, },
	[192567]={ class = "DEATHKNIGHT", level = 40, },
	[191584]={ class = "DEATHKNIGHT", level = 40, },
	[238078]={ class = "DEATHKNIGHT", level = 40, },
	[192542]={ class = "DEATHKNIGHT", level = 40, },
	[192543]={ class = "DEATHKNIGHT", level = 40, },
	[192544]={ class = "DEATHKNIGHT", level = 40, },
	[208793]={ class = "DEATHKNIGHT", level = 40, },
	[208794]={ class = "DEATHKNIGHT", level = 40, },
	[208795]={ class = "DEATHKNIGHT", level = 40, },
	[238686]={ class = "DEATHKNIGHT", level = 40, },
	[238687]={ class = "DEATHKNIGHT", level = 40, },
	[192457]={ class = "DEATHKNIGHT", level = 40, },
--++ Death Knight Azerite Traits ++	
	[289339]={ class = "DEATHKNIGHT", level = 45, },
	[289347]={ class = "DEATHKNIGHT", level = 45, },
	[273088]={ class = "DEATHKNIGHT", level = 45, },
	[278484]={ class = "DEATHKNIGHT", level = 45, },
	[279502]={ class = "DEATHKNIGHT", level = 45, },
	[279503]={ class = "DEATHKNIGHT", level = 45, },
	[278482]={ class = "DEATHKNIGHT", level = 45, },
	[288424]={ class = "DEATHKNIGHT", level = 45, },
	[288425]={ class = "DEATHKNIGHT", level = 45, },
	[288426]={ class = "DEATHKNIGHT", level = 45, },
	[265145]={ class = "DEATHKNIGHT", level = 45, },
	[272684]={ class = "DEATHKNIGHT", level = 45, },
	[275917]={ class = "DEATHKNIGHT", level = 45, },
	[278479]={ class = "DEATHKNIGHT", level = 45, },
	[278534]={ class = "DEATHKNIGHT", level = 45, },
	[278543]={ class = "DEATHKNIGHT", level = 45, },
	[274081]={ class = "DEATHKNIGHT", level = 45, },
	[274373]={ class = "DEATHKNIGHT", level = 45, },
	[287283]={ class = "DEATHKNIGHT", level = 45, },
	[287303]={ class = "DEATHKNIGHT", level = 45, },
	[287321]={ class = "DEATHKNIGHT", level = 45, },
	[278487]={ class = "DEATHKNIGHT", level = 45, },
	[275929]={ class = "DEATHKNIGHT", level = 45, },
	[275930]={ class = "DEATHKNIGHT", level = 45, },
	[275931]={ class = "DEATHKNIGHT", level = 45, },
	[286832]={ class = "DEATHKNIGHT", level = 45, },
	[286834]={ class = "DEATHKNIGHT", level = 45, },
	[286835]={ class = "DEATHKNIGHT", level = 45, },
	[286836]={ class = "DEATHKNIGHT", level = 45, },
	[286978]={ class = "DEATHKNIGHT", level = 45, },
	[286979]={ class = "DEATHKNIGHT", level = 45, },
	[272718]={ class = "DEATHKNIGHT", level = 45, },
	[272719]={ class = "DEATHKNIGHT", level = 45, },
	[272721]={ class = "DEATHKNIGHT", level = 45, },
	[278480]={ class = "DEATHKNIGHT", level = 45, },
	[278603]={ class = "DEATHKNIGHT", level = 45, },
	[278489]={ class = "DEATHKNIGHT", level = 45, },
	[273093]={ class = "DEATHKNIGHT", level = 45, },
	[288417]={ class = "DEATHKNIGHT", level = 45, },
	[288544]={ class = "DEATHKNIGHT", level = 45, },
	[280011]={ class = "DEATHKNIGHT", level = 45, },
	[280143]={ class = "DEATHKNIGHT", level = 45, },
	[274057]={ class = "DEATHKNIGHT", level = 45, },
	[280010]={ class = "DEATHKNIGHT", level = 45, },
	[280132]={ class = "DEATHKNIGHT", level = 45, },
	[265147]={ class = "DEATHKNIGHT", level = 45, },
	[269357]={ class = "DEATHKNIGHT", level = 45, },
--++ Death Knight Covenant Abilities ++	
	[311730]={ class = "DEATHKNIGHT", level = 49, },
	[324128]={ class = "DEATHKNIGHT", level = 48, },
	[324165]={ class = "DEATHKNIGHT", level = 48, },
	[341340]={ class = "DEATHKNIGHT", level = 48, },
--++ Death Knight Conduit Abilities ++	
	[337822]={ class = "DEATHKNIGHT", level = 60, },
	[337957]={ class = "DEATHKNIGHT", level = 60, },
	[338651]={ class = "DEATHKNIGHT", level = 60, },
	[337704]={ class = "DEATHKNIGHT", level = 60, },
	[338553]={ class = "DEATHKNIGHT", level = 60, },
	[338516]={ class = "DEATHKNIGHT", level = 60, },
	[337980]={ class = "DEATHKNIGHT", level = 60, },
	[337934]={ class = "DEATHKNIGHT", level = 60, },
	[337381]={ class = "DEATHKNIGHT", level = 60, },
	[337988]={ class = "DEATHKNIGHT", level = 60, },
	[338089]={ class = "DEATHKNIGHT", level = 60, },
	[337972]={ class = "DEATHKNIGHT", level = 60, },
	[338628]={ class = "DEATHKNIGHT", level = 60, },
	[338330]={ class = "DEATHKNIGHT", level = 60, },
	[338566]={ class = "DEATHKNIGHT", level = 60, },
	[338435]={ class = "DEATHKNIGHT", level = 60, },
	[338664]={ class = "DEATHKNIGHT", level = 60, },
	[337764]={ class = "DEATHKNIGHT", level = 60, },
	[337705]={ class = "DEATHKNIGHT", level = 60, },
	[338311]={ class = "DEATHKNIGHT", level = 60, },
	[338492]={ class = "DEATHKNIGHT", level = 60, },
	[338501]={ class = "DEATHKNIGHT", level = 60, },
	[341344]={ class = "DEATHKNIGHT", level = 60, },
	[337884]={ class = "DEATHKNIGHT", level = 60, },
--++ Death Knight Specializations ++	
	[137008]={ class = "DEATHKNIGHT", level = 10, },
	[674]={ class = "DEATHKNIGHT", level = 10, },
	[137006]={ class = "DEATHKNIGHT", level = 10, },
	[137007]={ class = "DEATHKNIGHT", level = 10, },
	[77513]={ class = "DEATHKNIGHT", level = 10, },
	[77515]={ class = "DEATHKNIGHT", level = 10, },
	[77514]={ class = "DEATHKNIGHT", level = 10, },
	[374721]={ class = "DEATHKNIGHT", level = 11, },
	[51462]={ class = "DEATHKNIGHT", level = 11, },
	[81229]={ class = "DEATHKNIGHT", level = 11, },
	[178819]={ class = "DEATHKNIGHT", level = 18, },
	[195621]={ class = "DEATHKNIGHT", level = 23, },
	[86113]={ class = "DEATHKNIGHT", level = 27, },
	[86536]={ class = "DEATHKNIGHT", level = 27, },
	[86537]={ class = "DEATHKNIGHT", level = 27, },
	[161797]={ class = "DEATHKNIGHT", level = 29, },
	[325554]={ class = "DEATHKNIGHT", level = 52, },
--++ Death Knight Talents ++	
	[48707]={ class = "DEATHKNIGHT", level = 10, },
	[316916]={ class = "DEATHKNIGHT", level = 10, },
	[49998]={ class = "DEATHKNIGHT", level = 10, },
	[47528]={ class = "DEATHKNIGHT", level = 10, },
	[85948]={ class = "DEATHKNIGHT", level = 11, },
	[49143]={ class = "DEATHKNIGHT", level = 11, },
	[205727]={ class = "DEATHKNIGHT", level = 12, },
	[378848]={ class = "DEATHKNIGHT", level = 12, },
	[111673]={ class = "DEATHKNIGHT", level = 12, },
	[392566]={ class = "DEATHKNIGHT", level = 12, },
	[48792]={ class = "DEATHKNIGHT", level = 12, },
	[374277]={ class = "DEATHKNIGHT", level = 12, },
	[391546]={ class = "DEATHKNIGHT", level = 12, },
	[46585]={ class = "DEATHKNIGHT", level = 12, },
	[327574]={ class = "DEATHKNIGHT", level = 12, },
	[50842]={ class = "DEATHKNIGHT", level = 13, },
	[49184]={ class = "DEATHKNIGHT", level = 13, },
	[195182]={ class = "DEATHKNIGHT", level = 13, },
	[49020]={ class = "DEATHKNIGHT", level = 13, },
	[46584]={ class = "DEATHKNIGHT", level = 13, },
	[55090]={ class = "DEATHKNIGHT", level = 13, },
	[374030]={ class = "DEATHKNIGHT", level = 14, },
	[374504]={ class = "DEATHKNIGHT", level = 14, },
	[207200]={ class = "DEATHKNIGHT", level = 14, },
	[374049]={ class = "DEATHKNIGHT", level = 14, },
	[48263]={ class = "DEATHKNIGHT", level = 14, },
	[81136]={ class = "DEATHKNIGHT", level = 15, },
	[63560]={ class = "DEATHKNIGHT", level = 15, },
	[51128]={ class = "DEATHKNIGHT", level = 15, },
	[77575]={ class = "DEATHKNIGHT", level = 15, },
	[59057]={ class = "DEATHKNIGHT", level = 15, },
	[55233]={ class = "DEATHKNIGHT", level = 15, },
	[316714]={ class = "DEATHKNIGHT", level = 16, },
	[195292]={ class = "DEATHKNIGHT", level = 17, },
	[316867]={ class = "DEATHKNIGHT", level = 17, },
	[316803]={ class = "DEATHKNIGHT", level = 17, },
	[374717]={ class = "DEATHKNIGHT", level = 17, },
	[317133]={ class = "DEATHKNIGHT", level = 17, },
	[207272]={ class = "DEATHKNIGHT", level = 17, },
	[219786]={ class = "DEATHKNIGHT", level = 17, },
	[376251]={ class = "DEATHKNIGHT", level = 17, },
	[390166]={ class = "DEATHKNIGHT", level = 17, },
	[115989]={ class = "DEATHKNIGHT", level = 17, },
	[376905]={ class = "DEATHKNIGHT", level = 17, },
	[373926]={ class = "DEATHKNIGHT", level = 26, },
	[51052]={ class = "DEATHKNIGHT", level = 26, },
	[389679]={ class = "DEATHKNIGHT", level = 26, },
	[373923]={ class = "DEATHKNIGHT", level = 26, },
	[374111]={ class = "DEATHKNIGHT", level = 26, },
	[194916]={ class = "DEATHKNIGHT", level = 27, },
	[275699]={ class = "DEATHKNIGHT", level = 27, },
	[207311]={ class = "DEATHKNIGHT", level = 27, },
	[49028]={ class = "DEATHKNIGHT", level = 27, },
	[207317]={ class = "DEATHKNIGHT", level = 27, },
	[390161]={ class = "DEATHKNIGHT", level = 27, },
	[206974]={ class = "DEATHKNIGHT", level = 27, },
	[207230]={ class = "DEATHKNIGHT", level = 27, },
	[194913]={ class = "DEATHKNIGHT", level = 27, },
	[221536]={ class = "DEATHKNIGHT", level = 27, },
	[273946]={ class = "DEATHKNIGHT", level = 27, },
	[317198]={ class = "DEATHKNIGHT", level = 27, },
	[316838]={ class = "DEATHKNIGHT", level = 27, },
	[374747]={ class = "DEATHKNIGHT", level = 27, },
	[51271]={ class = "DEATHKNIGHT", level = 27, },
	[390175]={ class = "DEATHKNIGHT", level = 27, },
	[317610]={ class = "DEATHKNIGHT", level = 27, },
	[377585]={ class = "DEATHKNIGHT", level = 27, },
	[194679]={ class = "DEATHKNIGHT", level = 27, },
	[49530]={ class = "DEATHKNIGHT", level = 27, },
	[374383]={ class = "DEATHKNIGHT", level = 28, },
	[48743]={ class = "DEATHKNIGHT", level = 28, },
	[276079]={ class = "DEATHKNIGHT", level = 28, },
	[391571]={ class = "DEATHKNIGHT", level = 28, },
	[273952]={ class = "DEATHKNIGHT", level = 28, },
	[373930]={ class = "DEATHKNIGHT", level = 28, },
	[389682]={ class = "DEATHKNIGHT", level = 28, },
	[377056]={ class = "DEATHKNIGHT", level = 29, },
	[206931]={ class = "DEATHKNIGHT", level = 29, },
	[207264]={ class = "DEATHKNIGHT", level = 29, },
	[305392]={ class = "DEATHKNIGHT", level = 29, },
	[281208]={ class = "DEATHKNIGHT", level = 29, },
	[274156]={ class = "DEATHKNIGHT", level = 29, },
	[152280]={ class = "DEATHKNIGHT", level = 29, },
	[207269]={ class = "DEATHKNIGHT", level = 29, },
	[377190]={ class = "DEATHKNIGHT", level = 29, },
	[377073]={ class = "DEATHKNIGHT", level = 29, },
	[317214]={ class = "DEATHKNIGHT", level = 29, },
	[377226]={ class = "DEATHKNIGHT", level = 29, },
	[57330]={ class = "DEATHKNIGHT", level = 29, },
	[374715]={ class = "DEATHKNIGHT", level = 29, },
	[377580]={ class = "DEATHKNIGHT", level = 29, },
	[377637]={ class = "DEATHKNIGHT", level = 29, },
	[377629]={ class = "DEATHKNIGHT", level = 29, },
	[390196]={ class = "DEATHKNIGHT", level = 29, },
	[194917]={ class = "DEATHKNIGHT", level = 29, },
	[377076]={ class = "DEATHKNIGHT", level = 29, },
	[194662]={ class = "DEATHKNIGHT", level = 29, },
	[390275]={ class = "DEATHKNIGHT", level = 29, },
	[390236]={ class = "DEATHKNIGHT", level = 29, },
	[316941]={ class = "DEATHKNIGHT", level = 29, },
	[319230]={ class = "DEATHKNIGHT", level = 29, },
	[207104]={ class = "DEATHKNIGHT", level = 30, },
	[374265]={ class = "DEATHKNIGHT", level = 30, },
	[212552]={ class = "DEATHKNIGHT", level = 30, },
	[391386]={ class = "DEATHKNIGHT", level = 31, },
	[221699]={ class = "DEATHKNIGHT", level = 31, },
	[195679]={ class = "DEATHKNIGHT", level = 31, },
	[391477]={ class = "DEATHKNIGHT", level = 31, },
	[392963]={ class = "DEATHKNIGHT", level = 31, },
	[377376]={ class = "DEATHKNIGHT", level = 31, },
	[377668]={ class = "DEATHKNIGHT", level = 31, },
	[194912]={ class = "DEATHKNIGHT", level = 31, },
	[276023]={ class = "DEATHKNIGHT", level = 31, },
	[253593]={ class = "DEATHKNIGHT", level = 31, },
	[207061]={ class = "DEATHKNIGHT", level = 31, },
	[277234]={ class = "DEATHKNIGHT", level = 31, },
	[377351]={ class = "DEATHKNIGHT", level = 31, },
	[377514]={ class = "DEATHKNIGHT", level = 31, },
	[374737]={ class = "DEATHKNIGHT", level = 31, },
	[390279]={ class = "DEATHKNIGHT", level = 31, },
	[273953]={ class = "DEATHKNIGHT", level = 31, },
	[390270]={ class = "DEATHKNIGHT", level = 33, },
	[390268]={ class = "DEATHKNIGHT", level = 33, },
	[207126]={ class = "DEATHKNIGHT", level = 33, },
	[374598]={ class = "DEATHKNIGHT", level = 50, },
	[356367]={ class = "DEATHKNIGHT", level = 50, },
	[391566]={ class = "DEATHKNIGHT", level = 50, },
	[206967]={ class = "DEATHKNIGHT", level = 50, },
	[42650]={ class = "DEATHKNIGHT", level = 51, },
	[207142]={ class = "DEATHKNIGHT", level = 51, },
	[377098]={ class = "DEATHKNIGHT", level = 51, },
	[377537]={ class = "DEATHKNIGHT", level = 51, },
	[376938]={ class = "DEATHKNIGHT", level = 51, },
	[108199]={ class = "DEATHKNIGHT", level = 51, },
	[392950]={ class = "DEATHKNIGHT", level = 51, },
	[81333]={ class = "DEATHKNIGHT", level = 51, },
	[391458]={ class = "DEATHKNIGHT", level = 51, },
	[207057]={ class = "DEATHKNIGHT", level = 51, },
	[49206]={ class = "DEATHKNIGHT", level = 51, },
	[219809]={ class = "DEATHKNIGHT", level = 51, },
	[194878]={ class = "DEATHKNIGHT", level = 52, },
	[374261]={ class = "DEATHKNIGHT", level = 52, },
	[276837]={ class = "DEATHKNIGHT", level = 53, },
	[377590]={ class = "DEATHKNIGHT", level = 53, },
	[279302]={ class = "DEATHKNIGHT", level = 53, },
	[377587]={ class = "DEATHKNIGHT", level = 53, },
	[377655]={ class = "DEATHKNIGHT", level = 53, },
	[391395]={ class = "DEATHKNIGHT", level = 53, },
	[377592]={ class = "DEATHKNIGHT", level = 53, },
	[205723]={ class = "DEATHKNIGHT", level = 53, },
	[377640]={ class = "DEATHKNIGHT", level = 53, },
	[206970]={ class = "DEATHKNIGHT", level = 53, },
	[377440]={ class = "DEATHKNIGHT", level = 53, },
	[374574]={ class = "DEATHKNIGHT", level = 54, },
	[377047]={ class = "DEATHKNIGHT", level = 55, },
	[391398]={ class = "DEATHKNIGHT", level = 55, },
	[377083]={ class = "DEATHKNIGHT", level = 55, },
	[377092]={ class = "DEATHKNIGHT", level = 55, },
	[114556]={ class = "DEATHKNIGHT", level = 55, },
	[392962]={ class = "DEATHKNIGHT", level = 56, },
	[390259]={ class = "DEATHKNIGHT", level = 57, },
	[390283]={ class = "DEATHKNIGHT", level = 57, },
	[391517]={ class = "DEATHKNIGHT", level = 57, },
	[207289]={ class = "DEATHKNIGHT", level = 57, },
	[152279]={ class = "DEATHKNIGHT", level = 59, },
	[281238]={ class = "DEATHKNIGHT", level = 59, },
--++ Death Knight PvP Talents ++	
	[356456]={ class = "DEATHKNIGHT", level = 20, },
	[77606]={ class = "DEATHKNIGHT", level = 20, },
	[287250]={ class = "DEATHKNIGHT", level = 20, },
	[204080]={ class = "DEATHKNIGHT", level = 20, },
	[233396]={ class = "DEATHKNIGHT", level = 20, },
	[288855]={ class = "DEATHKNIGHT", level = 20, },
	[207018]={ class = "DEATHKNIGHT", level = 20, },
	[210128]={ class = "DEATHKNIGHT", level = 20, },
	[202727]={ class = "DEATHKNIGHT", level = 20, },
	[202731]={ class = "DEATHKNIGHT", level = 20, },
	[288848]={ class = "DEATHKNIGHT", level = 29, },
	[356470]={ class = "DEATHKNIGHT", level = 30, },
	[356520]={ class = "DEATHKNIGHT", level = 30, },
	[356512]={ class = "DEATHKNIGHT", level = 35, },
	[233412]={ class = "DEATHKNIGHT", level = 35, },
	[288853]={ class = "DEATHKNIGHT", level = 45, },
	[356332]={ class = "DEATHKNIGHT", level = 48, },
	[199719]={ class = "DEATHKNIGHT", level = 50, },
--++ Demon Hunter Abilities ++	
	[344862]={ class = "DEMONHUNTER", level = 8, },
	[193840]={ class = "DEMONHUNTER", level = 8, },
	[344859]={ class = "DEMONHUNTER", level = 8, },
	[196055]={ class = "DEMONHUNTER", level = 8, },
	[344865]={ class = "DEMONHUNTER", level = 8, },
	[131347]={ class = "DEMONHUNTER", level = 8, },
	[214743]={ class = "DEMONHUNTER", level = 8, },
	[188501]={ class = "DEMONHUNTER", level = 8, },
	[221351]={ class = "DEMONHUNTER", level = 8, },
	[203724]={ class = "DEMONHUNTER", level = 8, },
	[258922]={ class = "DEMONHUNTER", level = 14, },
	[185123]={ class = "DEMONHUNTER", level = 16, },
	[320364]={ class = "DEMONHUNTER", level = 18, },
	[183752]={ class = "DEMONHUNTER", level = 20, },
	[191427]={ class = "DEMONHUNTER", level = 20, },
	[320379]={ class = "DEMONHUNTER", level = 42, },
	[255260]={ class = "DEMONHUNTER", level = 49, },
--++ Demon Hunter Artifact Traits ++	
	[207343]={ class = "DEMONHUNTER", level = 40, },
	[201473]={ class = "DEMONHUNTER", level = 40, },
	[201470]={ class = "DEMONHUNTER", level = 40, },
	[243188]={ class = "DEMONHUNTER", level = 40, },
	[214907]={ class = "DEMONHUNTER", level = 40, },
	[201456]={ class = "DEMONHUNTER", level = 40, },
	[238117]={ class = "DEMONHUNTER", level = 40, },
	[201454]={ class = "DEMONHUNTER", level = 40, },
	[201455]={ class = "DEMONHUNTER", level = 40, },
	[201463]={ class = "DEMONHUNTER", level = 40, },
	[212829]={ class = "DEMONHUNTER", level = 40, },
	[201458]={ class = "DEMONHUNTER", level = 40, },
	[201469]={ class = "DEMONHUNTER", level = 40, },
	[212894]={ class = "DEMONHUNTER", level = 40, },
	[212821]={ class = "DEMONHUNTER", level = 40, },
	[212816]={ class = "DEMONHUNTER", level = 40, },
	[238082]={ class = "DEMONHUNTER", level = 40, },
	[201468]={ class = "DEMONHUNTER", level = 40, },
	[212817]={ class = "DEMONHUNTER", level = 40, },
	[238118]={ class = "DEMONHUNTER", level = 40, },
	[213017]={ class = "DEMONHUNTER", level = 40, },
	[201467]={ class = "DEMONHUNTER", level = 40, },
	[207352]={ class = "DEMONHUNTER", level = 40, },
	[241091]={ class = "DEMONHUNTER", level = 40, },
	[241090]={ class = "DEMONHUNTER", level = 40, },
	[201459]={ class = "DEMONHUNTER", level = 40, },
	[207375]={ class = "DEMONHUNTER", level = 40, },
	[201471]={ class = "DEMONHUNTER", level = 40, },
	[238046]={ class = "DEMONHUNTER", level = 40, },
	[201464]={ class = "DEMONHUNTER", level = 40, },
	[201472]={ class = "DEMONHUNTER", level = 40, },
	[201457]={ class = "DEMONHUNTER", level = 40, },
	[212827]={ class = "DEMONHUNTER", level = 40, },
	[218910]={ class = "DEMONHUNTER", level = 40, },
	[214909]={ class = "DEMONHUNTER", level = 40, },
	[214744]={ class = "DEMONHUNTER", level = 40, },
	[201460]={ class = "DEMONHUNTER", level = 40, },
	[214795]={ class = "DEMONHUNTER", level = 40, },
	[238045]={ class = "DEMONHUNTER", level = 40, },
	[212819]={ class = "DEMONHUNTER", level = 40, },
--++ Demon Hunter Azerite Traits ++	
	[288754]={ class = "DEMONHUNTER", level = 45, },
	[278502]={ class = "DEMONHUNTER", level = 45, },
	[278766]={ class = "DEMONHUNTER", level = 45, },
	[278769]={ class = "DEMONHUNTER", level = 45, },
	[278501]={ class = "DEMONHUNTER", level = 45, },
	[279449]={ class = "DEMONHUNTER", level = 45, },
	[279450]={ class = "DEMONHUNTER", level = 45, },
	[278500]={ class = "DEMONHUNTER", level = 45, },
	[279442]={ class = "DEMONHUNTER", level = 45, },
	[273231]={ class = "DEMONHUNTER", level = 45, },
	[273232]={ class = "DEMONHUNTER", level = 45, },
	[288878]={ class = "DEMONHUNTER", level = 45, },
	[288880]={ class = "DEMONHUNTER", level = 45, },
	[288882]={ class = "DEMONHUNTER", level = 45, },
	[273236]={ class = "DEMONHUNTER", level = 45, },
	[273237]={ class = "DEMONHUNTER", level = 45, },
	[273239]={ class = "DEMONHUNTER", level = 45, },
	[272983]={ class = "DEMONHUNTER", level = 45, },
	[272985]={ class = "DEMONHUNTER", level = 45, },
	[272986]={ class = "DEMONHUNTER", level = 45, },
	[279581]={ class = "DEMONHUNTER", level = 45, },
	[279582]={ class = "DEMONHUNTER", level = 45, },
	[279584]={ class = "DEMONHUNTER", level = 45, },
	[275350]={ class = "DEMONHUNTER", level = 45, },
	[275934]={ class = "DEMONHUNTER", level = 45, },
	[275935]={ class = "DEMONHUNTER", level = 45, },
	[274345]={ class = "DEMONHUNTER", level = 45, },
	[278493]={ class = "DEMONHUNTER", level = 45, },
	[278736]={ class = "DEMONHUNTER", level = 45, },
	[288973]={ class = "DEMONHUNTER", level = 45, },
	[288997]={ class = "DEMONHUNTER", level = 45, },
--++ Demon Hunter Covenant Abilities ++	
	[306830]={ class = "DEMONHUNTER", level = 48, },
	[317075]={ class = "DEMONHUNTER", level = 48, },
	[317076]={ class = "DEMONHUNTER", level = 48, },
	[337044]={ class = "DEMONHUNTER", level = 48, },
	[350570]={ class = "DEMONHUNTER", level = 48, },
	[323639]={ class = "DEMONHUNTER", level = 48, },
--++ Demon Hunter Conduit Abilities ++	
	[340063]={ class = "DEMONHUNTER", level = 60, },
	[339228]={ class = "DEMONHUNTER", level = 60, },
	[339587]={ class = "DEMONHUNTER", level = 60, },
	[339048]={ class = "DEMONHUNTER", level = 60, },
	[338671]={ class = "DEMONHUNTER", level = 60, },
	[338799]={ class = "DEMONHUNTER", level = 60, },
	[339231]={ class = "DEMONHUNTER", level = 60, },
	[340028]={ class = "DEMONHUNTER", level = 60, },
	[339149]={ class = "DEMONHUNTER", level = 60, },
	[338835]={ class = "DEMONHUNTER", level = 60, },
	[339151]={ class = "DEMONHUNTER", level = 60, },
	[339895]={ class = "DEMONHUNTER", level = 60, },
	[339644]={ class = "DEMONHUNTER", level = 60, },
	[339230]={ class = "DEMONHUNTER", level = 60, },
	[338793]={ class = "DEMONHUNTER", level = 60, },
	[339423]={ class = "DEMONHUNTER", level = 60, },
	[344358]={ class = "DEMONHUNTER", level = 60, },
	[338682]={ class = "DEMONHUNTER", level = 60, },
--++ Demon Hunter Specializations ++	
	[162794]={ class = "DEMONHUNTER", level = 8, },
	[162243]={ class = "DEMONHUNTER", level = 8, },
	[195072]={ class = "DEMONHUNTER", level = 8, },
	[212612]={ class = "DEMONHUNTER", level = 8, },
	[189110]={ class = "DEMONHUNTER", level = 8, },
	[187827]={ class = "DEMONHUNTER", level = 8, },
	[178940]={ class = "DEMONHUNTER", level = 8, },
	[204254]={ class = "DEMONHUNTER", level = 8, },
	[203782]={ class = "DEMONHUNTER", level = 8, },
	[204157]={ class = "DEMONHUNTER", level = 8, },
	[212613]={ class = "DEMONHUNTER", level = 8, },
	[203720]={ class = "DEMONHUNTER", level = 8, },
	[203783]={ class = "DEMONHUNTER", level = 8, },
	[228477]={ class = "DEMONHUNTER", level = 8, },
	[320380]={ class = "DEMONHUNTER", level = 8, },
	[185164]={ class = "DEMONHUNTER", level = 10, },
	[203747]={ class = "DEMONHUNTER", level = 10, },
	[320794]={ class = "DEMONHUNTER", level = 10, },
	[188499]={ class = "DEMONHUNTER", level = 12, },
	[203513]={ class = "DEMONHUNTER", level = 13, },
	[278386]={ class = "DEMONHUNTER", level = 13, },
	[321021]={ class = "DEMONHUNTER", level = 14, },
	[198589]={ class = "DEMONHUNTER", level = 18, },
	[321067]={ class = "DEMONHUNTER", level = 20, },
	[320402]={ class = "DEMONHUNTER", level = 22, },
	[320639]={ class = "DEMONHUNTER", level = 23, },
	[320377]={ class = "DEMONHUNTER", level = 27, },
	[320378]={ class = "DEMONHUNTER", level = 27, },
	[178976]={ class = "DEMONHUNTER", level = 27, },
	[226359]={ class = "DEMONHUNTER", level = 27, },
	[320381]={ class = "DEMONHUNTER", level = 28, },
	[207197]={ class = "DEMONHUNTER", level = 29, },
	[320962]={ class = "DEMONHUNTER", level = 38, },
	[320382]={ class = "DEMONHUNTER", level = 43, },
	[321299]={ class = "DEMONHUNTER", level = 44, },
	[321068]={ class = "DEMONHUNTER", level = 48, },
--++ Demon Hunter Talents ++	
	[320416]={ class = "DEMONHUNTER", level = 10, },
	[389824]={ class = "DEMONHUNTER", level = 10, },
	[204596]={ class = "DEMONHUNTER", level = 10, },
	[320770]={ class = "DEMONHUNTER", level = 10, },
	[198793]={ class = "DEMONHUNTER", level = 10, },
	[198013]={ class = "DEMONHUNTER", level = 11, },
	[212084]={ class = "DEMONHUNTER", level = 11, },
	[203555]={ class = "DEMONHUNTER", level = 13, },
	[388109]={ class = "DEMONHUNTER", level = 13, },
	[204021]={ class = "DEMONHUNTER", level = 13, },
	[389958]={ class = "DEMONHUNTER", level = 13, },
	[343206]={ class = "DEMONHUNTER", level = 13, },
	[258876]={ class = "DEMONHUNTER", level = 13, },
	[320386]={ class = "DEMONHUNTER", level = 14, },
	[213010]={ class = "DEMONHUNTER", level = 14, },
	[278326]={ class = "DEMONHUNTER", level = 14, },
	[232893]={ class = "DEMONHUNTER", level = 14, },
	[389694]={ class = "DEMONHUNTER", level = 14, },
	[320361]={ class = "DEMONHUNTER", level = 14, },
	[320654]={ class = "DEMONHUNTER", level = 14, },
	[320635]={ class = "DEMONHUNTER", level = 14, },
	[320374]={ class = "DEMONHUNTER", level = 15, },
	[321028]={ class = "DEMONHUNTER", level = 15, },
	[206478]={ class = "DEMONHUNTER", level = 15, },
	[206416]={ class = "DEMONHUNTER", level = 15, },
	[393029]={ class = "DEMONHUNTER", level = 15, },
	[343017]={ class = "DEMONHUNTER", level = 15, },
	[389724]={ class = "DEMONHUNTER", level = 15, },
	[320387]={ class = "DEMONHUNTER", level = 15, },
	[207347]={ class = "DEMONHUNTER", level = 16, },
	[183782]={ class = "DEMONHUNTER", level = 16, },
	[320313]={ class = "DEMONHUNTER", level = 16, },
	[389720]={ class = "DEMONHUNTER", level = 17, },
	[320413]={ class = "DEMONHUNTER", level = 17, },
	[389978]={ class = "DEMONHUNTER", level = 17, },
	[389705]={ class = "DEMONHUNTER", level = 17, },
	[263642]={ class = "DEMONHUNTER", level = 17, },
	[328725]={ class = "DEMONHUNTER", level = 17, },
	[389729]={ class = "DEMONHUNTER", level = 17, },
	[391178]={ class = "DEMONHUNTER", level = 17, },
	[389997]={ class = "DEMONHUNTER", level = 17, },
	[202137]={ class = "DEMONHUNTER", level = 17, },
	[207666]={ class = "DEMONHUNTER", level = 26, },
	[389846]={ class = "DEMONHUNTER", level = 26, },
	[320331]={ class = "DEMONHUNTER", level = 26, },
	[389849]={ class = "DEMONHUNTER", level = 26, },
	[203556]={ class = "DEMONHUNTER", level = 26, },
	[389763]={ class = "DEMONHUNTER", level = 26, },
	[389799]={ class = "DEMONHUNTER", level = 26, },
	[320421]={ class = "DEMONHUNTER", level = 26, },
	[204909]={ class = "DEMONHUNTER", level = 26, },
	[217996]={ class = "DEMONHUNTER", level = 26, },
	[207548]={ class = "DEMONHUNTER", level = 27, },
	[320341]={ class = "DEMONHUNTER", level = 27, },
	[390213]={ class = "DEMONHUNTER", level = 27, },
	[388112]={ class = "DEMONHUNTER", level = 27, },
	[205411]={ class = "DEMONHUNTER", level = 27, },
	[389721]={ class = "DEMONHUNTER", level = 27, },
	[207697]={ class = "DEMONHUNTER", level = 27, },
	[388108]={ class = "DEMONHUNTER", level = 27, },
	[196555]={ class = "DEMONHUNTER", level = 27, },
	[202138]={ class = "DEMONHUNTER", level = 27, },
	[263648]={ class = "DEMONHUNTER", level = 27, },
	[247454]={ class = "DEMONHUNTER", level = 27, },
	[258881]={ class = "DEMONHUNTER", level = 27, },
	[207684]={ class = "DEMONHUNTER", level = 28, },
	[203550]={ class = "DEMONHUNTER", level = 29, },
	[390158]={ class = "DEMONHUNTER", level = 29, },
	[320415]={ class = "DEMONHUNTER", level = 29, },
	[343014]={ class = "DEMONHUNTER", level = 29, },
	[390154]={ class = "DEMONHUNTER", level = 29, },
	[347461]={ class = "DEMONHUNTER", level = 29, },
	[268175]={ class = "DEMONHUNTER", level = 29, },
	[320412]={ class = "DEMONHUNTER", level = 30, },
	[213410]={ class = "DEMONHUNTER", level = 30, },
	[321453]={ class = "DEMONHUNTER", level = 30, },
	[235893]={ class = "DEMONHUNTER", level = 30, },
	[389696]={ class = "DEMONHUNTER", level = 30, },
	[320418]={ class = "DEMONHUNTER", level = 30, },
	[388110]={ class = "DEMONHUNTER", level = 30, },
	[206477]={ class = "DEMONHUNTER", level = 30, },
	[389695]={ class = "DEMONHUNTER", level = 30, },
	[389715]={ class = "DEMONHUNTER", level = 31, },
	[227174]={ class = "DEMONHUNTER", level = 31, },
	[389220]={ class = "DEMONHUNTER", level = 31, },
	[207387]={ class = "DEMONHUNTER", level = 31, },
	[326853]={ class = "DEMONHUNTER", level = 31, },
	[391165]={ class = "DEMONHUNTER", level = 31, },
	[390808]={ class = "DEMONHUNTER", level = 31, },
	[391189]={ class = "DEMONHUNTER", level = 33, },
	[389708]={ class = "DEMONHUNTER", level = 33, },
	[343311]={ class = "DEMONHUNTER", level = 33, },
	[388113]={ class = "DEMONHUNTER", level = 33, },
	[389977]={ class = "DEMONHUNTER", level = 33, },
	[389688]={ class = "DEMONHUNTER", level = 33, },
	[391409]={ class = "DEMONHUNTER", level = 50, },
	[196718]={ class = "DEMONHUNTER", level = 50, },
	[393822]={ class = "DEMONHUNTER", level = 50, },
	[395446]={ class = "DEMONHUNTER", level = 50, },
	[391275]={ class = "DEMONHUNTER", level = 51, },
	[207739]={ class = "DEMONHUNTER", level = 51, },
	[389687]={ class = "DEMONHUNTER", level = 51, },
	[389718]={ class = "DEMONHUNTER", level = 51, },
	[343207]={ class = "DEMONHUNTER", level = 51, },
	[389693]={ class = "DEMONHUNTER", level = 51, },
	[206476]={ class = "DEMONHUNTER", level = 51, },
	[388107]={ class = "DEMONHUNTER", level = 51, },
	[390142]={ class = "DEMONHUNTER", level = 51, },
	[389711]={ class = "DEMONHUNTER", level = 51, },
	[393827]={ class = "DEMONHUNTER", level = 51, },
	[391397]={ class = "DEMONHUNTER", level = 52, },
	[389697]={ class = "DEMONHUNTER", level = 52, },
	[389781]={ class = "DEMONHUNTER", level = 52, },
	[389783]={ class = "DEMONHUNTER", level = 52, },
	[370965]={ class = "DEMONHUNTER", level = 52, },
	[336639]={ class = "DEMONHUNTER", level = 53, },
	[258887]={ class = "DEMONHUNTER", level = 53, },
	[390163]={ class = "DEMONHUNTER", level = 53, },
	[218612]={ class = "DEMONHUNTER", level = 53, },
	[391429]={ class = "DEMONHUNTER", level = 53, },
	[342817]={ class = "DEMONHUNTER", level = 53, },
	[388118]={ class = "DEMONHUNTER", level = 53, },
	[388106]={ class = "DEMONHUNTER", level = 53, },
	[389976]={ class = "DEMONHUNTER", level = 53, },
	[388111]={ class = "DEMONHUNTER", level = 54, },
	[389819]={ class = "DEMONHUNTER", level = 54, },
	[389811]={ class = "DEMONHUNTER", level = 54, },
	[390152]={ class = "DEMONHUNTER", level = 56, },
	[209281]={ class = "DEMONHUNTER", level = 56, },
	[388114]={ class = "DEMONHUNTER", level = 57, },
	[389732]={ class = "DEMONHUNTER", level = 57, },
	[258860]={ class = "DEMONHUNTER", level = 57, },
	[209258]={ class = "DEMONHUNTER", level = 57, },
	[388116]={ class = "DEMONHUNTER", level = 57, },
	[389985]={ class = "DEMONHUNTER", level = 57, },
--++ Demon Hunter PvP Talents ++	
	[356510]={ class = "DEMONHUNTER", level = 20, },
	[205625]={ class = "DEMONHUNTER", level = 20, },
	[205629]={ class = "DEMONHUNTER", level = 20, },
	[205626]={ class = "DEMONHUNTER", level = 20, },
	[205627]={ class = "DEMONHUNTER", level = 20, },
	[211489]={ class = "DEMONHUNTER", level = 20, },
	[207029]={ class = "DEMONHUNTER", level = 20, },
	[213480]={ class = "DEMONHUNTER", level = 20, },
	[206803]={ class = "DEMONHUNTER", level = 30, },
	[205604]={ class = "DEMONHUNTER", level = 30, },
	[205596]={ class = "DEMONHUNTER", level = 35, },
	[357419]={ class = "DEMONHUNTER", level = 40, },
	[355995]={ class = "DEMONHUNTER", level = 42, },
	[354489]={ class = "DEMONHUNTER", level = 42, },
--++ Druid Abilities ++	
	[231437]={ class = "DRUID", level = 1, },
	[137009]={ class = "DRUID", level = 1, },
	[5225]={ class = "DRUID", level = 1, },
	[5176]={ class = "DRUID", level = 1, },
	[8921]={ class = "DRUID", level = 2, },
	[768]={ class = "DRUID", level = 5, },
	[5221]={ class = "DRUID", level = 5, },
	[1850]={ class = "DRUID", level = 6, },
	[125972]={ class = "DRUID", level = 6, },
	[22568]={ class = "DRUID", level = 7, },
	[5487]={ class = "DRUID", level = 8, },
	[33917]={ class = "DRUID", level = 8, },
	[22812]={ class = "DRUID", level = 10, },
	[127757]={ class = "DRUID", level = 10, },
	[16870]={ class = "DRUID", level = 10, },
	[193753]={ class = "DRUID", level = 10, },
	[210053]={ class = "DRUID", level = 10, },
	[236716]={ class = "DRUID", level = 10, },
	[210065]={ class = "DRUID", level = 10, },
	[783]={ class = "DRUID", level = 10, },
	[77758]={ class = "DRUID", level = 11, },
	[231052]={ class = "DRUID", level = 13, },
	[5215]={ class = "DRUID", level = 13, },
	[50769]={ class = "DRUID", level = 13, },
	[326646]={ class = "DRUID", level = 14, },
	[276012]={ class = "DRUID", level = 17, },
	[20484]={ class = "DRUID", level = 19, },
	[164862]={ class = "DRUID", level = 21, },
	[18960]={ class = "DRUID", level = 22, },
	[165962]={ class = "DRUID", level = 24, },
	[276029]={ class = "DRUID", level = 30, },
	[343238]={ class = "DRUID", level = 56, },
--++ Druid Artifact Traits ++	
	[200850]={ class = "DRUID", level = 40, },
	[189754]={ class = "DRUID", level = 40, },
	[210702]={ class = "DRUID", level = 40, },
	[210579]={ class = "DRUID", level = 40, },
	[210722]={ class = "DRUID", level = 40, },
	[210590]={ class = "DRUID", level = 40, },
	[215799]={ class = "DRUID", level = 40, },
	[200414]={ class = "DRUID", level = 40, },
	[202302]={ class = "DRUID", level = 40, },
	[189744]={ class = "DRUID", level = 40, },
	[238120]={ class = "DRUID", level = 40, },
	[200515]={ class = "DRUID", level = 40, },
	[186393]={ class = "DRUID", level = 40, },
	[238119]={ class = "DRUID", level = 40, },
	[202384]={ class = "DRUID", level = 40, },
	[238122]={ class = "DRUID", level = 40, },
	[189849]={ class = "DRUID", level = 40, },
	[214508]={ class = "DRUID", level = 40, },
	[200855]={ class = "DRUID", level = 40, },
	[202464]={ class = "DRUID", level = 40, },
	[208253]={ class = "DRUID", level = 40, },
	[189760]={ class = "DRUID", level = 40, },
	[238050]={ class = "DRUID", level = 40, },
	[202445]={ class = "DRUID", level = 40, },
	[214911]={ class = "DRUID", level = 40, },
	[210631]={ class = "DRUID", level = 40, },
	[210571]={ class = "DRUID", level = 40, },
	[241100]={ class = "DRUID", level = 40, },
	[238085]={ class = "DRUID", level = 40, },
	[241101]={ class = "DRUID", level = 40, },
	[238084]={ class = "DRUID", level = 40, },
	[214913]={ class = "DRUID", level = 40, },
	[214910]={ class = "DRUID", level = 40, },
	[241102]={ class = "DRUID", level = 40, },
	[186320]={ class = "DRUID", level = 40, },
	[210638]={ class = "DRUID", level = 40, },
	[210557]={ class = "DRUID", level = 40, },
	[189757]={ class = "DRUID", level = 40, },
	[215061]={ class = "DRUID", level = 40, },
	[200409]={ class = "DRUID", level = 40, },
	[238086]={ class = "DRUID", level = 40, },
	[189772]={ class = "DRUID", level = 40, },
	[238047]={ class = "DRUID", level = 40, },
	[186372]={ class = "DRUID", level = 40, },
	[208762]={ class = "DRUID", level = 40, },
	[202940]={ class = "DRUID", level = 40, },
	[189749]={ class = "DRUID", level = 40, },
	[189787]={ class = "DRUID", level = 40, },
	[222644]={ class = "DRUID", level = 40, },
	[202767]={ class = "DRUID", level = 40, },
	[210666]={ class = "DRUID", level = 40, },
	[238121]={ class = "DRUID", level = 40, },
	[200402]={ class = "DRUID", level = 40, },
	[186396]={ class = "DRUID", level = 40, },
	[202996]={ class = "DRUID", level = 40, },
	[189870]={ class = "DRUID", level = 40, },
	[210575]={ class = "DRUID", level = 40, },
	[210650]={ class = "DRUID", level = 40, },
	[241099]={ class = "DRUID", level = 40, },
	[202890]={ class = "DRUID", level = 40, },
	[210570]={ class = "DRUID", level = 40, },
	[200395]={ class = "DRUID", level = 40, },
	[214996]={ class = "DRUID", level = 40, },
	[210663]={ class = "DRUID", level = 40, },
	[202433]={ class = "DRUID", level = 40, },
	[189768]={ class = "DRUID", level = 40, },
	[210676]={ class = "DRUID", level = 40, },
	[210637]={ class = "DRUID", level = 40, },
	[200415]={ class = "DRUID", level = 40, },
	[214736]={ class = "DRUID", level = 40, },
	[214514]={ class = "DRUID", level = 40, },
	[202426]={ class = "DRUID", level = 40, },
	[213682]={ class = "DRUID", level = 40, },
	[202466]={ class = "DRUID", level = 40, },
	[210593]={ class = "DRUID", level = 40, },
	[238048]={ class = "DRUID", level = 40, },
	[203018]={ class = "DRUID", level = 40, },
	[189857]={ class = "DRUID", level = 40, },
	[202386]={ class = "DRUID", level = 40, },
	[214912]={ class = "DRUID", level = 40, },
	[200399]={ class = "DRUID", level = 40, },
	[200440]={ class = "DRUID", level = 40, },
	[238083]={ class = "DRUID", level = 40, },
	[200400]={ class = "DRUID", level = 40, },
--++ Druid Azerite Traits ++	
	[287773]={ class = "DRUID", level = 45, },
	[287784]={ class = "DRUID", level = 45, },
	[287790]={ class = "DRUID", level = 45, },
	[274432]={ class = "DRUID", level = 45, },
	[287247]={ class = "DRUID", level = 45, },
	[279524]={ class = "DRUID", level = 45, },
	[279525]={ class = "DRUID", level = 45, },
	[289314]={ class = "DRUID", level = 45, },
	[276152]={ class = "DRUID", level = 45, },
	[276153]={ class = "DRUID", level = 45, },
	[276154]={ class = "DRUID", level = 45, },
	[287251]={ class = "DRUID", level = 45, },
	[287253]={ class = "DRUID", level = 45, },
	[278510]={ class = "DRUID", level = 45, },
	[279536]={ class = "DRUID", level = 45, },
	[279778]={ class = "DRUID", level = 45, },
	[279779]={ class = "DRUID", level = 45, },
	[278511]={ class = "DRUID", level = 45, },
	[279540]={ class = "DRUID", level = 45, },
	[279541]={ class = "DRUID", level = 45, },
	[278509]={ class = "DRUID", level = 45, },
	[279468]={ class = "DRUID", level = 45, },
	[279471]={ class = "DRUID", level = 45, },
	[278505]={ class = "DRUID", level = 45, },
	[279070]={ class = "DRUID", level = 45, },
	[276021]={ class = "DRUID", level = 45, },
	[274424]={ class = "DRUID", level = 45, },
	[274425]={ class = "DRUID", level = 45, },
	[274426]={ class = "DRUID", level = 45, },
	[279552]={ class = "DRUID", level = 45, },
	[279642]={ class = "DRUID", level = 45, },
	[279646]={ class = "DRUID", level = 45, },
	[279647]={ class = "DRUID", level = 45, },
	[269379]={ class = "DRUID", level = 45, },
	[269380]={ class = "DRUID", level = 45, },
	[270611]={ class = "DRUID", level = 45, },
	[278507]={ class = "DRUID", level = 45, },
	[273344]={ class = "DRUID", level = 45, },
	[273367]={ class = "DRUID", level = 45, },
	[273389]={ class = "DRUID", level = 45, },
	[269498]={ class = "DRUID", level = 45, },
	[272871]={ class = "DRUID", level = 45, },
	[272872]={ class = "DRUID", level = 45, },
	[287805]={ class = "DRUID", level = 45, },
	[280174]={ class = "DRUID", level = 45, },
	[275906]={ class = "DRUID", level = 45, },
	[275908]={ class = "DRUID", level = 45, },
	[275909]={ class = "DRUID", level = 45, },
	[273338]={ class = "DRUID", level = 45, },
	[273339]={ class = "DRUID", level = 45, },
	[280161]={ class = "DRUID", level = 45, },
	[278513]={ class = "DRUID", level = 45, },
	[278958]={ class = "DRUID", level = 45, },
	[279527]={ class = "DRUID", level = 45, },
--++ Druid Covenant Abilities ++	
	[323546]={ class = "DRUID", level = 48, },
	[325727]={ class = "DRUID", level = 48, },
	[323764]={ class = "DRUID", level = 48, },
--++ Druid Conduit Abilities ++	
	[341280]={ class = "DRUID", level = 60, },
	[341451]={ class = "DRUID", level = 60, },
	[340705]={ class = "DRUID", level = 60, },
	[341446]={ class = "DRUID", level = 60, },
	[341378]={ class = "DRUID", level = 60, },
	[341383]={ class = "DRUID", level = 60, },
	[341447]={ class = "DRUID", level = 60, },
	[340616]={ class = "DRUID", level = 60, },
	[340621]={ class = "DRUID", level = 60, },
	[341450]={ class = "DRUID", level = 60, },
	[340708]={ class = "DRUID", level = 60, },
	[340686]={ class = "DRUID", level = 60, },
	[340543]={ class = "DRUID", level = 60, },
	[340605]={ class = "DRUID", level = 60, },
	[340706]={ class = "DRUID", level = 60, },
	[340550]={ class = "DRUID", level = 60, },
	[340609]={ class = "DRUID", level = 60, },
	[340613]={ class = "DRUID", level = 60, },
	[340720]={ class = "DRUID", level = 60, },
	[340694]={ class = "DRUID", level = 60, },
	[340682]={ class = "DRUID", level = 60, },
	[340545]={ class = "DRUID", level = 60, },
	[340546]={ class = "DRUID", level = 60, },
	[340529]={ class = "DRUID", level = 60, },
	[340719]={ class = "DRUID", level = 60, },
	[340552]={ class = "DRUID", level = 60, },
	[340549]={ class = "DRUID", level = 60, },
	[340540]={ class = "DRUID", level = 60, },
	[340553]={ class = "DRUID", level = 60, },
--++ Druid Specializations ++	
	[137013]={ class = "DRUID", level = 1, },
	[137011]={ class = "DRUID", level = 1, },
	[137010]={ class = "DRUID", level = 1, },
	[137012]={ class = "DRUID", level = 1, },
	[157447]={ class = "DRUID", level = 1, },
	[228545]={ class = "DRUID", level = 1, },
	[190984]={ class = "DRUID", level = 1, },
	[197911]={ class = "DRUID", level = 10, },
	[393014]={ class = "DRUID", level = 10, },
	[77495]={ class = "DRUID", level = 10, },
	[155783]={ class = "DRUID", level = 10, },
	[77493]={ class = "DRUID", level = 10, },
	[88423]={ class = "DRUID", level = 10, },
	[270100]={ class = "DRUID", level = 12, },
	[300349]={ class = "DRUID", level = 19, },
	[86093]={ class = "DRUID", level = 27, },
	[86096]={ class = "DRUID", level = 27, },
	[86097]={ class = "DRUID", level = 27, },
	[86104]={ class = "DRUID", level = 27, },
	[231042]={ class = "DRUID", level = 37, },
	[231065]={ class = "DRUID", level = 47, },
	[212040]={ class = "DRUID", level = 47, },
--++ Druid Talents ++	
	[22842]={ class = "DRUID", level = 10, },
	[327993]={ class = "DRUID", level = 10, },
	[392378]={ class = "DRUID", level = 10, },
	[24858]={ class = "DRUID", level = 10, },
	[197625]={ class = "DRUID", level = 10, },
	[1822]={ class = "DRUID", level = 10, },
	[194153]={ class = "DRUID", level = 10, },
	[197628]={ class = "DRUID", level = 10, },
	[78674]={ class = "DRUID", level = 10, },
	[197626]={ class = "DRUID", level = 10, },
	[18562]={ class = "DRUID", level = 10, },
	[213764]={ class = "DRUID", level = 10, },
	[79577]={ class = "DRUID", level = 11, },
	[6807]={ class = "DRUID", level = 11, },
	[5217]={ class = "DRUID", level = 11, },
	[231055]={ class = "DRUID", level = 11, },
	[192081]={ class = "DRUID", level = 12, },
	[108299]={ class = "DRUID", level = 12, },
	[33873]={ class = "DRUID", level = 12, },
	[106832]={ class = "DRUID", level = 12, },
	[301768]={ class = "DRUID", level = 12, },
	[210706]={ class = "DRUID", level = 13, },
	[202430]={ class = "DRUID", level = 13, },
	[132158]={ class = "DRUID", level = 13, },
	[16864]={ class = "DRUID", level = 13, },
	[113043]={ class = "DRUID", level = 13, },
	[391037]={ class = "DRUID", level = 13, },
	[285381]={ class = "DRUID", level = 13, },
	[202342]={ class = "DRUID", level = 13, },
	[191034]={ class = "DRUID", level = 13, },
	[61336]={ class = "DRUID", level = 13, },
	[145108]={ class = "DRUID", level = 13, },
	[2782]={ class = "DRUID", level = 14, },
	[327541]={ class = "DRUID", level = 15, },
	[203953]={ class = "DRUID", level = 15, },
	[155835]={ class = "DRUID", level = 15, },
	[391700]={ class = "DRUID", level = 15, },
	[392220]={ class = "DRUID", level = 15, },
	[383192]={ class = "DRUID", level = 15, },
	[328767]={ class = "DRUID", level = 15, },
	[231064]={ class = "DRUID", level = 15, },
	[231063]={ class = "DRUID", level = 15, },
	[392288]={ class = "DRUID", level = 15, },
	[382550]={ class = "DRUID", level = 15, },
	[390772]={ class = "DRUID", level = 15, },
	[202021]={ class = "DRUID", level = 15, },
	[202031]={ class = "DRUID", level = 15, },
	[343647]={ class = "DRUID", level = 15, },
	[393760]={ class = "DRUID", level = 15, },
	[383195]={ class = "DRUID", level = 15, },
	[300346]={ class = "DRUID", level = 15, },
	[207383]={ class = "DRUID", level = 17, },
	[343240]={ class = "DRUID", level = 17, },
	[205636]={ class = "DRUID", level = 17, },
	[200854]={ class = "DRUID", level = 17, },
	[231032]={ class = "DRUID", level = 17, },
	[345208]={ class = "DRUID", level = 17, },
	[377811]={ class = "DRUID", level = 17, },
	[155580]={ class = "DRUID", level = 17, },
	[50464]={ class = "DRUID", level = 17, },
	[391947]={ class = "DRUID", level = 17, },
	[383352]={ class = "DRUID", level = 17, },
	[393611]={ class = "DRUID", level = 17, },
	[392221]={ class = "DRUID", level = 17, },
	[197524]={ class = "DRUID", level = 26, },
	[131768]={ class = "DRUID", level = 26, },
	[106839]={ class = "DRUID", level = 26, },
	[16931]={ class = "DRUID", level = 26, },
	[252216]={ class = "DRUID", level = 26, },
	[102401]={ class = "DRUID", level = 26, },
	[343223]={ class = "DRUID", level = 27, },
	[145205]={ class = "DRUID", level = 27, },
	[393427]={ class = "DRUID", level = 27, },
	[384721]={ class = "DRUID", level = 27, },
	[202918]={ class = "DRUID", level = 27, },
	[383197]={ class = "DRUID", level = 27, },
	[391709]={ class = "DRUID", level = 27, },
	[393954]={ class = "DRUID", level = 27, },
	[202345]={ class = "DRUID", level = 27, },
	[393940]={ class = "DRUID", level = 27, },
	[394115]={ class = "DRUID", level = 27, },
	[384667]={ class = "DRUID", level = 27, },
	[203965]={ class = "DRUID", level = 27, },
	[384665]={ class = "DRUID", level = 27, },
	[391785]={ class = "DRUID", level = 27, },
	[279620]={ class = "DRUID", level = 27, },
	[372618]={ class = "DRUID", level = 27, },
	[393956]={ class = "DRUID", level = 27, },
	[377796]={ class = "DRUID", level = 28, },
	[202359]={ class = "DRUID", level = 29, },
	[395022]={ class = "DRUID", level = 29, },
	[200390]={ class = "DRUID", level = 29, },
	[391045]={ class = "DRUID", level = 29, },
	[392162]={ class = "DRUID", level = 29, },
	[382552]={ class = "DRUID", level = 29, },
	[328025]={ class = "DRUID", level = 29, },
	[48484]={ class = "DRUID", level = 29, },
	[197073]={ class = "DRUID", level = 29, },
	[236068]={ class = "DRUID", level = 29, },
	[16974]={ class = "DRUID", level = 29, },
	[158478]={ class = "DRUID", level = 29, },
	[197061]={ class = "DRUID", level = 29, },
	[88747]={ class = "DRUID", level = 29, },
	[385786]={ class = "DRUID", level = 30, },
	[159286]={ class = "DRUID", level = 30, },
	[2908]={ class = "DRUID", level = 30, },
	[377801]={ class = "DRUID", level = 30, },
	[132469]={ class = "DRUID", level = 30, },
	[371905]={ class = "DRUID", level = 31, },
	[384668]={ class = "DRUID", level = 31, },
	[391174]={ class = "DRUID", level = 31, },
	[202028]={ class = "DRUID", level = 31, },
	[203974]={ class = "DRUID", level = 31, },
	[377835]={ class = "DRUID", level = 31, },
	[155578]={ class = "DRUID", level = 31, },
	[392256]={ class = "DRUID", level = 31, },
	[393958]={ class = "DRUID", level = 31, },
	[390378]={ class = "DRUID", level = 31, },
	[393960]={ class = "DRUID", level = 31, },
	[391078]={ class = "DRUID", level = 31, },
	[278515]={ class = "DRUID", level = 31, },
	[392116]={ class = "DRUID", level = 31, },
	[383191]={ class = "DRUID", level = 31, },
	[393618]={ class = "DRUID", level = 31, },
	[393771]={ class = "DRUID", level = 31, },
	[114107]={ class = "DRUID", level = 31, },
	[158477]={ class = "DRUID", level = 31, },
	[391872]={ class = "DRUID", level = 31, },
	[135288]={ class = "DRUID", level = 31, },
	[382559]={ class = "DRUID", level = 31, },
	[392325]={ class = "DRUID", level = 31, },
	[371999]={ class = "DRUID", level = 31, },
	[390864]={ class = "DRUID", level = 31, },
	[231050]={ class = "DRUID", level = 32, },
	[377779]={ class = "DRUID", level = 33, },
	[377623]={ class = "DRUID", level = 33, },
	[370695]={ class = "DRUID", level = 33, },
	[378988]={ class = "DRUID", level = 50, },
	[377842]={ class = "DRUID", level = 50, },
	[319439]={ class = "DRUID", level = 51, },
	[390902]={ class = "DRUID", level = 51, },
	[386318]={ class = "DRUID", level = 51, },
	[391969]={ class = "DRUID", level = 51, },
	[391528]={ class = "DRUID", level = 51, },
	[370586]={ class = "DRUID", level = 51, },
	[197721]={ class = "DRUID", level = 51, },
	[391875]={ class = "DRUID", level = 51, },
	[392999]={ class = "DRUID", level = 51, },
	[102560]={ class = "DRUID", level = 51, },
	[394013]={ class = "DRUID", level = 51, },
	[33891]={ class = "DRUID", level = 51, },
	[391972]={ class = "DRUID", level = 51, },
	[392099]={ class = "DRUID", level = 51, },
	[203651]={ class = "DRUID", level = 51, },
	[394046]={ class = "DRUID", level = 51, },
	[372945]={ class = "DRUID", level = 51, },
	[391347]={ class = "DRUID", level = 51, },
	[238049]={ class = "DRUID", level = 51, },
	[207385]={ class = "DRUID", level = 51, },
	[391978]={ class = "DRUID", level = 51, },
	[392410]={ class = "DRUID", level = 51, },
	[377847]={ class = "DRUID", level = 52, },
	[391881]={ class = "DRUID", level = 53, },
	[394058]={ class = "DRUID", level = 53, },
	[394048]={ class = "DRUID", level = 53, },
	[392167]={ class = "DRUID", level = 53, },
	[393371]={ class = "DRUID", level = 53, },
	[394065]={ class = "DRUID", level = 53, },
	[393991]={ class = "DRUID", level = 53, },
	[392124]={ class = "DRUID", level = 53, },
	[274837]={ class = "DRUID", level = 53, },
	[102558]={ class = "DRUID", level = 53, },
	[394786]={ class = "DRUID", level = 53, },
	[392160]={ class = "DRUID", level = 53, },
	[392315]={ class = "DRUID", level = 53, },
	[326228]={ class = "DRUID", level = 53, },
	[274281]={ class = "DRUID", level = 53, },
	[274902]={ class = "DRUID", level = 53, },
	[392302]={ class = "DRUID", level = 53, },
	[391951]={ class = "DRUID", level = 53, },
	[231040]={ class = "DRUID", level = 54, },
	[391888]={ class = "DRUID", level = 55, },
	[203962]={ class = "DRUID", level = 55, },
	[372119]={ class = "DRUID", level = 55, },
	[394081]={ class = "DRUID", level = 55, },
	[203964]={ class = "DRUID", level = 55, },
	[155675]={ class = "DRUID", level = 55, },
	[102543]={ class = "DRUID", level = 55, },
	[394121]={ class = "DRUID", level = 55, },
	[392356]={ class = "DRUID", level = 55, },
	[158476]={ class = "DRUID", level = 55, },
	[394094]={ class = "DRUID", level = 55, },
	[372567]={ class = "DRUID", level = 55, },
	[392301]={ class = "DRUID", level = 55, },
	[377210]={ class = "DRUID", level = 55, },
	[393414]={ class = "DRUID", level = 55, },
	[202425]={ class = "DRUID", level = 55, },
	[288826]={ class = "DRUID", level = 56, },
	[378986]={ class = "DRUID", level = 56, },
	[108238]={ class = "DRUID", level = 56, },
	[391548]={ class = "DRUID", level = 57, },
	[204053]={ class = "DRUID", level = 57, },
	[372943]={ class = "DRUID", level = 57, },
	[319454]={ class = "DRUID", level = 58, },
--++ Druid PvP Talents ++	
	[233754]={ class = "DRUID", level = 20, },
	[200567]={ class = "DRUID", level = 20, },
	[233755]={ class = "DRUID", level = 20, },
	[202226]={ class = "DRUID", level = 20, },
	[209749]={ class = "DRUID", level = 20, },
	[236020]={ class = "DRUID", level = 20, },
	[203224]={ class = "DRUID", level = 20, },
	[236012]={ class = "DRUID", level = 20, },
	[236147]={ class = "DRUID", level = 20, },
	[209730]={ class = "DRUID", level = 20, },
	[203399]={ class = "DRUID", level = 20, },
	[202110]={ class = "DRUID", level = 20, },
	[236019]={ class = "DRUID", level = 20, },
	[201259]={ class = "DRUID", level = 20, },
	[203553]={ class = "DRUID", level = 21, },
	[203052]={ class = "DRUID", level = 21, },
	[236153]={ class = "DRUID", level = 21, },
	[247543]={ class = "DRUID", level = 23, },
	[207017]={ class = "DRUID", level = 25, },
	[228431]={ class = "DRUID", level = 27, },
	[205673]={ class = "DRUID", level = 27, },
	[236180]={ class = "DRUID", level = 30, },
	[232546]={ class = "DRUID", level = 30, },
	[236144]={ class = "DRUID", level = 30, },
	[289237]={ class = "DRUID", level = 30, },
	[209740]={ class = "DRUID", level = 30, },
	[203624]={ class = "DRUID", level = 34, },
	[356517]={ class = "DRUID", level = 34, },
	[203242]={ class = "DRUID", level = 37, },
	[353114]={ class = "DRUID", level = 39, },
	[233673]={ class = "DRUID", level = 40, },
	[202626]={ class = "DRUID", level = 40, },
	[233750]={ class = "DRUID", level = 40, },
	[213200]={ class = "DRUID", level = 43, },
	[354654]={ class = "DRUID", level = 55, },
	[354541]={ class = "DRUID", level = 55, },
--++ Evoker Abilities ++	
	[353167]={ class = "EVOKER", level = 58, },
	[362969]={ class = "EVOKER", level = 58, },
	[355913]={ class = "EVOKER", level = 58, },
	[357208]={ class = "EVOKER", level = 58, },
	[357208]={ class = "EVOKER", level = 58, },
	[358267]={ class = "EVOKER", level = 58, },
	[361469]={ class = "EVOKER", level = 58, },
	[381773]={ class = "EVOKER", level = 58, },
	[396571]={ class = "EVOKER", level = 58, },
	[361227]={ class = "EVOKER", level = 59, },
	[364342]={ class = "EVOKER", level = 60, },
--++ Evoker Covenant Abilities ++	
	[387169]={ class = "EVOKER", level = 58, },
--++ Evoker Conduit Abilities ++	
	[387222]={ class = "EVOKER", level = 60, },
	[387228]={ class = "EVOKER", level = 60, },
	[387240]={ class = "EVOKER", level = 60, },
	[387198]={ class = "EVOKER", level = 60, },
	[387227]={ class = "EVOKER", level = 60, },
	[387202]={ class = "EVOKER", level = 60, },
	[387270]={ class = "EVOKER", level = 60, },
	[387267]={ class = "EVOKER", level = 60, },
	[387225]={ class = "EVOKER", level = 60, },
	[387201]={ class = "EVOKER", level = 60, },
--++ Evoker Specializations ++	
	[356809]={ class = "EVOKER", level = 58, },
	[356816]={ class = "EVOKER", level = 58, },
	[363510]={ class = "EVOKER", level = 58, },
	[356810]={ class = "EVOKER", level = 58, },
	[362980]={ class = "EVOKER", level = 58, },
	[365261]={ class = "EVOKER", level = 58, },
	[365262]={ class = "EVOKER", level = 58, },
	[361178]={ class = "EVOKER", level = 59, },
	[360823]={ class = "EVOKER", level = 59, },
--++ Evoker Talents ++	
	[365933]={ class = "EVOKER", level = 58, },
	[369990]={ class = "EVOKER", level = 58, },
	[375797]={ class = "EVOKER", level = 58, },
	[375618]={ class = "EVOKER", level = 58, },
	[386342]={ class = "EVOKER", level = 58, },
	[376930]={ class = "EVOKER", level = 58, },
	[375721]={ class = "EVOKER", level = 58, },
	[375510]={ class = "EVOKER", level = 58, },
	[370886]={ class = "EVOKER", level = 58, },
	[375801]={ class = "EVOKER", level = 58, },
	[386283]={ class = "EVOKER", level = 58, },
	[375777]={ class = "EVOKER", level = 58, },
	[370455]={ class = "EVOKER", level = 58, },
	[375443]={ class = "EVOKER", level = 58, },
	[371832]={ class = "EVOKER", level = 58, },
	[376207]={ class = "EVOKER", level = 58, },
	[370962]={ class = "EVOKER", level = 58, },
	[376166]={ class = "EVOKER", level = 58, },
	[375088]={ class = "EVOKER", level = 58, },
	[355936]={ class = "EVOKER", level = 58, },
	[377082]={ class = "EVOKER", level = 58, },
	[376138]={ class = "EVOKER", level = 58, },
	[372233]={ class = "EVOKER", level = 58, },
	[370837]={ class = "EVOKER", level = 58, },
	[375554]={ class = "EVOKER", level = 58, },
	[376210]={ class = "EVOKER", level = 58, },
	[375722]={ class = "EVOKER", level = 58, },
	[369297]={ class = "EVOKER", level = 58, },
	[359073]={ class = "EVOKER", level = 58, },
	[359077]={ class = "EVOKER", level = 58, },
	[382411]={ class = "EVOKER", level = 58, },
	[387839]={ class = "EVOKER", level = 58, },
	[375757]={ class = "EVOKER", level = 58, },
	[370819]={ class = "EVOKER", level = 58, },
	[377100]={ class = "EVOKER", level = 58, },
	[375517]={ class = "EVOKER", level = 58, },
	[375542]={ class = "EVOKER", level = 58, },
	[369375]={ class = "EVOKER", level = 58, },
	[369846]={ class = "EVOKER", level = 58, },
	[370062]={ class = "EVOKER", level = 58, },
	[375577]={ class = "EVOKER", level = 58, },
	[368847]={ class = "EVOKER", level = 58, },
	[385696]={ class = "EVOKER", level = 58, },
	[359793]={ class = "EVOKER", level = 58, },
	[375574]={ class = "EVOKER", level = 58, },
	[386336]={ class = "EVOKER", level = 58, },
	[375783]={ class = "EVOKER", level = 58, },
	[375528]={ class = "EVOKER", level = 58, },
	[378196]={ class = "EVOKER", level = 58, },
	[376239]={ class = "EVOKER", level = 58, },
	[375725]={ class = "EVOKER", level = 58, },
	[368838]={ class = "EVOKER", level = 58, },
	[375796]={ class = "EVOKER", level = 58, },
	[371038]={ class = "EVOKER", level = 58, },
	[370781]={ class = "EVOKER", level = 58, },
	[371016]={ class = "EVOKER", level = 58, },
	[375544]={ class = "EVOKER", level = 58, },
	[375520]={ class = "EVOKER", level = 58, },
	[386405]={ class = "EVOKER", level = 58, },
	[376164]={ class = "EVOKER", level = 58, },
	[370867]={ class = "EVOKER", level = 58, },
	[376204]={ class = "EVOKER", level = 58, },
	[358385]={ class = "EVOKER", level = 58, },
	[371034]={ class = "EVOKER", level = 58, },
	[369939]={ class = "EVOKER", level = 58, },
	[371426]={ class = "EVOKER", level = 58, },
	[376179]={ class = "EVOKER", level = 58, },
	[375561]={ class = "EVOKER", level = 58, },
	[369913]={ class = "EVOKER", level = 58, },
	[376237]={ class = "EVOKER", level = 58, },
	[375406]={ class = "EVOKER", level = 58, },
	[386348]={ class = "EVOKER", level = 58, },
	[381921]={ class = "EVOKER", level = 58, },
	[374346]={ class = "EVOKER", level = 58, },
	[387761]={ class = "EVOKER", level = 58, },
	[370897]={ class = "EVOKER", level = 58, },
	[369908]={ class = "EVOKER", level = 58, },
	[370839]={ class = "EVOKER", level = 58, },
	[369909]={ class = "EVOKER", level = 58, },
	[371270]={ class = "EVOKER", level = 58, },
	[357211]={ class = "EVOKER", level = 58, },
	[351338]={ class = "EVOKER", level = 58, },
	[371806]={ class = "EVOKER", level = 58, },
	[387787]={ class = "EVOKER", level = 58, },
	[374348]={ class = "EVOKER", level = 58, },
	[371257]={ class = "EVOKER", level = 58, },
	[376236]={ class = "EVOKER", level = 58, },
	[375507]={ class = "EVOKER", level = 58, },
	[365937]={ class = "EVOKER", level = 58, },
	[376872]={ class = "EVOKER", level = 58, },
	[377086]={ class = "EVOKER", level = 58, },
	[372469]={ class = "EVOKER", level = 58, },
	[370821]={ class = "EVOKER", level = 58, },
	[370783]={ class = "EVOKER", level = 58, },
	[377099]={ class = "EVOKER", level = 58, },
	[370845]={ class = "EVOKER", level = 58, },
	[367226]={ class = "EVOKER", level = 58, },
	[376150]={ class = "EVOKER", level = 58, },
	[375556]={ class = "EVOKER", level = 58, },
	[373861]={ class = "EVOKER", level = 58, },
	[381922]={ class = "EVOKER", level = 58, },
	[371032]={ class = "EVOKER", level = 58, },
	[372527]={ class = "EVOKER", level = 58, },
	[368412]={ class = "EVOKER", level = 58, },
	[374968]={ class = "EVOKER", level = 58, },
	[376240]={ class = "EVOKER", level = 58, },
	[370553]={ class = "EVOKER", level = 58, },
	[386272]={ class = "EVOKER", level = 58, },
	[370888]={ class = "EVOKER", level = 58, },
	[376888]={ class = "EVOKER", level = 58, },
	[360995]={ class = "EVOKER", level = 58, },
	[369089]={ class = "EVOKER", level = 58, },
	[387341]={ class = "EVOKER", level = 58, },
	[373834]={ class = "EVOKER", level = 58, },
	[373270]={ class = "EVOKER", level = 58, },
	[374251]={ class = "EVOKER", level = 58, },
	[365585]={ class = "EVOKER", level = 58, },
	[362874]={ class = "EVOKER", level = 58, },
	[363916]={ class = "EVOKER", level = 58, },
	[370537]={ class = "EVOKER", level = 58, },
	[368432]={ class = "EVOKER", level = 58, },
--++ Evoker PvP Talents ++	
	[384660]={ class = "EVOKER", level = 20, },
	[384689]={ class = "EVOKER", level = 20, },
	[377509]={ class = "EVOKER", level = 20, },
	[378464]={ class = "EVOKER", level = 20, },
	[378444]={ class = "EVOKER", level = 20, },
	[378438]={ class = "EVOKER", level = 20, },
	[378437]={ class = "EVOKER", level = 20, },
--++ Hunter Abilities ++	
	[137014]={ class = "HUNTER", level = 1, },
	[272790]={ class = "HUNTER", level = 1, },
	[138430]={ class = "HUNTER", level = 35, },
	[242155]={ class = "HUNTER", level = 45, },
	[205154]={ class = "HUNTER", level = 1, },
	[229533]={ class = "HUNTER", level = 1, },
	[191043]={ class = "HUNTER", level = 1, },
	[93322]={ class = "HUNTER", level = 1, },
	[157443]={ class = "HUNTER", level = 1, },
	[56641]={ class = "HUNTER", level = 1, },
	[185358]={ class = "HUNTER", level = 2, },
	[781]={ class = "HUNTER", level = 4, },
	[1494]={ class = "HUNTER", level = 4, },
	[19878]={ class = "HUNTER", level = 4, },
	[19879]={ class = "HUNTER", level = 4, },
	[19880]={ class = "HUNTER", level = 4, },
	[19882]={ class = "HUNTER", level = 4, },
	[19885]={ class = "HUNTER", level = 4, },
	[19883]={ class = "HUNTER", level = 4, },
	[19884]={ class = "HUNTER", level = 4, },
	[186257]={ class = "HUNTER", level = 5, },
	[1462]={ class = "HUNTER", level = 5, },
	[883]={ class = "HUNTER", level = 5, },
	[2641]={ class = "HUNTER", level = 5, },
	[6991]={ class = "HUNTER", level = 5, },
	[136]={ class = "HUNTER", level = 5, },
	[982]={ class = "HUNTER", level = 5, },
	[1515]={ class = "HUNTER", level = 5, },
	[5384]={ class = "HUNTER", level = 6, },
	[210000]={ class = "HUNTER", level = 6, },
	[186265]={ class = "HUNTER", level = 8, },
	[109304]={ class = "HUNTER", level = 9, },
	[61648]={ class = "HUNTER", level = 10, },
	[83242]={ class = "HUNTER", level = 10, },
	[93321]={ class = "HUNTER", level = 10, },
	[125050]={ class = "HUNTER", level = 10, },
	[127933]={ class = "HUNTER", level = 10, },
	[187650]={ class = "HUNTER", level = 10, },
	[209997]={ class = "HUNTER", level = 10, },
	[83243]={ class = "HUNTER", level = 17, },
	[1543]={ class = "HUNTER", level = 19, },
	[272651]={ class = "HUNTER", level = 22, },
	[321297]={ class = "HUNTER", level = 29, },
	[83244]={ class = "HUNTER", level = 41, },
	[6197]={ class = "HUNTER", level = 43, },
	[83245]={ class = "HUNTER", level = 48, },
--++ Hunter Artifact Traits ++	
	[241114]={ class = "HUNTER", level = 40, },
	[203755]={ class = "HUNTER", level = 40, },
	[215779]={ class = "HUNTER", level = 40, },
	[224764]={ class = "HUNTER", level = 40, },
	[241110]={ class = "HUNTER", level = 40, },
	[191048]={ class = "HUNTER", level = 40, },
	[190467]={ class = "HUNTER", level = 40, },
	[238123]={ class = "HUNTER", level = 40, },
	[191328]={ class = "HUNTER", level = 40, },
	[238124]={ class = "HUNTER", level = 40, },
	[190449]={ class = "HUNTER", level = 40, },
	[203757]={ class = "HUNTER", level = 40, },
	[238125]={ class = "HUNTER", level = 40, },
	[225092]={ class = "HUNTER", level = 40, },
	[203670]={ class = "HUNTER", level = 40, },
	[238088]={ class = "HUNTER", level = 40, },
	[241115]={ class = "HUNTER", level = 40, },
	[203669]={ class = "HUNTER", level = 40, },
	[197139]={ class = "HUNTER", level = 40, },
	[197047]={ class = "HUNTER", level = 40, },
	[190567]={ class = "HUNTER", level = 40, },
	[282143]={ class = "HUNTER", level = 40, },
	[190503]={ class = "HUNTER", level = 40, },
	[203673]={ class = "HUNTER", level = 40, },
	[197178]={ class = "HUNTER", level = 40, },
	[203749]={ class = "HUNTER", level = 40, },
	[203752]={ class = "HUNTER", level = 40, },
	[221773]={ class = "HUNTER", level = 40, },
	[238053]={ class = "HUNTER", level = 40, },
	[197162]={ class = "HUNTER", level = 40, },
	[203578]={ class = "HUNTER", level = 40, },
	[204219]={ class = "HUNTER", level = 40, },
	[190529]={ class = "HUNTER", level = 40, },
	[197248]={ class = "HUNTER", level = 40, },
	[197160]={ class = "HUNTER", level = 40, },
	[203577]={ class = "HUNTER", level = 40, },
	[197138]={ class = "HUNTER", level = 40, },
	[197080]={ class = "HUNTER", level = 40, },
	[197343]={ class = "HUNTER", level = 40, },
	[190520]={ class = "HUNTER", level = 40, },
	[190462]={ class = "HUNTER", level = 40, },
	[191339]={ class = "HUNTER", level = 40, },
	[203638]={ class = "HUNTER", level = 40, },
	[203566]={ class = "HUNTER", level = 40, },
	[238051]={ class = "HUNTER", level = 40, },
	[197199]={ class = "HUNTER", level = 40, },
	[214914]={ class = "HUNTER", level = 40, },
	[197140]={ class = "HUNTER", level = 40, },
	[197354]={ class = "HUNTER", level = 40, },
	[190514]={ class = "HUNTER", level = 40, },
	[238089]={ class = "HUNTER", level = 40, },
	[203563]={ class = "HUNTER", level = 40, },
	[203754]={ class = "HUNTER", level = 40, },
	[238087]={ class = "HUNTER", level = 40, },
	[207068]={ class = "HUNTER", level = 40, },
	[238052]={ class = "HUNTER", level = 40, },
	[206910]={ class = "HUNTER", level = 40, },
	[214916]={ class = "HUNTER", level = 40, },
	[197038]={ class = "HUNTER", level = 40, },
	[214826]={ class = "HUNTER", level = 40, },
	[204147]={ class = "HUNTER", level = 40, },
	[214915]={ class = "HUNTER", level = 40, },
	[190457]={ class = "HUNTER", level = 40, },
--++ Hunter Azerite Traits ++	
	[263814]={ class = "HUNTER", level = 45, },
	[263829]={ class = "HUNTER", level = 45, },
	[277653]={ class = "HUNTER", level = 45, },
	[277966]={ class = "HUNTER", level = 45, },
	[277969]={ class = "HUNTER", level = 45, },
	[274441]={ class = "HUNTER", level = 45, },
	[274442]={ class = "HUNTER", level = 45, },
	[274443]={ class = "HUNTER", level = 45, },
	[287093]={ class = "HUNTER", level = 45, },
	[287097]={ class = "HUNTER", level = 45, },
	[280169]={ class = "HUNTER", level = 45, },
	[278529]={ class = "HUNTER", level = 45, },
	[279607]={ class = "HUNTER", level = 45, },
	[269624]={ class = "HUNTER", level = 45, },
	[269625]={ class = "HUNTER", level = 45, },
	[270651]={ class = "HUNTER", level = 45, },
	[278531]={ class = "HUNTER", level = 45, },
	[279636]={ class = "HUNTER", level = 45, },
	[279637]={ class = "HUNTER", level = 45, },
	[273262]={ class = "HUNTER", level = 45, },
	[273263]={ class = "HUNTER", level = 45, },
	[264198]={ class = "HUNTER", level = 45, },
	[273283]={ class = "HUNTER", level = 45, },
	[273284]={ class = "HUNTER", level = 45, },
	[287938]={ class = "HUNTER", level = 45, },
	[287940]={ class = "HUNTER", level = 45, },
	[279806]={ class = "HUNTER", level = 45, },
	[279807]={ class = "HUNTER", level = 45, },
	[288570]={ class = "HUNTER", level = 45, },
	[288571]={ class = "HUNTER", level = 45, },
	[288573]={ class = "HUNTER", level = 45, },
	[269256]={ class = "HUNTER", level = 45, },
	[278530]={ class = "HUNTER", level = 45, },
	[263821]={ class = "HUNTER", level = 45, },
	[264195]={ class = "HUNTER", level = 45, },
	[269343]={ class = "HUNTER", level = 45, },
	[272717]={ class = "HUNTER", level = 45, },
	[274356]={ class = "HUNTER", level = 45, },
	[277651]={ class = "HUNTER", level = 45, },
	[277957]={ class = "HUNTER", level = 45, },
	[277959]={ class = "HUNTER", level = 45, },
	[287707]={ class = "HUNTER", level = 45, },
	[287711]={ class = "HUNTER", level = 45, },
	[274444]={ class = "HUNTER", level = 45, },
	[274445]={ class = "HUNTER", level = 45, },
	[274446]={ class = "HUNTER", level = 45, },
	[274590]={ class = "HUNTER", level = 45, },
	[263818]={ class = "HUNTER", level = 45, },
	[264199]={ class = "HUNTER", level = 45, },
	[278532]={ class = "HUNTER", level = 45, },
	[279589]={ class = "HUNTER", level = 45, },
	[272742]={ class = "HUNTER", level = 45, },
	[272743]={ class = "HUNTER", level = 45, },
--++ Hunter Covenant Abilities ++	
	[308491]={ class = "HUNTER", level = 48, },
	[325028]={ class = "HUNTER", level = 48, },
	[328231]={ class = "HUNTER", level = 48, },
--++ Hunter Conduit Abilities ++	
	[346747]={ class = "HUNTER", level = 60, },
	[341440]={ class = "HUNTER", level = 60, },
	[339924]={ class = "HUNTER", level = 60, },
	[339558]={ class = "HUNTER", level = 60, },
	[339973]={ class = "HUNTER", level = 60, },
	[341350]={ class = "HUNTER", level = 60, },
	[340876]={ class = "HUNTER", level = 60, },
	[339059]={ class = "HUNTER", level = 60, },
	[339018]={ class = "HUNTER", level = 60, },
	[339704]={ class = "HUNTER", level = 60, },
	[341399]={ class = "HUNTER", level = 60, },
	[339377]={ class = "HUNTER", level = 60, },
	[339264]={ class = "HUNTER", level = 60, },
	[339129]={ class = "HUNTER", level = 60, },
	[339750]={ class = "HUNTER", level = 60, },
	[340033]={ class = "HUNTER", level = 60, },
	[339399]={ class = "HUNTER", level = 60, },
	[339459]={ class = "HUNTER", level = 60, },
	[339495]={ class = "HUNTER", level = 60, },
	[339920]={ class = "HUNTER", level = 60, },
	[339109]={ class = "HUNTER", level = 60, },
	[341246]={ class = "HUNTER", level = 60, },
	[341222]={ class = "HUNTER", level = 60, },
	[339651]={ class = "HUNTER", level = 60, },
--++ Hunter Specializations ++	
	[137015]={ class = "HUNTER", level = 1, },
	[137016]={ class = "HUNTER", level = 1, },
	[137017]={ class = "HUNTER", level = 1, },
	[53270]={ class = "HUNTER", level = 10, },
	[76657]={ class = "HUNTER", level = 10, },
	[193468]={ class = "HUNTER", level = 10, },
	[263135]={ class = "HUNTER", level = 10, },
--++ Hunter Talents ++	
	[343248]={ class = "HUNTER", level = 10, },
	[34026]={ class = "HUNTER", level = 10, },
	[259489]={ class = "HUNTER", level = 10, },
	[53351]={ class = "HUNTER", level = 10, },
	[320976]={ class = "HUNTER", level = 10, },
	[109215]={ class = "HUNTER", level = 10, },
	[199921]={ class = "HUNTER", level = 10, },
	[231390]={ class = "HUNTER", level = 10, },
	[343242]={ class = "HUNTER", level = 10, },
	[19434]={ class = "HUNTER", level = 11, },
	[193455]={ class = "HUNTER", level = 11, },
	[186270]={ class = "HUNTER", level = 11, },
	[270581]={ class = "HUNTER", level = 12, },
	[321293]={ class = "HUNTER", level = 13, },
	[263186]={ class = "HUNTER", level = 13, },
	[321018]={ class = "HUNTER", level = 13, },
	[2643]={ class = "HUNTER", level = 13, },
	[321014]={ class = "HUNTER", level = 13, },
	[260240]={ class = "HUNTER", level = 13, },
	[260285]={ class = "HUNTER", level = 13, },
	[259495]={ class = "HUNTER", level = 13, },
	[147362]={ class = "HUNTER", level = 14, },
	[187707]={ class = "HUNTER", level = 14, },
	[187698]={ class = "HUNTER", level = 14, },
	[191384]={ class = "HUNTER", level = 15, },
	[186289]={ class = "HUNTER", level = 15, },
	[115939]={ class = "HUNTER", level = 15, },
	[260248]={ class = "HUNTER", level = 15, },
	[378916]={ class = "HUNTER", level = 15, },
	[378765]={ class = "HUNTER", level = 15, },
	[56315]={ class = "HUNTER", level = 15, },
	[388039]={ class = "HUNTER", level = 15, },
	[155228]={ class = "HUNTER", level = 15, },
	[378209]={ class = "HUNTER", level = 15, },
	[264735]={ class = "HUNTER", level = 16, },
	[267116]={ class = "HUNTER", level = 17, },
	[260228]={ class = "HUNTER", level = 17, },
	[342049]={ class = "HUNTER", level = 17, },
	[378961]={ class = "HUNTER", level = 17, },
	[378766]={ class = "HUNTER", level = 17, },
	[260367]={ class = "HUNTER", level = 17, },
	[378740]={ class = "HUNTER", level = 19, },
	[378205]={ class = "HUNTER", level = 19, },
	[265895]={ class = "HUNTER", level = 19, },
	[266921]={ class = "HUNTER", level = 26, },
	[393344]={ class = "HUNTER", level = 26, },
	[343247]={ class = "HUNTER", level = 26, },
	[388042]={ class = "HUNTER", level = 26, },
	[19801]={ class = "HUNTER", level = 26, },
	[321530]={ class = "HUNTER", level = 27, },
	[212436]={ class = "HUNTER", level = 27, },
	[187708]={ class = "HUNTER", level = 27, },
	[378244]={ class = "HUNTER", level = 27, },
	[378750]={ class = "HUNTER", level = 27, },
	[378769]={ class = "HUNTER", level = 27, },
	[378767]={ class = "HUNTER", level = 27, },
	[264332]={ class = "HUNTER", level = 27, },
	[385709]={ class = "HUNTER", level = 27, },
	[378207]={ class = "HUNTER", level = 27, },
	[260393]={ class = "HUNTER", level = 27, },
	[378934]={ class = "HUNTER", level = 27, },
	[259387]={ class = "HUNTER", level = 27, },
	[257891]={ class = "HUNTER", level = 27, },
	[391559]={ class = "HUNTER", level = 27, },
	[321287]={ class = "HUNTER", level = 27, },
	[257944]={ class = "HUNTER", level = 27, },
	[109248]={ class = "HUNTER", level = 28, },
	[199483]={ class = "HUNTER", level = 28, },
	[236776]={ class = "HUNTER", level = 28, },
	[343244]={ class = "HUNTER", level = 28, },
	[385539]={ class = "HUNTER", level = 28, },
	[19574]={ class = "HUNTER", level = 29, },
	[344572]={ class = "HUNTER", level = 29, },
	[269751]={ class = "HUNTER", level = 29, },
	[294029]={ class = "HUNTER", level = 29, },
	[321290]={ class = "HUNTER", level = 29, },
	[257620]={ class = "HUNTER", level = 29, },
	[384790]={ class = "HUNTER", level = 29, },
	[378953]={ class = "HUNTER", level = 29, },
	[268501]={ class = "HUNTER", level = 29, },
	[393933]={ class = "HUNTER", level = 29, },
	[321468]={ class = "HUNTER", level = 30, },
	[384799]={ class = "HUNTER", level = 30, },
	[378002]={ class = "HUNTER", level = 30, },
	[393505]={ class = "HUNTER", level = 30, },
	[388045]={ class = "HUNTER", level = 30, },
	[231548]={ class = "HUNTER", level = 31, },
	[378880]={ class = "HUNTER", level = 31, },
	[321460]={ class = "HUNTER", level = 31, },
	[120679]={ class = "HUNTER", level = 31, },
	[260402]={ class = "HUNTER", level = 31, },
	[378210]={ class = "HUNTER", level = 31, },
	[378948]={ class = "HUNTER", level = 31, },
	[193533]={ class = "HUNTER", level = 31, },
	[199530]={ class = "HUNTER", level = 31, },
	[378950]={ class = "HUNTER", level = 31, },
	[378951]={ class = "HUNTER", level = 31, },
	[257621]={ class = "HUNTER", level = 31, },
	[260247]={ class = "HUNTER", level = 31, },
	[185789]={ class = "HUNTER", level = 31, },
	[388056]={ class = "HUNTER", level = 32, },
	[388057]={ class = "HUNTER", level = 32, },
	[193530]={ class = "HUNTER", level = 33, },
	[385737]={ class = "HUNTER", level = 33, },
	[378771]={ class = "HUNTER", level = 33, },
	[378888]={ class = "HUNTER", level = 33, },
	[378007]={ class = "HUNTER", level = 50, },
	[378004]={ class = "HUNTER", level = 50, },
	[260309]={ class = "HUNTER", level = 50, },
	[389019]={ class = "HUNTER", level = 51, },
	[204089]={ class = "HUNTER", level = 51, },
	[359844]={ class = "HUNTER", level = 51, },
	[360952]={ class = "HUNTER", level = 51, },
	[378743]={ class = "HUNTER", level = 51, },
	[378910]={ class = "HUNTER", level = 51, },
	[378955]={ class = "HUNTER", level = 51, },
	[378913]={ class = "HUNTER", level = 51, },
	[194595]={ class = "HUNTER", level = 51, },
	[389654]={ class = "HUNTER", level = 51, },
	[199528]={ class = "HUNTER", level = 51, },
	[378940]={ class = "HUNTER", level = 51, },
	[193532]={ class = "HUNTER", level = 51, },
	[378907]={ class = "HUNTER", level = 51, },
	[389660]={ class = "HUNTER", level = 51, },
	[288613]={ class = "HUNTER", level = 51, },
	[355589]={ class = "HUNTER", level = 51, },
	[392060]={ class = "HUNTER", level = 51, },
	[271014]={ class = "HUNTER", level = 51, },
	[385739]={ class = "HUNTER", level = 53, },
	[389449]={ class = "HUNTER", level = 53, },
	[378937]={ class = "HUNTER", level = 53, },
	[203413]={ class = "HUNTER", level = 53, },
	[203415]={ class = "HUNTER", level = 53, },
	[385695]={ class = "HUNTER", level = 53, },
	[384791]={ class = "HUNTER", level = 53, },
	[390231]={ class = "HUNTER", level = 54, },
	[375891]={ class = "HUNTER", level = 54, },
	[378010]={ class = "HUNTER", level = 54, },
	[389882]={ class = "HUNTER", level = 54, },
	[201430]={ class = "HUNTER", level = 54, },
	[378739]={ class = "HUNTER", level = 55, },
	[386870]={ class = "HUNTER", level = 55, },
	[199532]={ class = "HUNTER", level = 55, },
	[190852]={ class = "HUNTER", level = 55, },
	[392053]={ class = "HUNTER", level = 55, },
	[389865]={ class = "HUNTER", level = 55, },
	[385718]={ class = "HUNTER", level = 55, },
	[360966]={ class = "HUNTER", level = 55, },
	[378442]={ class = "HUNTER", level = 55, },
	[389866]={ class = "HUNTER", level = 55, },
	[260241]={ class = "HUNTER", level = 56, },
	[378014]={ class = "HUNTER", level = 56, },
	[260331]={ class = "HUNTER", level = 57, },
	[389880]={ class = "HUNTER", level = 57, },
	[260404]={ class = "HUNTER", level = 57, },
	[378962]={ class = "HUNTER", level = 57, },
	[385810]={ class = "HUNTER", level = 57, },
	[386878]={ class = "HUNTER", level = 57, },
	[269737]={ class = "HUNTER", level = 58, },
	[120360]={ class = "HUNTER", level = 58, },
	[212431]={ class = "HUNTER", level = 58, },
	[273887]={ class = "HUNTER", level = 58, },
	[162488]={ class = "HUNTER", level = 58, },
	[378905]={ class = "HUNTER", level = 59, },
	[378745]={ class = "HUNTER", level = 61, },
--++ Hunter PvP Talents ++	
	[357018]={ class = "HUNTER", level = 20, },
	[205691]={ class = "HUNTER", level = 20, },
	[208652]={ class = "HUNTER", level = 20, },
	[202589]={ class = "HUNTER", level = 20, },
	[203235]={ class = "HUNTER", level = 20, },
	[212640]={ class = "HUNTER", level = 20, },
	[248443]={ class = "HUNTER", level = 20, },
	[356976]={ class = "HUNTER", level = 20, },
	[356015]={ class = "HUNTER", level = 20, },
	[203264]={ class = "HUNTER", level = 21, },
	[202746]={ class = "HUNTER", level = 25, },
	[356719]={ class = "HUNTER", level = 30, },
	[248518]={ class = "HUNTER", level = 30, },
	[203155]={ class = "HUNTER", level = 30, },
	[203129]={ class = "HUNTER", level = 35, },
	[203340]={ class = "HUNTER", level = 40, },
	[356962]={ class = "HUNTER", level = 60, },
	[356707]={ class = "HUNTER", level = 60, },
--++ Mage Abilities ++	
	[120146]={ class = "MAGE", level = 35, },
	[137018]={ class = "MAGE", level = 1, },
	[53142]={ class = "MAGE", level = 1, },
	[281402]={ class = "MAGE", level = 1, },
	[33691]={ class = "MAGE", level = 1, },
	[35717]={ class = "MAGE", level = 1, },
	[49361]={ class = "MAGE", level = 1, },
	[176246]={ class = "MAGE", level = 1, },
	[88345]={ class = "MAGE", level = 1, },
	[88346]={ class = "MAGE", level = 1, },
	[132620]={ class = "MAGE", level = 1, },
	[132626]={ class = "MAGE", level = 1, },
	[176244]={ class = "MAGE", level = 1, },
	[281404]={ class = "MAGE", level = 1, },
	[176248]={ class = "MAGE", level = 1, },
	[132621]={ class = "MAGE", level = 1, },
	[132627]={ class = "MAGE", level = 1, },
	[176242]={ class = "MAGE", level = 1, },
	[116]={ class = "MAGE", level = 1, },
	[319836]={ class = "MAGE", level = 2, },
	[1953]={ class = "MAGE", level = 4, },
	[190336]={ class = "MAGE", level = 5, },
	[1449]={ class = "MAGE", level = 6, },
	[2139]={ class = "MAGE", level = 7, },
	[1459]={ class = "MAGE", level = 8, },
	[210086]={ class = "MAGE", level = 10, },
	[131784]={ class = "MAGE", level = 10, },
	[193759]={ class = "MAGE", level = 10, },
	[281403]={ class = "MAGE", level = 11, },
	[224869]={ class = "MAGE", level = 11, },
	[343127]={ class = "MAGE", level = 21, },
	[53140]={ class = "MAGE", level = 21, },
	[3565]={ class = "MAGE", level = 21, },
	[32271]={ class = "MAGE", level = 21, },
	[3562]={ class = "MAGE", level = 21, },
	[3567]={ class = "MAGE", level = 21, },
	[33690]={ class = "MAGE", level = 21, },
	[35715]={ class = "MAGE", level = 21, },
	[32272]={ class = "MAGE", level = 21, },
	[49358]={ class = "MAGE", level = 21, },
	[3561]={ class = "MAGE", level = 21, },
	[49359]={ class = "MAGE", level = 21, },
	[3566]={ class = "MAGE", level = 21, },
	[88342]={ class = "MAGE", level = 21, },
	[88344]={ class = "MAGE", level = 21, },
	[3563]={ class = "MAGE", level = 21, },
	[343140]={ class = "MAGE", level = 24, },
	[281400]={ class = "MAGE", level = 24, },
	[11419]={ class = "MAGE", level = 24, },
	[32266]={ class = "MAGE", level = 24, },
	[11416]={ class = "MAGE", level = 24, },
	[11417]={ class = "MAGE", level = 24, },
	[32267]={ class = "MAGE", level = 24, },
	[10059]={ class = "MAGE", level = 24, },
	[49360]={ class = "MAGE", level = 24, },
	[11420]={ class = "MAGE", level = 24, },
	[11418]={ class = "MAGE", level = 24, },
	[224871]={ class = "MAGE", level = 24, },
	[120145]={ class = "MAGE", level = 28, },
	[344587]={ class = "MAGE", level = 52, },
	[344597]={ class = "MAGE", level = 58, },
	[395277]={ class = "MAGE", level = 62, },
	[395289]={ class = "MAGE", level = 68, },
--++ Mage Artifact Traits ++	
	[187680]={ class = "MAGE", level = 40, },
	[187287]={ class = "MAGE", level = 40, },
	[187264]={ class = "MAGE", level = 40, },
	[238054]={ class = "MAGE", level = 40, },
	[187321]={ class = "MAGE", level = 40, },
	[194431]={ class = "MAGE", level = 40, },
	[238090]={ class = "MAGE", level = 40, },
	[214917]={ class = "MAGE", level = 40, },
	[187313]={ class = "MAGE", level = 40, },
	[188006]={ class = "MAGE", level = 40, },
	[215796]={ class = "MAGE", level = 40, },
	[195615]={ class = "MAGE", level = 40, },
	[194487]={ class = "MAGE", level = 40, },
	[187258]={ class = "MAGE", level = 40, },
	[210182]={ class = "MAGE", level = 40, },
	[194312]={ class = "MAGE", level = 40, },
	[194318]={ class = "MAGE", level = 40, },
	[195419]={ class = "MAGE", level = 40, },
	[195448]={ class = "MAGE", level = 40, },
	[195351]={ class = "MAGE", level = 40, },
	[187310]={ class = "MAGE", level = 40, },
	[214634]={ class = "MAGE", level = 40, },
	[214918]={ class = "MAGE", level = 40, },
	[187276]={ class = "MAGE", level = 40, },
	[194314]={ class = "MAGE", level = 40, },
	[187301]={ class = "MAGE", level = 40, },
	[194224]={ class = "MAGE", level = 40, },
	[210716]={ class = "MAGE", level = 40, },
	[238092]={ class = "MAGE", level = 40, },
	[241125]={ class = "MAGE", level = 40, },
	[195345]={ class = "MAGE", level = 40, },
	[238128]={ class = "MAGE", level = 40, },
	[194313]={ class = "MAGE", level = 40, },
	[195317]={ class = "MAGE", level = 40, },
	[214664]={ class = "MAGE", level = 40, },
	[195315]={ class = "MAGE", level = 40, },
	[220817]={ class = "MAGE", level = 40, },
	[241124]={ class = "MAGE", level = 40, },
	[241121]={ class = "MAGE", level = 40, },
	[214776]={ class = "MAGE", level = 40, },
	[214626]={ class = "MAGE", level = 40, },
	[195322]={ class = "MAGE", level = 40, },
	[187318]={ class = "MAGE", level = 40, },
	[194315]={ class = "MAGE", level = 40, },
	[238056]={ class = "MAGE", level = 40, },
	[195323]={ class = "MAGE", level = 40, },
	[215773]={ class = "MAGE", level = 40, },
	[194466]={ class = "MAGE", level = 40, },
	[238055]={ class = "MAGE", level = 40, },
	[194331]={ class = "MAGE", level = 40, },
	[194239]={ class = "MAGE", level = 40, },
	[194234]={ class = "MAGE", level = 40, },
	[215463]={ class = "MAGE", level = 40, },
	[227481]={ class = "MAGE", level = 40, },
	[214629]={ class = "MAGE", level = 40, },
	[195354]={ class = "MAGE", level = 40, },
	[210730]={ class = "MAGE", level = 40, },
	[214919]={ class = "MAGE", level = 40, },
	[238127]={ class = "MAGE", level = 40, },
	[195352]={ class = "MAGE", level = 40, },
	[238126]={ class = "MAGE", level = 40, },
	[187304]={ class = "MAGE", level = 40, },
	[210725]={ class = "MAGE", level = 40, },
	[238091]={ class = "MAGE", level = 40, },
	[221844]={ class = "MAGE", level = 40, },
--++ Mage Azerite Traits ++	
	[274594]={ class = "MAGE", level = 45, },
	[270669]={ class = "MAGE", level = 45, },
	[270670]={ class = "MAGE", level = 45, },
	[270671]={ class = "MAGE", level = 45, },
	[274596]={ class = "MAGE", level = 45, },
	[274597]={ class = "MAGE", level = 45, },
	[274598]={ class = "MAGE", level = 45, },
	[273326]={ class = "MAGE", level = 45, },
	[273327]={ class = "MAGE", level = 45, },
	[273329]={ class = "MAGE", level = 45, },
	[273330]={ class = "MAGE", level = 45, },
	[288466]={ class = "MAGE", level = 45, },
	[280173]={ class = "MAGE", level = 45, },
	[278538]={ class = "MAGE", level = 45, },
	[279084]={ class = "MAGE", level = 45, },
	[274379]={ class = "MAGE", level = 45, },
	[264351]={ class = "MAGE", level = 45, },
	[264352]={ class = "MAGE", level = 45, },
	[264353]={ class = "MAGE", level = 45, },
	[286027]={ class = "MAGE", level = 45, },
	[278537]={ class = "MAGE", level = 45, },
	[278539]={ class = "MAGE", level = 45, },
	[272932]={ class = "MAGE", level = 45, },
	[272933]={ class = "MAGE", level = 45, },
	[272934]={ class = "MAGE", level = 45, },
	[288164]={ class = "MAGE", level = 45, },
	[288204]={ class = "MAGE", level = 45, },
	[278542]={ class = "MAGE", level = 45, },
	[279684]={ class = "MAGE", level = 45, },
	[279685]={ class = "MAGE", level = 45, },
	[278536]={ class = "MAGE", level = 45, },
	[279080]={ class = "MAGE", level = 45, },
	[279081]={ class = "MAGE", level = 45, },
	[279854]={ class = "MAGE", level = 45, },
	[279855]={ class = "MAGE", level = 45, },
	[272968]={ class = "MAGE", level = 45, },
	[272969]={ class = "MAGE", level = 45, },
	[288121]={ class = "MAGE", level = 45, },
	[288125]={ class = "MAGE", level = 45, },
	[277656]={ class = "MAGE", level = 45, },
	[277663]={ class = "MAGE", level = 45, },
	[277902]={ class = "MAGE", level = 45, },
	[277904]={ class = "MAGE", level = 45, },
	[278541]={ class = "MAGE", level = 45, },
	[288755]={ class = "MAGE", level = 45, },
	[288795]={ class = "MAGE", level = 45, },
--++ Mage Covenant Abilities ++	
	[324220]={ class = "MAGE", level = 48, },
--++ Mage Conduit Abilities ++	
	[336873]={ class = "MAGE", level = 60, },
	[337240]={ class = "MAGE", level = 60, },
	[341325]={ class = "MAGE", level = 60, },
	[337123]={ class = "MAGE", level = 60, },
	[336992]={ class = "MAGE", level = 60, },
	[337136]={ class = "MAGE", level = 60, },
	[337224]={ class = "MAGE", level = 60, },
	[336636]={ class = "MAGE", level = 60, },
	[336999]={ class = "MAGE", level = 60, },
	[336777]={ class = "MAGE", level = 60, },
	[336569]={ class = "MAGE", level = 60, },
	[336522]={ class = "MAGE", level = 60, },
	[337275]={ class = "MAGE", level = 60, },
	[336821]={ class = "MAGE", level = 60, },
	[337058]={ class = "MAGE", level = 60, },
	[337192]={ class = "MAGE", level = 60, },
	[336852]={ class = "MAGE", level = 60, },
	[336886]={ class = "MAGE", level = 60, },
	[336472]={ class = "MAGE", level = 60, },
	[337087]={ class = "MAGE", level = 60, },
	[337293]={ class = "MAGE", level = 60, },
	[336460]={ class = "MAGE", level = 60, },
	[336613]={ class = "MAGE", level = 60, },
--++ Mage Specializations ++	
	[137019]={ class = "MAGE", level = 1, },
	[137020]={ class = "MAGE", level = 1, },
	[137021]={ class = "MAGE", level = 10, },
	[30451]={ class = "MAGE", level = 10, },
	[133]={ class = "MAGE", level = 10, },
	[76613]={ class = "MAGE", level = 10, },
	[321684]={ class = "MAGE", level = 10, },
	[12846]={ class = "MAGE", level = 10, },
	[190740]={ class = "MAGE", level = 10, },
--++ Mage Talents ++	
	[45438]={ class = "MAGE", level = 10, },
	[66]={ class = "MAGE", level = 10, },
	[390218]={ class = "MAGE", level = 10, },
	[235450]={ class = "MAGE", level = 10, },
	[44425]={ class = "MAGE", level = 11, },
	[30455]={ class = "MAGE", level = 11, },
	[11366]={ class = "MAGE", level = 11, },
	[383092]={ class = "MAGE", level = 12, },
	[382293]={ class = "MAGE", level = 12, },
	[1463]={ class = "MAGE", level = 12, },
	[475]={ class = "MAGE", level = 12, },
	[116011]={ class = "MAGE", level = 12, },
	[30449]={ class = "MAGE", level = 12, },
	[382289]={ class = "MAGE", level = 12, },
	[382424]={ class = "MAGE", level = 12, },
	[5143]={ class = "MAGE", level = 13, },
	[190356]={ class = "MAGE", level = 13, },
	[387044]={ class = "MAGE", level = 13, },
	[112965]={ class = "MAGE", level = 13, },
	[108853]={ class = "MAGE", level = 13, },
	[84714]={ class = "MAGE", level = 13, },
	[55342]={ class = "MAGE", level = 13, },
	[342245]={ class = "MAGE", level = 14, },
	[153626]={ class = "MAGE", level = 15, },
	[79684]={ class = "MAGE", level = 15, },
	[235219]={ class = "MAGE", level = 15, },
	[44614]={ class = "MAGE", level = 15, },
	[257541]={ class = "MAGE", level = 15, },
	[2948]={ class = "MAGE", level = 15, },
	[12982]={ class = "MAGE", level = 15, },
	[365350]={ class = "MAGE", level = 17, },
	[383980]={ class = "MAGE", level = 17, },
	[190447]={ class = "MAGE", level = 17, },
	[321752]={ class = "MAGE", level = 17, },
	[385167]={ class = "MAGE", level = 17, },
	[205026]={ class = "MAGE", level = 17, },
	[378756]={ class = "MAGE", level = 17, },
	[383661]={ class = "MAGE", level = 17, },
	[343230]={ class = "MAGE", level = 17, },
	[383782]={ class = "MAGE", level = 17, },
	[378919]={ class = "MAGE", level = 17, },
	[157642]={ class = "MAGE", level = 17, },
	[269644]={ class = "MAGE", level = 17, },
	[382292]={ class = "MAGE", level = 26, },
	[382270]={ class = "MAGE", level = 26, },
	[342249]={ class = "MAGE", level = 26, },
	[382297]={ class = "MAGE", level = 26, },
	[382820]={ class = "MAGE", level = 26, },
	[382569]={ class = "MAGE", level = 26, },
	[236628]={ class = "MAGE", level = 27, },
	[205022]={ class = "MAGE", level = 27, },
	[321739]={ class = "MAGE", level = 27, },
	[205027]={ class = "MAGE", level = 27, },
	[86949]={ class = "MAGE", level = 27, },
	[384651]={ class = "MAGE", level = 27, },
	[117216]={ class = "MAGE", level = 27, },
	[205029]={ class = "MAGE", level = 27, },
	[205037]={ class = "MAGE", level = 27, },
	[236662]={ class = "MAGE", level = 27, },
	[383604]={ class = "MAGE", level = 27, },
	[205024]={ class = "MAGE", level = 27, },
	[321526]={ class = "MAGE", level = 27, },
	[378198]={ class = "MAGE", level = 27, },
	[205028]={ class = "MAGE", level = 27, },
	[264354]={ class = "MAGE", level = 27, },
	[236457]={ class = "MAGE", level = 27, },
	[31687]={ class = "MAGE", level = 27, },
	[108839]={ class = "MAGE", level = 28, },
	[391102]={ class = "MAGE", level = 28, },
	[113724]={ class = "MAGE", level = 28, },
	[212653]={ class = "MAGE", level = 28, },
	[231564]={ class = "MAGE", level = 29, },
	[190319]={ class = "MAGE", level = 29, },
	[231630]={ class = "MAGE", level = 29, },
	[257537]={ class = "MAGE", level = 29, },
	[379993]={ class = "MAGE", level = 29, },
	[384861]={ class = "MAGE", level = 29, },
	[205030]={ class = "MAGE", level = 29, },
	[378947]={ class = "MAGE", level = 29, },
	[383676]={ class = "MAGE", level = 29, },
	[321420]={ class = "MAGE", level = 29, },
	[321745]={ class = "MAGE", level = 29, },
	[383665]={ class = "MAGE", level = 29, },
	[205025]={ class = "MAGE", level = 29, },
	[281482]={ class = "MAGE", level = 29, },
	[381706]={ class = "MAGE", level = 29, },
	[380154]={ class = "MAGE", level = 29, },
	[378406]={ class = "MAGE", level = 29, },
	[386828]={ class = "MAGE", level = 30, },
	[343183]={ class = "MAGE", level = 30, },
	[382481]={ class = "MAGE", level = 30, },
	[382490]={ class = "MAGE", level = 30, },
	[382493]={ class = "MAGE", level = 30, },
	[389627]={ class = "MAGE", level = 30, },
	[235870]={ class = "MAGE", level = 31, },
	[343222]={ class = "MAGE", level = 31, },
	[235711]={ class = "MAGE", level = 31, },
	[205023]={ class = "MAGE", level = 31, },
	[378749]={ class = "MAGE", level = 31, },
	[383391]={ class = "MAGE", level = 31, },
	[383499]={ class = "MAGE", level = 31, },
	[342344]={ class = "MAGE", level = 31, },
	[383967]={ class = "MAGE", level = 31, },
	[379049]={ class = "MAGE", level = 31, },
	[157980]={ class = "MAGE", level = 31, },
	[383659]={ class = "MAGE", level = 31, },
	[321507]={ class = "MAGE", level = 31, },
	[12472]={ class = "MAGE", level = 33, },
	[382268]={ class = "MAGE", level = 50, },
	[235224]={ class = "MAGE", level = 50, },
	[382826]={ class = "MAGE", level = 50, },
	[384581]={ class = "MAGE", level = 51, },
	[342231]={ class = "MAGE", level = 51, },
	[153595]={ class = "MAGE", level = 51, },
	[759]={ class = "MAGE", level = 51, },
	[321387]={ class = "MAGE", level = 51, },
	[12051]={ class = "MAGE", level = 51, },
	[384033]={ class = "MAGE", level = 51, },
	[203275]={ class = "MAGE", level = 51, },
	[270233]={ class = "MAGE", level = 51, },
	[378433]={ class = "MAGE", level = 51, },
	[384060]={ class = "MAGE", level = 51, },
	[155148]={ class = "MAGE", level = 51, },
	[384174]={ class = "MAGE", level = 51, },
	[383476]={ class = "MAGE", level = 51, },
	[269650]={ class = "MAGE", level = 51, },
	[205020]={ class = "MAGE", level = 51, },
	[56377]={ class = "MAGE", level = 51, },
	[383489]={ class = "MAGE", level = 51, },
	[384276]={ class = "MAGE", level = 53, },
	[278309]={ class = "MAGE", level = 53, },
	[383669]={ class = "MAGE", level = 53, },
	[383810]={ class = "MAGE", level = 53, },
	[378448]={ class = "MAGE", level = 53, },
	[381244]={ class = "MAGE", level = 53, },
	[384612]={ class = "MAGE", level = 53, },
	[384187]={ class = "MAGE", level = 53, },
	[382144]={ class = "MAGE", level = 53, },
	[378901]={ class = "MAGE", level = 53, },
	[382800]={ class = "MAGE", level = 54, },
	[110959]={ class = "MAGE", level = 54, },
	[205036]={ class = "MAGE", level = 54, },
	[387807]={ class = "MAGE", level = 54, },
	[384374]={ class = "MAGE", level = 55, },
	[383634]={ class = "MAGE", level = 55, },
	[382103]={ class = "MAGE", level = 55, },
	[384683]={ class = "MAGE", level = 55, },
	[155149]={ class = "MAGE", level = 55, },
	[389713]={ class = "MAGE", level = 56, },
	[386763]={ class = "MAGE", level = 56, },
	[153561]={ class = "MAGE", level = 56, },
	[386539]={ class = "MAGE", level = 56, },
	[383243]={ class = "MAGE", level = 56, },
	[384452]={ class = "MAGE", level = 57, },
	[382110]={ class = "MAGE", level = 57, },
	[383860]={ class = "MAGE", level = 57, },
	[384858]={ class = "MAGE", level = 57, },
	[383886]={ class = "MAGE", level = 57, },
--++ Mage PvP Talents ++	
	[276741]={ class = "MAGE", level = 20, },
	[198126]={ class = "MAGE", level = 20, },
	[390428]={ class = "MAGE", level = 20, },
	[198062]={ class = "MAGE", level = 20, },
	[198064]={ class = "MAGE", level = 20, },
	[203280]={ class = "MAGE", level = 20, },
	[203284]={ class = "MAGE", level = 30, },
	[198144]={ class = "MAGE", level = 30, },
	[203283]={ class = "MAGE", level = 30, },
	[198111]={ class = "MAGE", level = 30, },
	[198148]={ class = "MAGE", level = 40, },
	[203286]={ class = "MAGE", level = 40, },
	[198100]={ class = "MAGE", level = 40, },
	[210476]={ class = "MAGE", level = 48, },
	[353128]={ class = "MAGE", level = 55, },
	[352278]={ class = "MAGE", level = 55, },
	[353082]={ class = "MAGE", level = 55, },
--++ Monk Abilities ++	
	[124255]={ class = "MONK", level = 1, },
	[137022]={ class = "MONK", level = 1, },
	[116812]={ class = "MONK", level = 1, },
	[100780]={ class = "MONK", level = 1, },
	[100784]={ class = "MONK", level = 2, },
	[109132]={ class = "MONK", level = 3, },
	[116670]={ class = "MONK", level = 4, },
	[322101]={ class = "MONK", level = 8, },
	[115546]={ class = "MONK", level = 9, },
	[322109]={ class = "MONK", level = 10, },
	[126892]={ class = "MONK", level = 11, },
	[115178]={ class = "MONK", level = 13, },
	[126895]={ class = "MONK", level = 16, },
	[169340]={ class = "MONK", level = 17, },
	[125883]={ class = "MONK", level = 30, },
	[8647]={ class = "MONK", level = 49, },
--++ Monk Artifact Traits ++	
	[199665]={ class = "MONK", level = 40, },
	[214372]={ class = "MONK", level = 40, },
	[199640]={ class = "MONK", level = 40, },
	[199364]={ class = "MONK", level = 40, },
	[195650]={ class = "MONK", level = 40, },
	[199573]={ class = "MONK", level = 40, },
	[213062]={ class = "MONK", level = 40, },
	[227688]={ class = "MONK", level = 40, },
	[227689]={ class = "MONK", level = 40, },
	[227690]={ class = "MONK", level = 40, },
	[227691]={ class = "MONK", level = 40, },
	[227692]={ class = "MONK", level = 40, },
	[239306]={ class = "MONK", level = 40, },
	[239307]={ class = "MONK", level = 40, },
	[195265]={ class = "MONK", level = 40, },
	[195266]={ class = "MONK", level = 40, },
	[213183]={ class = "MONK", level = 40, },
	[238057]={ class = "MONK", level = 40, },
	[238094]={ class = "MONK", level = 40, },
	[241131]={ class = "MONK", level = 40, },
	[199485]={ class = "MONK", level = 40, },
	[199372]={ class = "MONK", level = 40, },
	[213116]={ class = "MONK", level = 40, },
	[241136]={ class = "MONK", level = 40, },
	[195291]={ class = "MONK", level = 40, },
	[213340]={ class = "MONK", level = 40, },
	[214428]={ class = "MONK", level = 40, },
	[195399]={ class = "MONK", level = 40, },
	[213136]={ class = "MONK", level = 40, },
	[195295]={ class = "MONK", level = 40, },
	[195380]={ class = "MONK", level = 40, },
	[213133]={ class = "MONK", level = 40, },
	[213049]={ class = "MONK", level = 40, },
	[227683]={ class = "MONK", level = 40, },
	[227684]={ class = "MONK", level = 40, },
	[227685]={ class = "MONK", level = 40, },
	[227686]={ class = "MONK", level = 40, },
	[227687]={ class = "MONK", level = 40, },
	[239304]={ class = "MONK", level = 40, },
	[239305]={ class = "MONK", level = 40, },
	[199380]={ class = "MONK", level = 40, },
	[195244]={ class = "MONK", level = 40, },
	[199401]={ class = "MONK", level = 40, },
	[238095]={ class = "MONK", level = 40, },
	[199563]={ class = "MONK", level = 40, },
	[241134]={ class = "MONK", level = 40, },
	[214516]={ class = "MONK", level = 40, },
	[214921]={ class = "MONK", level = 40, },
	[213051]={ class = "MONK", level = 40, },
	[216424]={ class = "MONK", level = 40, },
	[213180]={ class = "MONK", level = 40, },
	[213047]={ class = "MONK", level = 40, },
	[195269]={ class = "MONK", level = 40, },
	[199367]={ class = "MONK", level = 40, },
	[238129]={ class = "MONK", level = 40, },
	[195263]={ class = "MONK", level = 40, },
	[205406]={ class = "MONK", level = 40, },
	[199365]={ class = "MONK", level = 40, },
	[213050]={ class = "MONK", level = 40, },
	[199377]={ class = "MONK", level = 40, },
	[199384]={ class = "MONK", level = 40, },
	[195298]={ class = "MONK", level = 40, },
	[238059]={ class = "MONK", level = 40, },
	[213055]={ class = "MONK", level = 40, },
	[238093]={ class = "MONK", level = 40, },
	[195267]={ class = "MONK", level = 40, },
	[213161]={ class = "MONK", level = 40, },
	[238058]={ class = "MONK", level = 40, },
	[199887]={ class = "MONK", level = 40, },
	[238131]={ class = "MONK", level = 40, },
	[218607]={ class = "MONK", level = 40, },
	[196082]={ class = "MONK", level = 40, },
	[214920]={ class = "MONK", level = 40, },
	[199366]={ class = "MONK", level = 40, },
	[238130]={ class = "MONK", level = 40, },
	[214922]={ class = "MONK", level = 40, },
--++ Monk Azerite Traits ++	
	[272792]={ class = "MONK", level = 45, },
	[272797]={ class = "MONK", level = 45, },
	[277667]={ class = "MONK", level = 45, },
	[287472]={ class = "MONK", level = 45, },
	[286585]={ class = "MONK", level = 45, },
	[286586]={ class = "MONK", level = 45, },
	[286587]={ class = "MONK", level = 45, },
	[278571]={ class = "MONK", level = 45, },
	[279605]={ class = "MONK", level = 45, },
	[289323]={ class = "MONK", level = 45, },
	[275892]={ class = "MONK", level = 45, },
	[279875]={ class = "MONK", level = 45, },
	[287055]={ class = "MONK", level = 45, },
	[288634]={ class = "MONK", level = 45, },
	[275975]={ class = "MONK", level = 45, },
	[276025]={ class = "MONK", level = 45, },
	[280386]={ class = "MONK", level = 45, },
	[279918]={ class = "MONK", level = 45, },
	[279921]={ class = "MONK", level = 45, },
	[273328]={ class = "MONK", level = 45, },
	[273334]={ class = "MONK", level = 45, },
	[278577]={ class = "MONK", level = 45, },
	[278718]={ class = "MONK", level = 45, },
	[287829]={ class = "MONK", level = 45, },
	[287830]={ class = "MONK", level = 45, },
	[273464]={ class = "MONK", level = 45, },
	[273468]={ class = "MONK", level = 45, },
	[285958]={ class = "MONK", level = 45, },
	[274771]={ class = "MONK", level = 45, },
	[274774]={ class = "MONK", level = 45, },
	[273291]={ class = "MONK", level = 45, },
	[273292]={ class = "MONK", level = 45, },
	[280182]={ class = "MONK", level = 45, },
	[278569]={ class = "MONK", level = 45, },
	[278576]={ class = "MONK", level = 45, },
	[279603]={ class = "MONK", level = 45, },
--++ Monk Covenant Abilities ++	
	[310454]={ class = "MONK", level = 48, },
	[311054]={ class = "MONK", level = 48, },
	[326860]={ class = "MONK", level = 48, },
	[327104]={ class = "MONK", level = 1, },
--++ Monk Conduit Abilities ++	
	[337295]={ class = "MONK", level = 60, },
	[336526]={ class = "MONK", level = 60, },
	[337134]={ class = "MONK", level = 60, },
	[336598]={ class = "MONK", level = 60, },
	[336890]={ class = "MONK", level = 60, },
	[337250]={ class = "MONK", level = 60, },
	[336853]={ class = "MONK", level = 60, },
	[336632]={ class = "MONK", level = 60, },
	[336379]={ class = "MONK", level = 60, },
	[337301]={ class = "MONK", level = 60, },
	[336452]={ class = "MONK", level = 60, },
	[336773]={ class = "MONK", level = 60, },
	[336884]={ class = "MONK", level = 60, },
	[337241]={ class = "MONK", level = 60, },
	[336812]={ class = "MONK", level = 60, },
	[337099]={ class = "MONK", level = 60, },
	[337119]={ class = "MONK", level = 60, },
	[337286]={ class = "MONK", level = 60, },
	[337078]={ class = "MONK", level = 60, },
	[337084]={ class = "MONK", level = 60, },
	[337264]={ class = "MONK", level = 60, },
	[337303]={ class = "MONK", level = 60, },
	[336616]={ class = "MONK", level = 60, },
--++ Monk Specializations ++	
	[137023]={ class = "MONK", level = 1, },
	[137024]={ class = "MONK", level = 1, },
	[137025]={ class = "MONK", level = 1, },
	[346104]={ class = "MONK", level = 1, },
	[343731]={ class = "MONK", level = 1, },
	[322106]={ class = "MONK", level = 1, },
	[344487]={ class = "MONK", level = 1, },
	[362170]={ class = "MONK", level = 1, },
	[157445]={ class = "MONK", level = 1, },
	[124146]={ class = "MONK", level = 1, },
	[115450]={ class = "MONK", level = 10, },
	[115636]={ class = "MONK", level = 10, },
	[117906]={ class = "MONK", level = 10, },
	[117907]={ class = "MONK", level = 10, },
	[128595]={ class = "MONK", level = 14, },
	[261916]={ class = "MONK", level = 17, },
	[245013]={ class = "MONK", level = 19, },
	[137384]={ class = "MONK", level = 19, },
	[261917]={ class = "MONK", level = 23, },
	[120224]={ class = "MONK", level = 27, },
	[120225]={ class = "MONK", level = 27, },
	[120227]={ class = "MONK", level = 27, },
	[343730]={ class = "MONK", level = 33, },
	[116092]={ class = "MONK", level = 38, },
	[322102]={ class = "MONK", level = 43, },
	[322104]={ class = "MONK", level = 43, },
	[322719]={ class = "MONK", level = 46, },
	[216519]={ class = "MONK", level = 46, },
	[212051]={ class = "MONK", level = 47, },
	[325095]={ class = "MONK", level = 52, },
	[325215]={ class = "MONK", level = 52, },
	[325214]={ class = "MONK", level = 54, },
--++ Monk Talents ++	
	[388664]={ class = "MONK", level = 10, },
	[218164]={ class = "MONK", level = 10, },
	[328669]={ class = "MONK", level = 10, },
	[231602]={ class = "MONK", level = 10, },
	[107428]={ class = "MONK", level = 10, },
	[392900]={ class = "MONK", level = 10, },
	[388674]={ class = "MONK", level = 12, },
	[388874]={ class = "MONK", level = 12, },
	[344359]={ class = "MONK", level = 12, },
	[264348]={ class = "MONK", level = 12, },
	[388812]={ class = "MONK", level = 12, },
	[115396]={ class = "MONK", level = 13, },
	[191837]={ class = "MONK", level = 13, },
	[121817]={ class = "MONK", level = 13, },
	[115151]={ class = "MONK", level = 13, },
	[115069]={ class = "MONK", level = 13, },
	[122470]={ class = "MONK", level = 13, },
	[388811]={ class = "MONK", level = 14, },
	[388854]={ class = "MONK", level = 15, },
	[391383]={ class = "MONK", level = 15, },
	[274586]={ class = "MONK", level = 15, },
	[392970]={ class = "MONK", level = 15, },
	[119582]={ class = "MONK", level = 15, },
	[322120]={ class = "MONK", level = 15, },
	[116680]={ class = "MONK", level = 15, },
	[231876]={ class = "MONK", level = 15, },
	[388856]={ class = "MONK", level = 15, },
	[388846]={ class = "MONK", level = 15, },
	[124502]={ class = "MONK", level = 17, },
	[392958]={ class = "MONK", level = 17, },
	[122281]={ class = "MONK", level = 17, },
	[383695]={ class = "MONK", level = 17, },
	[220357]={ class = "MONK", level = 17, },
	[281231]={ class = "MONK", level = 17, },
	[388505]={ class = "MONK", level = 17, },
	[388615]={ class = "MONK", level = 17, },
	[115310]={ class = "MONK", level = 17, },
	[198898]={ class = "MONK", level = 17, },
	[196730]={ class = "MONK", level = 17, },
	[116645]={ class = "MONK", level = 17, },
	[101545]={ class = "MONK", level = 19, },
	[123986]={ class = "MONK", level = 26, },
	[115098]={ class = "MONK", level = 26, },
	[388681]={ class = "MONK", level = 26, },
	[388809]={ class = "MONK", level = 26, },
	[388917]={ class = "MONK", level = 26, },
	[328670]={ class = "MONK", level = 26, },
	[116705]={ class = "MONK", level = 26, },
	[101643]={ class = "MONK", level = 26, },
	[322507]={ class = "MONK", level = 27, },
	[325177]={ class = "MONK", level = 27, },
	[324312]={ class = "MONK", level = 27, },
	[337209]={ class = "MONK", level = 27, },
	[387256]={ class = "MONK", level = 27, },
	[196740]={ class = "MONK", level = 27, },
	[195243]={ class = "MONK", level = 27, },
	[391330]={ class = "MONK", level = 27, },
	[388548]={ class = "MONK", level = 27, },
	[387765]={ class = "MONK", level = 27, },
	[388847]={ class = "MONK", level = 27, },
	[152173]={ class = "MONK", level = 27, },
	[392982]={ class = "MONK", level = 27, },
	[210802]={ class = "MONK", level = 27, },
	[387625]={ class = "MONK", level = 27, },
	[137639]={ class = "MONK", level = 27, },
	[388551]={ class = "MONK", level = 27, },
	[115176]={ class = "MONK", level = 27, },
	[124081]={ class = "MONK", level = 27, },
	[388564]={ class = "MONK", level = 29, },
	[115181]={ class = "MONK", level = 29, },
	[388218]={ class = "MONK", level = 29, },
	[325201]={ class = "MONK", level = 29, },
	[391370]={ class = "MONK", level = 29, },
	[388604]={ class = "MONK", level = 29, },
	[387230]={ class = "MONK", level = 29, },
	[387035]={ class = "MONK", level = 29, },
	[383700]={ class = "MONK", level = 29, },
	[322510]={ class = "MONK", level = 29, },
	[343743]={ class = "MONK", level = 29, },
	[325197]={ class = "MONK", level = 29, },
	[322118]={ class = "MONK", level = 29, },
	[392979]={ class = "MONK", level = 29, },
	[388511]={ class = "MONK", level = 29, },
	[387638]={ class = "MONK", level = 29, },
	[280197]={ class = "MONK", level = 29, },
	[392985]={ class = "MONK", level = 29, },
	[393357]={ class = "MONK", level = 29, },
	[388038]={ class = "MONK", level = 29, },
	[115173]={ class = "MONK", level = 30, },
	[115008]={ class = "MONK", level = 30, },
	[122783]={ class = "MONK", level = 30, },
	[388813]={ class = "MONK", level = 30, },
	[388814]={ class = "MONK", level = 30, },
	[392910]={ class = "MONK", level = 30, },
	[115399]={ class = "MONK", level = 31, },
	[280515]={ class = "MONK", level = 31, },
	[388701]={ class = "MONK", level = 31, },
	[343655]={ class = "MONK", level = 31, },
	[389942]={ class = "MONK", level = 31, },
	[393098]={ class = "MONK", level = 31, },
	[322960]={ class = "MONK", level = 31, },
	[132578]={ class = "MONK", level = 31, },
	[123904]={ class = "MONK", level = 31, },
	[197915]={ class = "MONK", level = 31, },
	[325093]={ class = "MONK", level = 31, },
	[197908]={ class = "MONK", level = 31, },
	[393516]={ class = "MONK", level = 31, },
	[383697]={ class = "MONK", level = 31, },
	[383698]={ class = "MONK", level = 31, },
	[383714]={ class = "MONK", level = 31, },
	[122278]={ class = "MONK", level = 32, },
	[196607]={ class = "MONK", level = 32, },
	[322113]={ class = "MONK", level = 32, },
	[387276]={ class = "MONK", level = 32, },
	[197900]={ class = "MONK", level = 33, },
	[389574]={ class = "MONK", level = 50, },
	[394110]={ class = "MONK", level = 50, },
	[394123]={ class = "MONK", level = 50, },
	[389575]={ class = "MONK", level = 50, },
	[157411]={ class = "MONK", level = 50, },
	[388023]={ class = "MONK", level = 51, },
	[386937]={ class = "MONK", level = 51, },
	[386965]={ class = "MONK", level = 51, },
	[388047]={ class = "MONK", level = 51, },
	[383785]={ class = "MONK", level = 51, },
	[388848]={ class = "MONK", level = 51, },
	[383994]={ class = "MONK", level = 51, },
	[387046]={ class = "MONK", level = 51, },
	[323999]={ class = "MONK", level = 51, },
	[388193]={ class = "MONK", level = 51, },
	[197895]={ class = "MONK", level = 51, },
	[396166]={ class = "MONK", level = 51, },
	[388212]={ class = "MONK", level = 51, },
	[196737]={ class = "MONK", level = 51, },
	[388031]={ class = "MONK", level = 51, },
	[388849]={ class = "MONK", level = 51, },
	[274963]={ class = "MONK", level = 51, },
	[387219]={ class = "MONK", level = 51, },
	[392986]={ class = "MONK", level = 51, },
	[388740]={ class = "MONK", level = 53, },
	[386941]={ class = "MONK", level = 53, },
	[386949]={ class = "MONK", level = 53, },
	[392989]={ class = "MONK", level = 53, },
	[388682]={ class = "MONK", level = 53, },
	[388593]={ class = "MONK", level = 53, },
	[388020]={ class = "MONK", level = 53, },
	[388491]={ class = "MONK", level = 53, },
	[195300]={ class = "MONK", level = 53, },
	[387184]={ class = "MONK", level = 53, },
	[152175]={ class = "MONK", level = 53, },
	[392993]={ class = "MONK", level = 53, },
	[389577]={ class = "MONK", level = 54, },
	[389578]={ class = "MONK", level = 54, },
	[389579]={ class = "MONK", level = 54, },
	[196736]={ class = "MONK", level = 55, },
	[397251]={ class = "MONK", level = 55, },
	[393400]={ class = "MONK", level = 55, },
	[322740]={ class = "MONK", level = 55, },
	[388661]={ class = "MONK", level = 55, },
	[392991]={ class = "MONK", level = 55, },
	[388779]={ class = "MONK", level = 57, },
	[394093]={ class = "MONK", level = 57, },
	[391412]={ class = "MONK", level = 57, },
	[388509]={ class = "MONK", level = 57, },
	[274909]={ class = "MONK", level = 57, },
	[383707]={ class = "MONK", level = 57, },
	[388517]={ class = "MONK", level = 57, },
	[393460]={ class = "MONK", level = 57, },
	[387991]={ class = "MONK", level = 57, },
	[388477]={ class = "MONK", level = 57, },
	[392994]={ class = "MONK", level = 57, },
	[115315]={ class = "MONK", level = 58, },
	[115313]={ class = "MONK", level = 58, },
	[388686]={ class = "MONK", level = 58, },
--++ Monk PvP Talents ++	
	[207025]={ class = "MONK", level = 20, },
	[287503]={ class = "MONK", level = 20, },
	[202577]={ class = "MONK", level = 20, },
	[205147]={ class = "MONK", level = 20, },
	[202370]={ class = "MONK", level = 20, },
	[353508]={ class = "MONK", level = 20, },
	[342928]={ class = "MONK", level = 20, },
	[287681]={ class = "MONK", level = 20, },
	[357633]={ class = "MONK", level = 20, },
	[209584]={ class = "MONK", level = 20, },
	[201372]={ class = "MONK", level = 21, },
	[357495]={ class = "MONK", level = 22, },
	[232876]={ class = "MONK", level = 23, },
	[205234]={ class = "MONK", level = 25, },
	[202424]={ class = "MONK", level = 27, },
	[202107]={ class = "MONK", level = 28, },
	[202272]={ class = "MONK", level = 29, },
	[353502]={ class = "MONK", level = 30, },
	[202126]={ class = "MONK", level = 30, },
	[247483]={ class = "MONK", level = 30, },
	[353584]={ class = "MONK", level = 32, },
	[201769]={ class = "MONK", level = 34, },
	[202200]={ class = "MONK", level = 34, },
	[353361]={ class = "MONK", level = 35, },
	[353936]={ class = "MONK", level = 35, },
	[345829]={ class = "MONK", level = 40, },
	[353313]={ class = "MONK", level = 49, },
	[355917]={ class = "MONK", level = 58, },
--++ Paladin Abilities ++	
	[137026]={ class = "PALADIN", level = 1, },
	[290608]={ class = "PALADIN", level = 1, },
	[23214]={ class = "PALADIN", level = 1, },
	[270562]={ class = "PALADIN", level = 1, },
	[270564]={ class = "PALADIN", level = 1, },
	[73629]={ class = "PALADIN", level = 1, },
	[73630]={ class = "PALADIN", level = 1, },
	[69826]={ class = "PALADIN", level = 1, },
	[363613]={ class = "PALADIN", level = 1, },
	[69820]={ class = "PALADIN", level = 1, },
	[34767]={ class = "PALADIN", level = 1, },
	[34769]={ class = "PALADIN", level = 1, },
	[13819]={ class = "PALADIN", level = 1, },
	[123830]={ class = "PALADIN", level = 1, },
	[115675]={ class = "PALADIN", level = 1, },
	[35395]={ class = "PALADIN", level = 1, },
	[82242]={ class = "PALADIN", level = 1, },
	[53600]={ class = "PALADIN", level = 2, },
	[20271]={ class = "PALADIN", level = 3, },
	[19750]={ class = "PALADIN", level = 4, },
	[85673]={ class = "PALADIN", level = 7, },
	[327977]={ class = "PALADIN", level = 8, },
	[121183]={ class = "PALADIN", level = 10, },
	[642]={ class = "PALADIN", level = 10, },
	[5502]={ class = "PALADIN", level = 10, },
	[7328]={ class = "PALADIN", level = 13, },
	[391054]={ class = "PALADIN", level = 19, },
	[317872]={ class = "PALADIN", level = 43, },
	[200327]={ class = "PALADIN", level = 47, },
	[327979]={ class = "PALADIN", level = 48, },
	[317911]={ class = "PALADIN", level = 49, },
	[317906]={ class = "PALADIN", level = 56, },
	[326730]={ class = "PALADIN", level = 58, },
--++ Paladin Artifact Traits ++	
	[207604]={ class = "PALADIN", level = 40, },
	[179546]={ class = "PALADIN", level = 40, },
	[209216]={ class = "PALADIN", level = 40, },
	[214081]={ class = "PALADIN", level = 40, },
	[193108]={ class = "PALADIN", level = 40, },
	[238133]={ class = "PALADIN", level = 40, },
	[238098]={ class = "PALADIN", level = 40, },
	[200298]={ class = "PALADIN", level = 40, },
	[241146]={ class = "PALADIN", level = 40, },
	[209218]={ class = "PALADIN", level = 40, },
	[238097]={ class = "PALADIN", level = 40, },
	[184778]={ class = "PALADIN", level = 40, },
	[186927]={ class = "PALADIN", level = 40, },
	[200294]={ class = "PALADIN", level = 40, },
	[186773]={ class = "PALADIN", level = 40, },
	[186788]={ class = "PALADIN", level = 40, },
	[186934]={ class = "PALADIN", level = 40, },
	[185086]={ class = "PALADIN", level = 40, },
	[200296]={ class = "PALADIN", level = 40, },
	[209225]={ class = "PALADIN", level = 40, },
	[211912]={ class = "PALADIN", level = 40, },
	[211913]={ class = "PALADIN", level = 40, },
	[211914]={ class = "PALADIN", level = 40, },
	[211915]={ class = "PALADIN", level = 40, },
	[211916]={ class = "PALADIN", level = 40, },
	[239295]={ class = "PALADIN", level = 40, },
	[239296]={ class = "PALADIN", level = 40, },
	[241147]={ class = "PALADIN", level = 40, },
	[200326]={ class = "PALADIN", level = 40, },
	[209376]={ class = "PALADIN", level = 40, },
	[209229]={ class = "PALADIN", level = 40, },
	[193058]={ class = "PALADIN", level = 40, },
	[186941]={ class = "PALADIN", level = 40, },
	[238061]={ class = "PALADIN", level = 40, },
	[238134]={ class = "PALADIN", level = 40, },
	[200316]={ class = "PALADIN", level = 40, },
	[200302]={ class = "PALADIN", level = 40, },
	[241145]={ class = "PALADIN", level = 40, },
	[209539]={ class = "PALADIN", level = 40, },
	[185368]={ class = "PALADIN", level = 40, },
	[209341]={ class = "PALADIN", level = 40, },
	[200407]={ class = "PALADIN", level = 40, },
	[186944]={ class = "PALADIN", level = 40, },
	[209224]={ class = "PALADIN", level = 40, },
	[184843]={ class = "PALADIN", level = 40, },
	[209226]={ class = "PALADIN", level = 40, },
	[213570]={ class = "PALADIN", level = 40, },
	[213571]={ class = "PALADIN", level = 40, },
	[213572]={ class = "PALADIN", level = 40, },
	[213573]={ class = "PALADIN", level = 40, },
	[213574]={ class = "PALADIN", level = 40, },
	[239293]={ class = "PALADIN", level = 40, },
	[239294]={ class = "PALADIN", level = 40, },
	[238062]={ class = "PALADIN", level = 40, },
	[238132]={ class = "PALADIN", level = 40, },
	[209285]={ class = "PALADIN", level = 40, },
	[209223]={ class = "PALADIN", level = 40, },
	[278074]={ class = "PALADIN", level = 40, },
	[278075]={ class = "PALADIN", level = 40, },
	[184759]={ class = "PALADIN", level = 40, },
	[200315]={ class = "PALADIN", level = 40, },
	[214923]={ class = "PALADIN", level = 40, },
	[209217]={ class = "PALADIN", level = 40, },
	[238096]={ class = "PALADIN", level = 40, },
	[200311]={ class = "PALADIN", level = 40, },
	[200421]={ class = "PALADIN", level = 40, },
	[221841]={ class = "PALADIN", level = 40, },
	[209474]={ class = "PALADIN", level = 40, },
	[238060]={ class = "PALADIN", level = 40, },
	[182234]={ class = "PALADIN", level = 40, },
	[209220]={ class = "PALADIN", level = 40, },
	[214924]={ class = "PALADIN", level = 40, },
	[200373]={ class = "PALADIN", level = 40, },
	[222648]={ class = "PALADIN", level = 40, },
	[186945]={ class = "PALADIN", level = 40, },
--++ Paladin Azerite Traits ++	
	[272904]={ class = "PALADIN", level = 45, },
	[278594]={ class = "PALADIN", level = 45, },
	[279406]={ class = "PALADIN", level = 45, },
	[272976]={ class = "PALADIN", level = 45, },
	[272977]={ class = "PALADIN", level = 45, },
	[272979]={ class = "PALADIN", level = 45, },
	[269243]={ class = "PALADIN", level = 45, },
	[275463]={ class = "PALADIN", level = 45, },
	[275466]={ class = "PALADIN", level = 45, },
	[275468]={ class = "PALADIN", level = 45, },
	[287730]={ class = "PALADIN", level = 45, },
	[286392]={ class = "PALADIN", level = 45, },
	[286393]={ class = "PALADIN", level = 45, },
	[273476]={ class = "PALADIN", level = 45, },
	[273134]={ class = "PALADIN", level = 45, },
	[280189]={ class = "PALADIN", level = 45, },
	[287268]={ class = "PALADIN", level = 45, },
	[287269]={ class = "PALADIN", level = 45, },
	[278784]={ class = "PALADIN", level = 45, },
	[273142]={ class = "PALADIN", level = 45, },
	[273130]={ class = "PALADIN", level = 45, },
	[279387]={ class = "PALADIN", level = 45, },
	[92322]={ class = "PALADIN", level = 45, },
	[278573]={ class = "PALADIN", level = 45, },
	[286229]={ class = "PALADIN", level = 45, },
	[286231]={ class = "PALADIN", level = 45, },
	[278138]={ class = "PALADIN", level = 45, },
	[278142]={ class = "PALADIN", level = 45, },
	[273131]={ class = "PALADIN", level = 45, },
	[279201]={ class = "PALADIN", level = 45, },
	[269245]={ class = "PALADIN", level = 45, },
	[287126]={ class = "PALADIN", level = 45, },
	[273140]={ class = "PALADIN", level = 45, },
	[278951]={ class = "PALADIN", level = 45, },
	[274391]={ class = "PALADIN", level = 45, },
	[269262]={ class = "PALADIN", level = 45, },
	[270596]={ class = "PALADIN", level = 45, },
--++ Paladin Covenant Abilities ++	
	[304971]={ class = "PALADIN", level = 48, },
	[316958]={ class = "PALADIN", level = 48, },
	[317221]={ class = "PALADIN", level = 48, },
	[328278]={ class = "PALADIN", level = 48, },
--++ Paladin Conduit Abilities ++	
	[338741]={ class = "PALADIN", level = 60, },
	[339316]={ class = "PALADIN", level = 60, },
	[339570]={ class = "PALADIN", level = 60, },
	[339371]={ class = "PALADIN", level = 60, },
	[339984]={ class = "PALADIN", level = 60, },
	[339114]={ class = "PALADIN", level = 60, },
	[340212]={ class = "PALADIN", level = 60, },
	[340214]={ class = "PALADIN", level = 60, },
	[339268]={ class = "PALADIN", level = 60, },
	[340012]={ class = "PALADIN", level = 60, },
	[339124]={ class = "PALADIN", level = 60, },
	[340023]={ class = "PALADIN", level = 60, },
	[339712]={ class = "PALADIN", level = 60, },
	[340192]={ class = "PALADIN", level = 60, },
	[340218]={ class = "PALADIN", level = 60, },
	[340030]={ class = "PALADIN", level = 60, },
	[338787]={ class = "PALADIN", level = 60, },
	[338788]={ class = "PALADIN", level = 60, },
	[339531]={ class = "PALADIN", level = 60, },
	[340185]={ class = "PALADIN", level = 60, },
	[339374]={ class = "PALADIN", level = 60, },
	[339987]={ class = "PALADIN", level = 60, },
	[340006]={ class = "PALADIN", level = 60, },
	[339518]={ class = "PALADIN", level = 60, },
	[339664]={ class = "PALADIN", level = 60, },
	[339669]={ class = "PALADIN", level = 60, },
	[339292]={ class = "PALADIN", level = 60, },
--++ Paladin Specializations ++	
	[137029]={ class = "PALADIN", level = 1, },
	[137028]={ class = "PALADIN", level = 1, },
	[137027]={ class = "PALADIN", level = 1, },
	[344172]={ class = "PALADIN", level = 1, },
	[275773]={ class = "PALADIN", level = 1, },
	[315867]={ class = "PALADIN", level = 1, },
	[317907]={ class = "PALADIN", level = 1, },
	[275779]={ class = "PALADIN", level = 3, },
	[4987]={ class = "PALADIN", level = 10, },
	[289941]={ class = "PALADIN", level = 10, },
	[76671]={ class = "PALADIN", level = 10, },
	[267316]={ class = "PALADIN", level = 10, },
	[183997]={ class = "PALADIN", level = 10, },
	[25780]={ class = "PALADIN", level = 10, },
	[105805]={ class = "PALADIN", level = 10, },
	[85256]={ class = "PALADIN", level = 10, },
	[342348]={ class = "PALADIN", level = 11, },
	[353367]={ class = "PALADIN", level = 15, },
	[53563]={ class = "PALADIN", level = 16, },
	[272906]={ class = "PALADIN", level = 18, },
	[327980]={ class = "PALADIN", level = 23, },
	[53576]={ class = "PALADIN", level = 23, },
	[86102]={ class = "PALADIN", level = 27, },
	[86103]={ class = "PALADIN", level = 27, },
	[86539]={ class = "PALADIN", level = 27, },
	[315921]={ class = "PALADIN", level = 34, },
	[358934]={ class = "PALADIN", level = 36, },
	[212056]={ class = "PALADIN", level = 44, },
	[161800]={ class = "PALADIN", level = 48, },
--++ Paladin Talents ++	
	[385633]={ class = "PALADIN", level = 10, },
	[115750]={ class = "PALADIN", level = 10, },
	[190784]={ class = "PALADIN", level = 10, },
	[234299]={ class = "PALADIN", level = 10, },
	[24275]={ class = "PALADIN", level = 10, },
	[633]={ class = "PALADIN", level = 10, },
	[184575]={ class = "PALADIN", level = 11, },
	[327981]={ class = "PALADIN", level = 11, },
	[20473]={ class = "PALADIN", level = 11, },
	[385639]={ class = "PALADIN", level = 12, },
	[230332]={ class = "PALADIN", level = 12, },
	[393024]={ class = "PALADIN", level = 12, },
	[377016]={ class = "PALADIN", level = 12, },
	[376996]={ class = "PALADIN", level = 12, },
	[267344]={ class = "PALADIN", level = 13, },
	[317912]={ class = "PALADIN", level = 13, },
	[204019]={ class = "PALADIN", level = 13, },
	[53385]={ class = "PALADIN", level = 13, },
	[53595]={ class = "PALADIN", level = 13, },
	[82326]={ class = "PALADIN", level = 13, },
	[386568]={ class = "PALADIN", level = 13, },
	[85222]={ class = "PALADIN", level = 13, },
	[280373]={ class = "PALADIN", level = 13, },
	[213644]={ class = "PALADIN", level = 14, },
	[231663]={ class = "PALADIN", level = 14, },
	[383263]={ class = "PALADIN", level = 15, },
	[392914]={ class = "PALADIN", level = 15, },
	[498]={ class = "PALADIN", level = 15, },
	[85043]={ class = "PALADIN", level = 15, },
	[383342]={ class = "PALADIN", level = 15, },
	[386967]={ class = "PALADIN", level = 15, },
	[152261]={ class = "PALADIN", level = 15, },
	[387993]={ class = "PALADIN", level = 15, },
	[383254]={ class = "PALADIN", level = 15, },
	[383228]={ class = "PALADIN", level = 15, },
	[321136]={ class = "PALADIN", level = 15, },
	[387998]={ class = "PALADIN", level = 15, },
	[31850]={ class = "PALADIN", level = 17, },
	[31821]={ class = "PALADIN", level = 17, },
	[385726]={ class = "PALADIN", level = 17, },
	[231832]={ class = "PALADIN", level = 17, },
	[204054]={ class = "PALADIN", level = 17, },
	[379022]={ class = "PALADIN", level = 17, },
	[387791]={ class = "PALADIN", level = 17, },
	[326732]={ class = "PALADIN", level = 17, },
	[393027]={ class = "PALADIN", level = 17, },
	[393022]={ class = "PALADIN", level = 17, },
	[387786]={ class = "PALADIN", level = 17, },
	[392902]={ class = "PALADIN", level = 17, },
	[214202]={ class = "PALADIN", level = 17, },
	[392928]={ class = "PALADIN", level = 17, },
	[231644]={ class = "PALADIN", level = 18, },
	[384376]={ class = "PALADIN", level = 26, },
	[377128]={ class = "PALADIN", level = 26, },
	[385515]={ class = "PALADIN", level = 26, },
	[96231]={ class = "PALADIN", level = 26, },
	[209389]={ class = "PALADIN", level = 27, },
	[382275]={ class = "PALADIN", level = 27, },
	[380188]={ class = "PALADIN", level = 27, },
	[210294]={ class = "PALADIN", level = 27, },
	[383344]={ class = "PALADIN", level = 27, },
	[383271]={ class = "PALADIN", level = 27, },
	[392961]={ class = "PALADIN", level = 27, },
	[393114]={ class = "PALADIN", level = 27, },
	[393030]={ class = "PALADIN", level = 27, },
	[378405]={ class = "PALADIN", level = 27, },
	[200430]={ class = "PALADIN", level = 27, },
	[231667]={ class = "PALADIN", level = 27, },
	[267610]={ class = "PALADIN", level = 27, },
	[382536]={ class = "PALADIN", level = 27, },
	[379021]={ class = "PALADIN", level = 27, },
	[386901]={ class = "PALADIN", level = 27, },
	[388005]={ class = "PALADIN", level = 27, },
	[393071]={ class = "PALADIN", level = 27, },
	[231642]={ class = "PALADIN", level = 27, },
	[378285]={ class = "PALADIN", level = 27, },
	[392911]={ class = "PALADIN", level = 27, },
	[385414]={ class = "PALADIN", level = 28, },
	[384897]={ class = "PALADIN", level = 28, },
	[377053]={ class = "PALADIN", level = 28, },
	[383300]={ class = "PALADIN", level = 29, },
	[387781]={ class = "PALADIN", level = 29, },
	[231895]={ class = "PALADIN", level = 29, },
	[384392]={ class = "PALADIN", level = 29, },
	[387805]={ class = "PALADIN", level = 29, },
	[387808]={ class = "PALADIN", level = 29, },
	[387801]={ class = "PALADIN", level = 29, },
	[203316]={ class = "PALADIN", level = 29, },
	[114165]={ class = "PALADIN", level = 29, },
	[383334]={ class = "PALADIN", level = 29, },
	[183998]={ class = "PALADIN", level = 29, },
	[114158]={ class = "PALADIN", level = 29, },
	[384052]={ class = "PALADIN", level = 29, },
	[385422]={ class = "PALADIN", level = 29, },
	[382430]={ class = "PALADIN", level = 29, },
	[157047]={ class = "PALADIN", level = 29, },
	[387640]={ class = "PALADIN", level = 29, },
	[200482]={ class = "PALADIN", level = 29, },
	[385438]={ class = "PALADIN", level = 29, },
	[389539]={ class = "PALADIN", level = 29, },
	[379008]={ class = "PALADIN", level = 29, },
	[383350]={ class = "PALADIN", level = 29, },
	[387814]={ class = "PALADIN", level = 29, },
	[378425]={ class = "PALADIN", level = 29, },
	[269569]={ class = "PALADIN", level = 29, },
	[384909]={ class = "PALADIN", level = 30, },
	[385464]={ class = "PALADIN", level = 30, },
	[183778]={ class = "PALADIN", level = 30, },
	[384914]={ class = "PALADIN", level = 30, },
	[384820]={ class = "PALADIN", level = 30, },
	[385349]={ class = "PALADIN", level = 30, },
	[114154]={ class = "PALADIN", level = 30, },
	[383876]={ class = "PALADIN", level = 31, },
	[383185]={ class = "PALADIN", level = 31, },
	[86659]={ class = "PALADIN", level = 31, },
	[315924]={ class = "PALADIN", level = 31, },
	[326734]={ class = "PALADIN", level = 31, },
	[215661]={ class = "PALADIN", level = 31, },
	[383388]={ class = "PALADIN", level = 31, },
	[387479]={ class = "PALADIN", level = 31, },
	[85804]={ class = "PALADIN", level = 31, },
	[383396]={ class = "PALADIN", level = 31, },
	[378974]={ class = "PALADIN", level = 33, },
	[204023]={ class = "PALADIN", level = 33, },
	[385416]={ class = "PALADIN", level = 50, },
	[223817]={ class = "PALADIN", level = 50, },
	[377043]={ class = "PALADIN", level = 50, },
	[105809]={ class = "PALADIN", level = 50, },
	[385427]={ class = "PALADIN", level = 50, },
	[384815]={ class = "PALADIN", level = 50, },
	[383276]={ class = "PALADIN", level = 51, },
	[216331]={ class = "PALADIN", level = 51, },
	[394088]={ class = "PALADIN", level = 51, },
	[384442]={ class = "PALADIN", level = 51, },
	[387879]={ class = "PALADIN", level = 51, },
	[375576]={ class = "PALADIN", level = 51, },
	[379043]={ class = "PALADIN", level = 51, },
	[378845]={ class = "PALADIN", level = 51, },
	[378279]={ class = "PALADIN", level = 51, },
	[388018]={ class = "PALADIN", level = 51, },
	[200474]={ class = "PALADIN", level = 51, },
	[204074]={ class = "PALADIN", level = 51, },
	[378457]={ class = "PALADIN", level = 51, },
	[383274]={ class = "PALADIN", level = 51, },
	[392938]={ class = "PALADIN", level = 51, },
	[385425]={ class = "PALADIN", level = 52, },
	[385450]={ class = "PALADIN", level = 52, },
	[248033]={ class = "PALADIN", level = 53, },
	[196926]={ class = "PALADIN", level = 53, },
	[387893]={ class = "PALADIN", level = 53, },
	[379017]={ class = "PALADIN", level = 53, },
	[378762]={ class = "PALADIN", level = 53, },
	[204077]={ class = "PALADIN", level = 53, },
	[385125]={ class = "PALADIN", level = 54, },
	[392951]={ class = "PALADIN", level = 55, },
	[386653]={ class = "PALADIN", level = 55, },
	[387170]={ class = "PALADIN", level = 55, },
	[383327]={ class = "PALADIN", level = 55, },
	[383328]={ class = "PALADIN", level = 55, },
	[325966]={ class = "PALADIN", level = 55, },
	[383304]={ class = "PALADIN", level = 55, },
	[53376]={ class = "PALADIN", level = 56, },
	[171648]={ class = "PALADIN", level = 56, },
	[317866]={ class = "PALADIN", level = 56, },
	[385129]={ class = "PALADIN", level = 56, },
	[152262]={ class = "PALADIN", level = 56, },
	[391142]={ class = "PALADIN", level = 56, },
	[384027]={ class = "PALADIN", level = 57, },
	[386738]={ class = "PALADIN", level = 57, },
	[384162]={ class = "PALADIN", level = 57, },
	[387196]={ class = "PALADIN", level = 57, },
	[392907]={ class = "PALADIN", level = 57, },
	[327193]={ class = "PALADIN", level = 57, },
	[379391]={ class = "PALADIN", level = 57, },
	[383314]={ class = "PALADIN", level = 57, },
--++ Paladin PvP Talents ++	
	[199441]={ class = "PALADIN", level = 20, },
	[204914]={ class = "PALADIN", level = 20, },
	[216855]={ class = "PALADIN", level = 20, },
	[216868]={ class = "PALADIN", level = 20, },
	[207028]={ class = "PALADIN", level = 20, },
	[204979]={ class = "PALADIN", level = 20, },
	[246806]={ class = "PALADIN", level = 20, },
	[216327]={ class = "PALADIN", level = 20, },
	[199542]={ class = "PALADIN", level = 20, },
	[210341]={ class = "PALADIN", level = 20, },
	[305394]={ class = "PALADIN", level = 22, },
	[355858]={ class = "PALADIN", level = 23, },
	[210323]={ class = "PALADIN", level = 24, },
	[199428]={ class = "PALADIN", level = 25, },
	[199456]={ class = "PALADIN", level = 25, },
	[199330]={ class = "PALADIN", level = 27, },
	[247675]={ class = "PALADIN", level = 30, },
	[199454]={ class = "PALADIN", level = 30, },
	[216853]={ class = "PALADIN", level = 32, },
	[210378]={ class = "PALADIN", level = 34, },
	[355614]={ class = "PALADIN", level = 38, },
	[199324]={ class = "PALADIN", level = 39, },
	[228049]={ class = "PALADIN", level = 40, },
	[204934]={ class = "PALADIN", level = 40, },
	[199452]={ class = "PALADIN", level = 41, },
--++ Priest Abilities ++	
	[137030]={ class = "PRIEST", level = 1, },
	[392941]={ class = "PRIEST", level = 1, },
	[585]={ class = "PRIEST", level = 1, },
	[2061]={ class = "PRIEST", level = 3, },
	[8092]={ class = "PRIEST", level = 5, },
	[19236]={ class = "PRIEST", level = 8, },
	[586]={ class = "PRIEST", level = 9, },
	[2006]={ class = "PRIEST", level = 10, },
	[45243]={ class = "PRIEST", level = 16, },
	[327821]={ class = "PRIEST", level = 17, },
	[228266]={ class = "PRIEST", level = 23, },
	[228264]={ class = "PRIEST", level = 23, },
--++ Priest Artifact Traits ++	
	[219655]={ class = "PRIEST", level = 40, },
	[197815]={ class = "PRIEST", level = 40, },
	[214926]={ class = "PRIEST", level = 40, },
	[196578]={ class = "PRIEST", level = 40, },
	[197762]={ class = "PRIEST", level = 40, },
	[197716]={ class = "PRIEST", level = 40, },
	[193371]={ class = "PRIEST", level = 40, },
	[238064]={ class = "PRIEST", level = 40, },
	[197708]={ class = "PRIEST", level = 40, },
	[194002]={ class = "PRIEST", level = 40, },
	[214927]={ class = "PRIEST", level = 40, },
	[216212]={ class = "PRIEST", level = 40, },
	[241150]={ class = "PRIEST", level = 40, },
	[193645]={ class = "PRIEST", level = 40, },
	[197727]={ class = "PRIEST", level = 40, },
	[238065]={ class = "PRIEST", level = 40, },
	[196419]={ class = "PRIEST", level = 40, },
	[222646]={ class = "PRIEST", level = 40, },
	[214925]={ class = "PRIEST", level = 40, },
	[193642]={ class = "PRIEST", level = 40, },
	[196429]={ class = "PRIEST", level = 40, },
	[196434]={ class = "PRIEST", level = 40, },
	[196422]={ class = "PRIEST", level = 40, },
	[196779]={ class = "PRIEST", level = 40, },
	[216122]={ class = "PRIEST", level = 40, },
	[196684]={ class = "PRIEST", level = 40, },
	[238137]={ class = "PRIEST", level = 40, },
	[277906]={ class = "PRIEST", level = 40, },
	[208065]={ class = "PRIEST", level = 40, },
	[241149]={ class = "PRIEST", level = 40, },
	[207946]={ class = "PRIEST", level = 40, },
	[194378]={ class = "PRIEST", level = 40, },
	[194018]={ class = "PRIEST", level = 40, },
	[238101]={ class = "PRIEST", level = 40, },
	[193643]={ class = "PRIEST", level = 40, },
	[197713]={ class = "PRIEST", level = 40, },
	[277905]={ class = "PRIEST", level = 40, },
	[196492]={ class = "PRIEST", level = 40, },
	[196418]={ class = "PRIEST", level = 40, },
	[196358]={ class = "PRIEST", level = 40, },
	[196416]={ class = "PRIEST", level = 40, },
	[197781]={ class = "PRIEST", level = 40, },
	[197729]={ class = "PRIEST", level = 40, },
	[194026]={ class = "PRIEST", level = 40, },
	[198074]={ class = "PRIEST", level = 40, },
	[197766]={ class = "PRIEST", level = 40, },
	[194179]={ class = "PRIEST", level = 40, },
	[197779]={ class = "PRIEST", level = 40, },
	[197715]={ class = "PRIEST", level = 40, },
	[193647]={ class = "PRIEST", level = 40, },
	[194024]={ class = "PRIEST", level = 40, },
	[281390]={ class = "PRIEST", level = 40, },
	[193644]={ class = "PRIEST", level = 40, },
	[194007]={ class = "PRIEST", level = 40, },
	[196355]={ class = "PRIEST", level = 40, },
	[238099]={ class = "PRIEST", level = 40, },
	[194093]={ class = "PRIEST", level = 40, },
	[197711]={ class = "PRIEST", level = 40, },
	[194016]={ class = "PRIEST", level = 40, },
	[215322]={ class = "PRIEST", level = 40, },
	[241148]={ class = "PRIEST", level = 40, },
	[196430]={ class = "PRIEST", level = 40, },
--++ Priest Azerite Traits ++	
	[269561]={ class = "PRIEST", level = 45, },
	[270649]={ class = "PRIEST", level = 45, },
	[273313]={ class = "PRIEST", level = 45, },
	[278661]={ class = "PRIEST", level = 45, },
	[278629]={ class = "PRIEST", level = 45, },
	[278904]={ class = "PRIEST", level = 45, },
	[313267]={ class = "PRIEST", level = 45, },
	[287717]={ class = "PRIEST", level = 45, },
	[287719]={ class = "PRIEST", level = 45, },
	[278659]={ class = "PRIEST", level = 45, },
	[275541]={ class = "PRIEST", level = 45, },
	[275542]={ class = "PRIEST", level = 45, },
	[275544]={ class = "PRIEST", level = 45, },
	[278643]={ class = "PRIEST", level = 45, },
	[279245]={ class = "PRIEST", level = 45, },
	[277681]={ class = "PRIEST", level = 45, },
	[272775]={ class = "PRIEST", level = 45, },
	[272780]={ class = "PRIEST", level = 45, },
	[272782]={ class = "PRIEST", level = 45, },
	[275602]={ class = "PRIEST", level = 45, },
	[287336]={ class = "PRIEST", level = 45, },
	[287337]={ class = "PRIEST", level = 45, },
	[287340]={ class = "PRIEST", level = 45, },
	[274366]={ class = "PRIEST", level = 45, },
	[274368]={ class = "PRIEST", level = 45, },
	[274369]={ class = "PRIEST", level = 45, },
	[272788]={ class = "PRIEST", level = 45, },
	[277682]={ class = "PRIEST", level = 45, },
	[287355]={ class = "PRIEST", level = 45, },
	[287356]={ class = "PRIEST", level = 45, },
	[287360]={ class = "PRIEST", level = 45, },
	[288340]={ class = "PRIEST", level = 45, },
	[288342]={ class = "PRIEST", level = 45, },
	[288343]={ class = "PRIEST", level = 45, },
	[269555]={ class = "PRIEST", level = 45, },
	[273307]={ class = "PRIEST", level = 45, },
	[273308]={ class = "PRIEST", level = 45, },
	[275722]={ class = "PRIEST", level = 45, },
	[275725]={ class = "PRIEST", level = 45, },
	[275726]={ class = "PRIEST", level = 45, },
	[278645]={ class = "PRIEST", level = 45, },
--++ Priest Covenant Abilities ++	
	[327661]={ class = "PRIEST", level = 48, },
--++ Priest Conduit Abilities ++	
	[337715]={ class = "PRIEST", level = 60, },
	[337707]={ class = "PRIEST", level = 60, },
	[337966]={ class = "PRIEST", level = 60, },
	[338342]={ class = "PRIEST", level = 60, },
	[337790]={ class = "PRIEST", level = 60, },
	[338305]={ class = "PRIEST", level = 60, },
	[337979]={ class = "PRIEST", level = 60, },
	[337914]={ class = "PRIEST", level = 60, },
	[338319]={ class = "PRIEST", level = 60, },
	[338345]={ class = "PRIEST", level = 60, },
	[337811]={ class = "PRIEST", level = 60, },
	[337748]={ class = "PRIEST", level = 60, },
	[337954]={ class = "PRIEST", level = 60, },
	[338332]={ class = "PRIEST", level = 60, },
	[337678]={ class = "PRIEST", level = 60, },
	[337786]={ class = "PRIEST", level = 60, },
	[337762]={ class = "PRIEST", level = 60, },
	[338338]={ class = "PRIEST", level = 60, },
	[337947]={ class = "PRIEST", level = 60, },
	[338315]={ class = "PRIEST", level = 60, },
	[337778]={ class = "PRIEST", level = 60, },
	[337891]={ class = "PRIEST", level = 60, },
	[337662]={ class = "PRIEST", level = 60, },
--++ Priest Specializations ++	
	[137032]={ class = "PRIEST", level = 1, },
	[137031]={ class = "PRIEST", level = 1, },
	[137033]={ class = "PRIEST", level = 1, },
	[397527]={ class = "PRIEST", level = 1, },
	[280752]={ class = "PRIEST", level = 10, },
	[77485]={ class = "PRIEST", level = 10, },
	[271534]={ class = "PRIEST", level = 10, },
	[343690]={ class = "PRIEST", level = 10, },
	[527]={ class = "PRIEST", level = 10, },
	[232698]={ class = "PRIEST", level = 10, },
	[47540]={ class = "PRIEST", level = 11, },
	[280391]={ class = "PRIEST", level = 12, },
	[2060]={ class = "PRIEST", level = 15, },
	[63733]={ class = "PRIEST", level = 26, },
	[20711]={ class = "PRIEST", level = 29, },
	[212036]={ class = "PRIEST", level = 37, },
--++ Priest Talents ++	
	[390767]={ class = "PRIEST", level = 10, },
	[321291]={ class = "PRIEST", level = 10, },
	[528]={ class = "PRIEST", level = 10, },
	[372354]={ class = "PRIEST", level = 10, },
	[132157]={ class = "PRIEST", level = 10, },
	[393870]={ class = "PRIEST", level = 10, },
	[108942]={ class = "PRIEST", level = 10, },
	[33076]={ class = "PRIEST", level = 10, },
	[196704]={ class = "PRIEST", level = 10, },
	[32379]={ class = "PRIEST", level = 10, },
	[34433]={ class = "PRIEST", level = 10, },
	[390667]={ class = "PRIEST", level = 10, },
	[81749]={ class = "PRIEST", level = 11, },
	[2050]={ class = "PRIEST", level = 11, },
	[121536]={ class = "PRIEST", level = 12, },
	[390615]={ class = "PRIEST", level = 12, },
	[390632]={ class = "PRIEST", level = 12, },
	[193063]={ class = "PRIEST", level = 12, },
	[213634]={ class = "PRIEST", level = 12, },
	[390622]={ class = "PRIEST", level = 12, },
	[390919]={ class = "PRIEST", level = 12, },
	[47585]={ class = "PRIEST", level = 13, },
	[88625]={ class = "PRIEST", level = 13, },
	[198068]={ class = "PRIEST", level = 13, },
	[194509]={ class = "PRIEST", level = 13, },
	[596]={ class = "PRIEST", level = 13, },
	[341491]={ class = "PRIEST", level = 13, },
	[372307]={ class = "PRIEST", level = 15, },
	[200199]={ class = "PRIEST", level = 15, },
	[238136]={ class = "PRIEST", level = 15, },
	[372972]={ class = "PRIEST", level = 15, },
	[263346]={ class = "PRIEST", level = 15, },
	[200209]={ class = "PRIEST", level = 15, },
	[196437]={ class = "PRIEST", level = 15, },
	[34861]={ class = "PRIEST", level = 15, },
	[288733]={ class = "PRIEST", level = 15, },
	[263716]={ class = "PRIEST", level = 15, },
	[322115]={ class = "PRIEST", level = 15, },
	[391079]={ class = "PRIEST", level = 15, },
	[377065]={ class = "PRIEST", level = 15, },
	[238558]={ class = "PRIEST", level = 15, },
	[372991]={ class = "PRIEST", level = 15, },
	[373035]={ class = "PRIEST", level = 16, },
	[196707]={ class = "PRIEST", level = 17, },
	[390684]={ class = "PRIEST", level = 17, },
	[204883]={ class = "PRIEST", level = 17, },
	[391242]={ class = "PRIEST", level = 17, },
	[372616]={ class = "PRIEST", level = 17, },
	[390685]={ class = "PRIEST", level = 17, },
	[372969]={ class = "PRIEST", level = 17, },
	[73510]={ class = "PRIEST", level = 17, },
	[390686]={ class = "PRIEST", level = 17, },
	[62618]={ class = "PRIEST", level = 17, },
	[129250]={ class = "PRIEST", level = 17, },
	[341997]={ class = "PRIEST", level = 17, },
	[391208]={ class = "PRIEST", level = 17, },
	[196489]={ class = "PRIEST", level = 17, },
	[197045]={ class = "PRIEST", level = 17, },
	[390668]={ class = "PRIEST", level = 26, },
	[390676]={ class = "PRIEST", level = 26, },
	[32375]={ class = "PRIEST", level = 26, },
	[390620]={ class = "PRIEST", level = 26, },
	[373223]={ class = "PRIEST", level = 26, },
	[377438]={ class = "PRIEST", level = 26, },
	[193157]={ class = "PRIEST", level = 27, },
	[391109]={ class = "PRIEST", level = 27, },
	[193155]={ class = "PRIEST", level = 27, },
	[390881]={ class = "PRIEST", level = 27, },
	[391154]={ class = "PRIEST", level = 27, },
	[375994]={ class = "PRIEST", level = 27, },
	[321377]={ class = "PRIEST", level = 27, },
	[391209]={ class = "PRIEST", level = 27, },
	[377387]={ class = "PRIEST", level = 27, },
	[204197]={ class = "PRIEST", level = 27, },
	[314867]={ class = "PRIEST", level = 27, },
	[162448]={ class = "PRIEST", level = 27, },
	[200128]={ class = "PRIEST", level = 27, },
	[341273]={ class = "PRIEST", level = 27, },
	[64129]={ class = "PRIEST", level = 28, },
	[341167]={ class = "PRIEST", level = 28, },
	[199855]={ class = "PRIEST", level = 28, },
	[377422]={ class = "PRIEST", level = 28, },
	[373466]={ class = "PRIEST", level = 28, },
	[373456]={ class = "PRIEST", level = 28, },
	[228260]={ class = "PRIEST", level = 28, },
	[280749]={ class = "PRIEST", level = 28, },
	[341240]={ class = "PRIEST", level = 29, },
	[197419]={ class = "PRIEST", level = 29, },
	[390954]={ class = "PRIEST", level = 29, },
	[391233]={ class = "PRIEST", level = 29, },
	[372985]={ class = "PRIEST", level = 29, },
	[391161]={ class = "PRIEST", level = 29, },
	[373042]={ class = "PRIEST", level = 29, },
	[372370]={ class = "PRIEST", level = 29, },
	[391296]={ class = "PRIEST", level = 29, },
	[373049]={ class = "PRIEST", level = 29, },
	[391090]={ class = "PRIEST", level = 29, },
	[390947]={ class = "PRIEST", level = 29, },
	[390689]={ class = "PRIEST", level = 29, },
	[373003]={ class = "PRIEST", level = 29, },
	[205385]={ class = "PRIEST", level = 29, },
	[375888]={ class = "PRIEST", level = 29, },
	[373065]={ class = "PRIEST", level = 29, },
	[390972]={ class = "PRIEST", level = 30, },
	[390691]={ class = "PRIEST", level = 31, },
	[193134]={ class = "PRIEST", level = 31, },
	[391095]={ class = "PRIEST", level = 31, },
	[391228]={ class = "PRIEST", level = 31, },
	[390977]={ class = "PRIEST", level = 31, },
	[390967]={ class = "PRIEST", level = 31, },
	[199484]={ class = "PRIEST", level = 31, },
	[373054]={ class = "PRIEST", level = 31, },
	[391137]={ class = "PRIEST", level = 31, },
	[155271]={ class = "PRIEST", level = 33, },
	[391284]={ class = "PRIEST", level = 33, },
	[238100]={ class = "PRIEST", level = 50, },
	[368275]={ class = "PRIEST", level = 50, },
	[110744]={ class = "PRIEST", level = 50, },
	[122121]={ class = "PRIEST", level = 50, },
	[120517]={ class = "PRIEST", level = 50, },
	[120644]={ class = "PRIEST", level = 50, },
	[373446]={ class = "PRIEST", level = 50, },
	[200183]={ class = "PRIEST", level = 51, },
	[341374]={ class = "PRIEST", level = 51, },
	[392507]={ class = "PRIEST", level = 51, },
	[391339]={ class = "PRIEST", level = 51, },
	[391235]={ class = "PRIEST", level = 51, },
	[246287]={ class = "PRIEST", level = 51, },
	[265202]={ class = "PRIEST", level = 51, },
	[238063]={ class = "PRIEST", level = 51, },
	[373178]={ class = "PRIEST", level = 51, },
	[391399]={ class = "PRIEST", level = 51, },
	[123040]={ class = "PRIEST", level = 51, },
	[200174]={ class = "PRIEST", level = 51, },
	[390980]={ class = "PRIEST", level = 51, },
	[391368]={ class = "PRIEST", level = 51, },
	[391186]={ class = "PRIEST", level = 51, },
	[390693]={ class = "PRIEST", level = 51, },
	[373457]={ class = "PRIEST", level = 52, },
	[390670]={ class = "PRIEST", level = 52, },
	[373450]={ class = "PRIEST", level = 52, },
	[390996]={ class = "PRIEST", level = 52, },
	[109186]={ class = "PRIEST", level = 52, },
	[391387]={ class = "PRIEST", level = 53, },
	[215768]={ class = "PRIEST", level = 53, },
	[391381]={ class = "PRIEST", level = 53, },
	[47515]={ class = "PRIEST", level = 53, },
	[390832]={ class = "PRIEST", level = 53, },
	[390994]={ class = "PRIEST", level = 53, },
	[373180]={ class = "PRIEST", level = 53, },
	[373427]={ class = "PRIEST", level = 53, },
	[373212]={ class = "PRIEST", level = 53, },
	[196985]={ class = "PRIEST", level = 53, },
	[373221]={ class = "PRIEST", level = 53, },
	[373202]={ class = "PRIEST", level = 53, },
	[391288]={ class = "PRIEST", level = 53, },
	[372309]={ class = "PRIEST", level = 53, },
	[390765]={ class = "PRIEST", level = 53, },
	[375767]={ class = "PRIEST", level = 53, },
	[372611]={ class = "PRIEST", level = 53, },
	[108945]={ class = "PRIEST", level = 56, },
	[373481]={ class = "PRIEST", level = 56, },
	[391112]={ class = "PRIEST", level = 56, },
	[108968]={ class = "PRIEST", level = 56, },
	[238135]={ class = "PRIEST", level = 57, },
	[392988]={ class = "PRIEST", level = 57, },
	[372760]={ class = "PRIEST", level = 57, },
	[377349]={ class = "PRIEST", level = 57, },
	[373280]={ class = "PRIEST", level = 57, },
	[373273]={ class = "PRIEST", level = 57, },
	[373310]={ class = "PRIEST", level = 57, },
	[390992]={ class = "PRIEST", level = 57, },
	[372835]={ class = "PRIEST", level = 57, },
	[235587]={ class = "PRIEST", level = 57, },
	[391124]={ class = "PRIEST", level = 57, },
	[390705]={ class = "PRIEST", level = 57, },
	[390770]={ class = "PRIEST", level = 57, },
	[390786]={ class = "PRIEST", level = 57, },
	[390781]={ class = "PRIEST", level = 57, },
--++ Priest PvP Talents ++	
	[197862]={ class = "PRIEST", level = 20, },
	[197871]={ class = "PRIEST", level = 20, },
	[289666]={ class = "PRIEST", level = 20, },
	[213610]={ class = "PRIEST", level = 20, },
	[199445]={ class = "PRIEST", level = 20, },
	[211522]={ class = "PRIEST", level = 20, },
	[196162]={ class = "PRIEST", level = 20, },
	[196439]={ class = "PRIEST", level = 20, },
	[197535]={ class = "PRIEST", level = 20, },
	[214205]={ class = "PRIEST", level = 20, },
	[328530]={ class = "PRIEST", level = 22, },
	[199259]={ class = "PRIEST", level = 23, },
	[236499]={ class = "PRIEST", level = 23, },
	[228630]={ class = "PRIEST", level = 23, },
	[215982]={ class = "PRIEST", level = 29, },
	[356085]={ class = "PRIEST", level = 35, },
	[357711]={ class = "PRIEST", level = 40, },
	[357481]={ class = "PRIEST", level = 41, },
	[328529]={ class = "PRIEST", level = 43, },
	[197590]={ class = "PRIEST", level = 44, },
	[391297]={ class = "PRIEST", level = 49, },
	[196611]={ class = "PRIEST", level = 49, },
	[322107]={ class = "PRIEST", level = 49, },
	[316262]={ class = "PRIEST", level = 50, },
--++ Rogue Abilities ++	
	[137034]={ class = "ROGUE", level = 1, },
	[82245]={ class = "ROGUE", level = 1, },
	[157442]={ class = "ROGUE", level = 1, },
	[1752]={ class = "ROGUE", level = 1, },
	[196819]={ class = "ROGUE", level = 2, },
	[1784]={ class = "ROGUE", level = 3, },
	[31209]={ class = "ROGUE", level = 4, },
	[2983]={ class = "ROGUE", level = 5, },
	[1766]={ class = "ROGUE", level = 6, },
	[8676]={ class = "ROGUE", level = 7, },
	[185311]={ class = "ROGUE", level = 8, },
	[315496]={ class = "ROGUE", level = 9, },
	[210108]={ class = "ROGUE", level = 10, },
	[56814]={ class = "ROGUE", level = 10, },
	[1804]={ class = "ROGUE", level = 14, },
	[2836]={ class = "ROGUE", level = 19, },
	[1856]={ class = "ROGUE", level = 23, },
	[921]={ class = "ROGUE", level = 24, },
	[1860]={ class = "ROGUE", level = 25, },
	[1725]={ class = "ROGUE", level = 28, },
	[344362]={ class = "ROGUE", level = 56, },
--++ Rogue Artifact Traits ++	
	[209835]={ class = "ROGUE", level = 40, },
	[214368]={ class = "ROGUE", level = 40, },
	[192657]={ class = "ROGUE", level = 40, },
	[192326]={ class = "ROGUE", level = 40, },
	[216230]={ class = "ROGUE", level = 40, },
	[202507]={ class = "ROGUE", level = 40, },
	[202628]={ class = "ROGUE", level = 40, },
	[192923]={ class = "ROGUE", level = 40, },
	[202897]={ class = "ROGUE", level = 40, },
	[202769]={ class = "ROGUE", level = 40, },
	[241153]={ class = "ROGUE", level = 40, },
	[197241]={ class = "ROGUE", level = 40, },
	[210144]={ class = "ROGUE", level = 40, },
	[210145]={ class = "ROGUE", level = 40, },
	[210146]={ class = "ROGUE", level = 40, },
	[210147]={ class = "ROGUE", level = 40, },
	[210148]={ class = "ROGUE", level = 40, },
	[239290]={ class = "ROGUE", level = 40, },
	[239291]={ class = "ROGUE", level = 40, },
	[202665]={ class = "ROGUE", level = 40, },
	[202463]={ class = "ROGUE", level = 40, },
	[214929]={ class = "ROGUE", level = 40, },
	[202755]={ class = "ROGUE", level = 40, },
	[197233]={ class = "ROGUE", level = 40, },
	[238102]={ class = "ROGUE", level = 40, },
	[238103]={ class = "ROGUE", level = 40, },
	[197604]={ class = "ROGUE", level = 40, },
	[197239]={ class = "ROGUE", level = 40, },
	[192323]={ class = "ROGUE", level = 40, },
	[202514]={ class = "ROGUE", level = 40, },
	[202524]={ class = "ROGUE", level = 40, },
	[238140]={ class = "ROGUE", level = 40, },
	[197406]={ class = "ROGUE", level = 40, },
	[197256]={ class = "ROGUE", level = 40, },
	[202530]={ class = "ROGUE", level = 40, },
	[197369]={ class = "ROGUE", level = 40, },
	[202907]={ class = "ROGUE", level = 40, },
	[202521]={ class = "ROGUE", level = 40, },
	[192428]={ class = "ROGUE", level = 40, },
	[197244]={ class = "ROGUE", level = 40, },
	[202533]={ class = "ROGUE", level = 40, },
	[209782]={ class = "ROGUE", level = 40, },
	[202820]={ class = "ROGUE", level = 40, },
	[202522]={ class = "ROGUE", level = 40, },
	[192329]={ class = "ROGUE", level = 40, },
	[197234]={ class = "ROGUE", level = 40, },
	[202753]={ class = "ROGUE", level = 40, },
	[214930]={ class = "ROGUE", level = 40, },
	[238139]={ class = "ROGUE", level = 40, },
	[192318]={ class = "ROGUE", level = 40, },
	[192349]={ class = "ROGUE", level = 40, },
	[192376]={ class = "ROGUE", level = 40, },
	[197235]={ class = "ROGUE", level = 40, },
	[238067]={ class = "ROGUE", level = 40, },
	[197610]={ class = "ROGUE", level = 40, },
	[192315]={ class = "ROGUE", level = 40, },
	[221856]={ class = "ROGUE", level = 40, },
	[209781]={ class = "ROGUE", level = 40, },
	[192422]={ class = "ROGUE", level = 40, },
	[192345]={ class = "ROGUE", level = 40, },
	[242707]={ class = "ROGUE", level = 40, },
	[241154]={ class = "ROGUE", level = 40, },
	[241152]={ class = "ROGUE", level = 40, },
	[238138]={ class = "ROGUE", level = 40, },
	[214928]={ class = "ROGUE", level = 40, },
	[197386]={ class = "ROGUE", level = 40, },
	[238066]={ class = "ROGUE", level = 40, },
	[192424]={ class = "ROGUE", level = 40, },
	[197231]={ class = "ROGUE", level = 40, },
	[192310]={ class = "ROGUE", level = 40, },
	[192384]={ class = "ROGUE", level = 40, },
	[238068]={ class = "ROGUE", level = 40, },
--++ Rogue Azerite Traits ++	
	[278676]={ class = "ROGUE", level = 45, },
	[279712]={ class = "ROGUE", level = 45, },
	[279752]={ class = "ROGUE", level = 45, },
	[279754]={ class = "ROGUE", level = 45, },
	[277723]={ class = "ROGUE", level = 45, },
	[269308]={ class = "ROGUE", level = 45, },
	[270627]={ class = "ROGUE", level = 45, },
	[272935]={ class = "ROGUE", level = 45, },
	[272936]={ class = "ROGUE", level = 45, },
	[272940]={ class = "ROGUE", level = 45, },
	[273007]={ class = "ROGUE", level = 45, },
	[287649]={ class = "ROGUE", level = 45, },
	[287650]={ class = "ROGUE", level = 45, },
	[287653]={ class = "ROGUE", level = 45, },
	[274694]={ class = "ROGUE", level = 45, },
	[278683]={ class = "ROGUE", level = 45, },
	[279720]={ class = "ROGUE", level = 45, },
	[288979]={ class = "ROGUE", level = 45, },
	[288985]={ class = "ROGUE", level = 45, },
	[288988]={ class = "ROGUE", level = 45, },
	[273419]={ class = "ROGUE", level = 45, },
	[273424]={ class = "ROGUE", level = 45, },
	[286573]={ class = "ROGUE", level = 45, },
	[286579]={ class = "ROGUE", level = 45, },
	[278675]={ class = "ROGUE", level = 45, },
	[277719]={ class = "ROGUE", level = 45, },
	[277720]={ class = "ROGUE", level = 45, },
	[286130]={ class = "ROGUE", level = 45, },
	[280199]={ class = "ROGUE", level = 45, },
	[278666]={ class = "ROGUE", level = 45, },
	[275858]={ class = "ROGUE", level = 45, },
	[275863]={ class = "ROGUE", level = 45, },
	[269297]={ class = "ROGUE", level = 45, },
	[278681]={ class = "ROGUE", level = 45, },
	[273488]={ class = "ROGUE", level = 45, },
--++ Rogue Covenant Abilities ++	
	[323547]={ class = "ROGUE", level = 48, },
	[328547]={ class = "ROGUE", level = 48, },
--++ Rogue Conduit Abilities ++	
	[341542]={ class = "ROGUE", level = 60, },
	[341529]={ class = "ROGUE", level = 60, },
	[341546]={ class = "ROGUE", level = 60, },
	[341549]={ class = "ROGUE", level = 60, },
	[341532]={ class = "ROGUE", level = 60, },
	[341310]={ class = "ROGUE", level = 60, },
	[341539]={ class = "ROGUE", level = 60, },
	[341538]={ class = "ROGUE", level = 60, },
	[341311]={ class = "ROGUE", level = 60, },
	[341567]={ class = "ROGUE", level = 60, },
	[341556]={ class = "ROGUE", level = 60, },
	[341536]={ class = "ROGUE", level = 60, },
	[341535]={ class = "ROGUE", level = 60, },
	[341531]={ class = "ROGUE", level = 60, },
	[341312]={ class = "ROGUE", level = 60, },
	[341264]={ class = "ROGUE", level = 60, },
	[341534]={ class = "ROGUE", level = 60, },
	[341309]={ class = "ROGUE", level = 60, },
	[341543]={ class = "ROGUE", level = 60, },
	[341559]={ class = "ROGUE", level = 60, },
	[341272]={ class = "ROGUE", level = 60, },
	[341540]={ class = "ROGUE", level = 60, },
	[341537]={ class = "ROGUE", level = 60, },
--++ Rogue Specializations ++	
	[137037]={ class = "ROGUE", level = 1, },
	[137036]={ class = "ROGUE", level = 1, },
	[137035]={ class = "ROGUE", level = 1, },
	[199736]={ class = "ROGUE", level = 1, },
	[331851]={ class = "ROGUE", level = 1, },
	[76808]={ class = "ROGUE", level = 10, },
	[76806]={ class = "ROGUE", level = 10, },
	[76803]={ class = "ROGUE", level = 10, },
	[185438]={ class = "ROGUE", level = 10, },
	[193315]={ class = "ROGUE", level = 10, },
	[197835]={ class = "ROGUE", level = 11, },
	[1329]={ class = "ROGUE", level = 12, },
	[53]={ class = "ROGUE", level = 14, },
	[114014]={ class = "ROGUE", level = 16, },
	[315341]={ class = "ROGUE", level = 17, },
	[51723]={ class = "ROGUE", level = 19, },
	[2098]={ class = "ROGUE", level = 22, },
	[32645]={ class = "ROGUE", level = 22, },
	[394929]={ class = "ROGUE", level = 22, },
	[196912]={ class = "ROGUE", level = 27, },
	[185565]={ class = "ROGUE", level = 29, },
	[212283]={ class = "ROGUE", level = 29, },
	[319473]={ class = "ROGUE", level = 41, },
	[231716]={ class = "ROGUE", level = 44, },
--++ Rogue Talents ++	
	[31224]={ class = "ROGUE", level = 10, },
	[5277]={ class = "ROGUE", level = 10, },
	[1966]={ class = "ROGUE", level = 10, },
	[5938]={ class = "ROGUE", level = 10, },
	[113780]={ class = "ROGUE", level = 11, },
	[319949]={ class = "ROGUE", level = 11, },
	[319951]={ class = "ROGUE", level = 11, },
	[279876]={ class = "ROGUE", level = 11, },
	[36544]={ class = "ROGUE", level = 11, },
	[394931]={ class = "ROGUE", level = 11, },
	[394932]={ class = "ROGUE", level = 11, },
	[394935]={ class = "ROGUE", level = 11, },
	[379005]={ class = "ROGUE", level = 12, },
	[196864]={ class = "ROGUE", level = 12, },
	[378436]={ class = "ROGUE", level = 12, },
	[378427]={ class = "ROGUE", level = 12, },
	[378807]={ class = "ROGUE", level = 12, },
	[381822]={ class = "ROGUE", level = 13, },
	[319175]={ class = "ROGUE", level = 13, },
	[61329]={ class = "ROGUE", level = 13, },
	[195457]={ class = "ROGUE", level = 13, },
	[196922]={ class = "ROGUE", level = 13, },
	[319032]={ class = "ROGUE", level = 13, },
	[382503]={ class = "ROGUE", level = 13, },
	[58423]={ class = "ROGUE", level = 13, },
	[108209]={ class = "ROGUE", level = 13, },
	[79134]={ class = "ROGUE", level = 13, },
	[193537]={ class = "ROGUE", level = 13, },
	[200733]={ class = "ROGUE", level = 13, },
	[13750]={ class = "ROGUE", level = 15, },
	[381626]={ class = "ROGUE", level = 15, },
	[381877]={ class = "ROGUE", level = 15, },
	[51667]={ class = "ROGUE", level = 15, },
	[381878]={ class = "ROGUE", level = 15, },
	[193640]={ class = "ROGUE", level = 15, },
	[381624]={ class = "ROGUE", level = 15, },
	[154904]={ class = "ROGUE", level = 15, },
	[381627]={ class = "ROGUE", level = 15, },
	[277953]={ class = "ROGUE", level = 15, },
	[343160]={ class = "ROGUE", level = 15, },
	[256188]={ class = "ROGUE", level = 15, },
	[344363]={ class = "ROGUE", level = 15, },
	[121471]={ class = "ROGUE", level = 15, },
	[257505]={ class = "ROGUE", level = 15, },
	[385722]={ class = "ROGUE", level = 15, },
	[378813]={ class = "ROGUE", level = 26, },
	[231691]={ class = "ROGUE", level = 26, },
	[319066]={ class = "ROGUE", level = 26, },
	[193546]={ class = "ROGUE", level = 26, },
	[131511]={ class = "ROGUE", level = 26, },
	[108208]={ class = "ROGUE", level = 26, },
	[256165]={ class = "ROGUE", level = 27, },
	[108216]={ class = "ROGUE", level = 27, },
	[392384]={ class = "ROGUE", level = 27, },
	[35551]={ class = "ROGUE", level = 27, },
	[200758]={ class = "ROGUE", level = 27, },
	[235484]={ class = "ROGUE", level = 27, },
	[381632]={ class = "ROGUE", level = 27, },
	[394023]={ class = "ROGUE", level = 27, },
	[381630]={ class = "ROGUE", level = 27, },
	[394983]={ class = "ROGUE", level = 27, },
	[79096]={ class = "ROGUE", level = 27, },
	[14161]={ class = "ROGUE", level = 27, },
	[280719]={ class = "ROGUE", level = 27, },
	[382509]={ class = "ROGUE", level = 27, },
	[381988]={ class = "ROGUE", level = 27, },
	[381629]={ class = "ROGUE", level = 27, },
	[382017]={ class = "ROGUE", level = 27, },
	[31230]={ class = "ROGUE", level = 28, },
	[231719]={ class = "ROGUE", level = 28, },
	[79008]={ class = "ROGUE", level = 28, },
	[378803]={ class = "ROGUE", level = 28, },
	[381621]={ class = "ROGUE", level = 28, },
	[381543]={ class = "ROGUE", level = 28, },
	[381828]={ class = "ROGUE", level = 29, },
	[185314]={ class = "ROGUE", level = 29, },
	[394321]={ class = "ROGUE", level = 29, },
	[200806]={ class = "ROGUE", level = 29, },
	[381885]={ class = "ROGUE", level = 29, },
	[255989]={ class = "ROGUE", level = 29, },
	[196976]={ class = "ROGUE", level = 29, },
	[196938]={ class = "ROGUE", level = 29, },
	[382506]={ class = "ROGUE", level = 29, },
	[315508]={ class = "ROGUE", level = 29, },
	[394309]={ class = "ROGUE", level = 29, },
	[382505]={ class = "ROGUE", level = 29, },
	[152152]={ class = "ROGUE", level = 29, },
	[381542]={ class = "ROGUE", level = 30, },
	[14062]={ class = "ROGUE", level = 30, },
	[381619]={ class = "ROGUE", level = 30, },
	[381845]={ class = "ROGUE", level = 31, },
	[272026]={ class = "ROGUE", level = 31, },
	[354897]={ class = "ROGUE", level = 31, },
	[381631]={ class = "ROGUE", level = 31, },
	[382746]={ class = "ROGUE", level = 31, },
	[393972]={ class = "ROGUE", level = 31, },
	[196861]={ class = "ROGUE", level = 31, },
	[381640]={ class = "ROGUE", level = 31, },
	[256170]={ class = "ROGUE", level = 31, },
	[382508]={ class = "ROGUE", level = 31, },
	[382511]={ class = "ROGUE", level = 31, },
	[382507]={ class = "ROGUE", level = 31, },
	[277925]={ class = "ROGUE", level = 31, },
	[381839]={ class = "ROGUE", level = 31, },
	[381894]={ class = "ROGUE", level = 31, },
	[381669]={ class = "ROGUE", level = 31, },
	[381634]={ class = "ROGUE", level = 31, },
	[381982]={ class = "ROGUE", level = 33, },
	[381673]={ class = "ROGUE", level = 33, },
	[381652]={ class = "ROGUE", level = 33, },
	[196924]={ class = "ROGUE", level = 34, },
	[381620]={ class = "ROGUE", level = 34, },
	[14983]={ class = "ROGUE", level = 34, },
	[382515]={ class = "ROGUE", level = 35, },
	[382514]={ class = "ROGUE", level = 35, },
	[382512]={ class = "ROGUE", level = 35, },
	[394320]={ class = "ROGUE", level = 35, },
	[382513]={ class = "ROGUE", level = 35, },
	[193539]={ class = "ROGUE", level = 50, },
	[280716]={ class = "ROGUE", level = 50, },
	[382238]={ class = "ROGUE", level = 50, },
	[378996]={ class = "ROGUE", level = 50, },
	[200759]={ class = "ROGUE", level = 50, },
	[393970]={ class = "ROGUE", level = 50, },
	[271877]={ class = "ROGUE", level = 51, },
	[328085]={ class = "ROGUE", level = 51, },
	[245687]={ class = "ROGUE", level = 51, },
	[382517]={ class = "ROGUE", level = 51, },
	[343142]={ class = "ROGUE", level = 51, },
	[395422]={ class = "ROGUE", level = 51, },
	[382518]={ class = "ROGUE", level = 51, },
	[255544]={ class = "ROGUE", level = 51, },
	[381985]={ class = "ROGUE", level = 51, },
	[385424]={ class = "ROGUE", level = 51, },
	[385478]={ class = "ROGUE", level = 51, },
	[381800]={ class = "ROGUE", level = 51, },
	[385616]={ class = "ROGUE", level = 52, },
	[14190]={ class = "ROGUE", level = 52, },
	[381846]={ class = "ROGUE", level = 53, },
	[381799]={ class = "ROGUE", level = 53, },
	[381990]={ class = "ROGUE", level = 53, },
	[382742]={ class = "ROGUE", level = 53, },
	[381798]={ class = "ROGUE", level = 53, },
	[382245]={ class = "ROGUE", level = 54, },
	[193531]={ class = "ROGUE", level = 54, },
	[91023]={ class = "ROGUE", level = 54, },
	[381622]={ class = "ROGUE", level = 54, },
	[394332]={ class = "ROGUE", level = 54, },
	[381797]={ class = "ROGUE", level = 55, },
	[382525]={ class = "ROGUE", level = 55, },
	[382523]={ class = "ROGUE", level = 55, },
	[382524]={ class = "ROGUE", level = 55, },
	[394930]={ class = "ROGUE", level = 56, },
	[381623]={ class = "ROGUE", level = 56, },
	[386823]={ class = "ROGUE", level = 57, },
	[383281]={ class = "ROGUE", level = 57, },
	[381989]={ class = "ROGUE", level = 57, },
	[382528]={ class = "ROGUE", level = 59, },
	[382504]={ class = "ROGUE", level = 59, },
	[381802]={ class = "ROGUE", level = 59, },
	[382015]={ class = "ROGUE", level = 59, },
	[381801]={ class = "ROGUE", level = 61, },
--++ Rogue PvP Talents ++	
	[209752]={ class = "ROGUE", level = 20, },
	[198675]={ class = "ROGUE", level = 20, },
	[269513]={ class = "ROGUE", level = 20, },
	[354425]={ class = "ROGUE", level = 20, },
	[197000]={ class = "ROGUE", level = 20, },
	[197899]={ class = "ROGUE", level = 20, },
	[198020]={ class = "ROGUE", level = 20, },
	[198952]={ class = "ROGUE", level = 20, },
	[198145]={ class = "ROGUE", level = 22, },
	[354843]={ class = "ROGUE", level = 25, },
	[354825]={ class = "ROGUE", level = 25, },
	[198265]={ class = "ROGUE", level = 29, },
	[354895]={ class = "ROGUE", level = 30, },
	[354406]={ class = "ROGUE", level = 35, },
	[354661]={ class = "ROGUE", level = 48, },
	[221622]={ class = "ROGUE", level = 48, },
	[354124]={ class = "ROGUE", level = 58, },
--++ Shaman Abilities ++	
	[137038]={ class = "SHAMAN", level = 1, },
	[188196]={ class = "SHAMAN", level = 1, },
	[73899]={ class = "SHAMAN", level = 2, },
	[8004]={ class = "SHAMAN", level = 4, },
	[2484]={ class = "SHAMAN", level = 5, },
	[318044]={ class = "SHAMAN", level = 6, },
	[318038]={ class = "SHAMAN", level = 7, },
	[20608]={ class = "SHAMAN", level = 8, },
	[192106]={ class = "SHAMAN", level = 9, },
	[2645]={ class = "SHAMAN", level = 10, },
	[2008]={ class = "SHAMAN", level = 13, },
	[6196]={ class = "SHAMAN", level = 14, },
	[556]={ class = "SHAMAN", level = 32, },
	[328928]={ class = "SHAMAN", level = 48, },
	[328930]={ class = "SHAMAN", level = 48, },
	[327163]={ class = "SHAMAN", level = 48, },
--++ Shaman Artifact Traits ++	
	[207092]={ class = "SHAMAN", level = 40, },
	[191493]={ class = "SHAMAN", level = 40, },
	[207354]={ class = "SHAMAN", level = 40, },
	[238070]={ class = "SHAMAN", level = 40, },
	[207362]={ class = "SHAMAN", level = 40, },
	[238143]={ class = "SHAMAN", level = 40, },
	[199107]={ class = "SHAMAN", level = 40, },
	[204945]={ class = "SHAMAN", level = 40, },
	[198505]={ class = "SHAMAN", level = 40, },
	[191598]={ class = "SHAMAN", level = 40, },
	[214932]={ class = "SHAMAN", level = 40, },
	[241205]={ class = "SHAMAN", level = 40, },
	[191577]={ class = "SHAMAN", level = 40, },
	[238069]={ class = "SHAMAN", level = 40, },
	[198248]={ class = "SHAMAN", level = 40, },
	[191512]={ class = "SHAMAN", level = 40, },
	[207255]={ class = "SHAMAN", level = 40, },
	[191740]={ class = "SHAMAN", level = 40, },
	[207348]={ class = "SHAMAN", level = 40, },
	[214933]={ class = "SHAMAN", level = 40, },
	[198236]={ class = "SHAMAN", level = 40, },
	[191717]={ class = "SHAMAN", level = 40, },
	[198349]={ class = "SHAMAN", level = 40, },
	[198299]={ class = "SHAMAN", level = 40, },
	[207351]={ class = "SHAMAN", level = 40, },
	[224841]={ class = "SHAMAN", level = 40, },
	[198228]={ class = "SHAMAN", level = 40, },
	[238142]={ class = "SHAMAN", level = 40, },
	[191504]={ class = "SHAMAN", level = 40, },
	[191647]={ class = "SHAMAN", level = 40, },
	[241203]={ class = "SHAMAN", level = 40, },
	[191572]={ class = "SHAMAN", level = 40, },
	[242652]={ class = "SHAMAN", level = 40, },
	[241202]={ class = "SHAMAN", level = 40, },
	[191569]={ class = "SHAMAN", level = 40, },
	[207118]={ class = "SHAMAN", level = 40, },
	[210029]={ class = "SHAMAN", level = 40, },
	[210030]={ class = "SHAMAN", level = 40, },
	[210031]={ class = "SHAMAN", level = 40, },
	[210032]={ class = "SHAMAN", level = 40, },
	[210033]={ class = "SHAMAN", level = 40, },
	[207285]={ class = "SHAMAN", level = 40, },
	[207360]={ class = "SHAMAN", level = 40, },
	[198361]={ class = "SHAMAN", level = 40, },
	[207356]={ class = "SHAMAN", level = 40, },
	[238141]={ class = "SHAMAN", level = 40, },
	[207355]={ class = "SHAMAN", level = 40, },
	[207357]={ class = "SHAMAN", level = 40, },
	[191582]={ class = "SHAMAN", level = 40, },
	[198238]={ class = "SHAMAN", level = 40, },
	[198296]={ class = "SHAMAN", level = 40, },
	[191602]={ class = "SHAMAN", level = 40, },
	[198367]={ class = "SHAMAN", level = 40, },
	[205495]={ class = "SHAMAN", level = 40, },
	[214931]={ class = "SHAMAN", level = 40, },
	[215414]={ class = "SHAMAN", level = 40, },
	[238105]={ class = "SHAMAN", level = 40, },
	[191499]={ class = "SHAMAN", level = 40, },
	[207088]={ class = "SHAMAN", level = 40, },
	[207358]={ class = "SHAMAN", level = 40, },
	[238071]={ class = "SHAMAN", level = 40, },
	[198736]={ class = "SHAMAN", level = 40, },
	[192630]={ class = "SHAMAN", level = 40, },
	[207206]={ class = "SHAMAN", level = 40, },
	[215381]={ class = "SHAMAN", level = 40, },
	[198292]={ class = "SHAMAN", level = 40, },
	[198247]={ class = "SHAMAN", level = 40, },
	[238106]={ class = "SHAMAN", level = 40, },
--++ Shaman Azerite Traits ++	
	[263790]={ class = "SHAMAN", level = 45, },
	[277926]={ class = "SHAMAN", level = 45, },
	[287775]={ class = "SHAMAN", level = 45, },
	[287777]={ class = "SHAMAN", level = 45, },
	[287778]={ class = "SHAMAN", level = 45, },
	[263786]={ class = "SHAMAN", level = 45, },
	[275381]={ class = "SHAMAN", level = 45, },
	[264121]={ class = "SHAMAN", level = 45, },
	[264113]={ class = "SHAMAN", level = 45, },
	[269567]={ class = "SHAMAN", level = 45, },
	[279829]={ class = "SHAMAN", level = 45, },
	[279830]={ class = "SHAMAN", level = 45, },
	[273448]={ class = "SHAMAN", level = 45, },
	[273449]={ class = "SHAMAN", level = 45, },
	[273453]={ class = "SHAMAN", level = 45, },
	[275388]={ class = "SHAMAN", level = 45, },
	[275389]={ class = "SHAMAN", level = 45, },
	[275393]={ class = "SHAMAN", level = 45, },
	[263792]={ class = "SHAMAN", level = 45, },
	[278697]={ class = "SHAMAN", level = 45, },
	[277658]={ class = "SHAMAN", level = 45, },
	[278077]={ class = "SHAMAN", level = 45, },
	[278095]={ class = "SHAMAN", level = 45, },
	[280203]={ class = "SHAMAN", level = 45, },
	[280205]={ class = "SHAMAN", level = 45, },
	[272992]={ class = "SHAMAN", level = 45, },
	[273005]={ class = "SHAMAN", level = 45, },
	[273006]={ class = "SHAMAN", level = 45, },
	[278719]={ class = "SHAMAN", level = 45, },
	[274416]={ class = "SHAMAN", level = 45, },
	[274823]={ class = "SHAMAN", level = 45, },
	[278715]={ class = "SHAMAN", level = 45, },
	[279504]={ class = "SHAMAN", level = 45, },
	[263795]={ class = "SHAMAN", level = 45, },
	[273461]={ class = "SHAMAN", level = 45, },
	[273463]={ class = "SHAMAN", level = 45, },
	[273465]={ class = "SHAMAN", level = 45, },
	[269570]={ class = "SHAMAN", level = 45, },
	[278713]={ class = "SHAMAN", level = 45, },
	[279181]={ class = "SHAMAN", level = 45, },
	[277958]={ class = "SHAMAN", level = 45, },
	[286949]={ class = "SHAMAN", level = 45, },
	[287768]={ class = "SHAMAN", level = 45, },
	[287801]={ class = "SHAMAN", level = 45, },
	[287802]={ class = "SHAMAN", level = 45, },
	[287300]={ class = "SHAMAN", level = 45, },
	[287302]={ class = "SHAMAN", level = 45, },
	[272978]={ class = "SHAMAN", level = 45, },
	[272980]={ class = "SHAMAN", level = 45, },
	[272981]={ class = "SHAMAN", level = 45, },
--++ Shaman Covenant Abilities ++	
	[324386]={ class = "SHAMAN", level = 48, },
	[320674]={ class = "SHAMAN", level = 48, },
	[326059]={ class = "SHAMAN", level = 48, },
	[328923]={ class = "SHAMAN", level = 48, },
--++ Shaman Conduit Abilities ++	
	[337964]={ class = "SHAMAN", level = 60, },
	[338303]={ class = "SHAMAN", level = 60, },
	[338325]={ class = "SHAMAN", level = 60, },
	[338054]={ class = "SHAMAN", level = 60, },
	[339182]={ class = "SHAMAN", level = 60, },
	[338329]={ class = "SHAMAN", level = 60, },
	[339183]={ class = "SHAMAN", level = 60, },
	[338322]={ class = "SHAMAN", level = 60, },
	[338343]={ class = "SHAMAN", level = 60, },
	[338131]={ class = "SHAMAN", level = 60, },
	[339185]={ class = "SHAMAN", level = 60, },
	[338331]={ class = "SHAMAN", level = 60, },
	[338346]={ class = "SHAMAN", level = 60, },
	[345594]={ class = "SHAMAN", level = 60, },
	[337974]={ class = "SHAMAN", level = 60, },
	[338252]={ class = "SHAMAN", level = 60, },
	[338048]={ class = "SHAMAN", level = 60, },
	[338339]={ class = "SHAMAN", level = 60, },
	[338033]={ class = "SHAMAN", level = 60, },
	[338042]={ class = "SHAMAN", level = 60, },
	[339186]={ class = "SHAMAN", level = 60, },
	[338318]={ class = "SHAMAN", level = 60, },
	[337981]={ class = "SHAMAN", level = 60, },
--++ Shaman Specializations ++	
	[137040]={ class = "SHAMAN", level = 1, },
	[137041]={ class = "SHAMAN", level = 1, },
	[137039]={ class = "SHAMAN", level = 1, },
	[212048]={ class = "SHAMAN", level = 1, },
	[201845]={ class = "SHAMAN", level = 1, },
	[157444]={ class = "SHAMAN", level = 10, },
	[86629]={ class = "SHAMAN", level = 10, },
	[190488]={ class = "SHAMAN", level = 10, },
	[187828]={ class = "SHAMAN", level = 10, },
	[343725]={ class = "SHAMAN", level = 10, },
	[77226]={ class = "SHAMAN", level = 10, },
	[168534]={ class = "SHAMAN", level = 10, },
	[77223]={ class = "SHAMAN", level = 10, },
	[77130]={ class = "SHAMAN", level = 10, },
	[86099]={ class = "SHAMAN", level = 27, },
	[86100]={ class = "SHAMAN", level = 27, },
	[86108]={ class = "SHAMAN", level = 27, },
--++ Shaman Talents ++	
	[108271]={ class = "SHAMAN", level = 10, },
	[1064]={ class = "SHAMAN", level = 10, },
	[188443]={ class = "SHAMAN", level = 10, },
	[198103]={ class = "SHAMAN", level = 10, },
	[382886]={ class = "SHAMAN", level = 10, },
	[382888]={ class = "SHAMAN", level = 10, },
	[381666]={ class = "SHAMAN", level = 10, },
	[51505]={ class = "SHAMAN", level = 10, },
	[187880]={ class = "SHAMAN", level = 10, },
	[57994]={ class = "SHAMAN", level = 10, },
	[8042]={ class = "SHAMAN", level = 11, },
	[17364]={ class = "SHAMAN", level = 11, },
	[382947]={ class = "SHAMAN", level = 12, },
	[377933]={ class = "SHAMAN", level = 12, },
	[192058]={ class = "SHAMAN", level = 12, },
	[51886]={ class = "SHAMAN", level = 12, },
	[383010]={ class = "SHAMAN", level = 12, },
	[378773]={ class = "SHAMAN", level = 12, },
	[381647]={ class = "SHAMAN", level = 12, },
	[370]={ class = "SHAMAN", level = 12, },
	[260878]={ class = "SHAMAN", level = 12, },
	[79206]={ class = "SHAMAN", level = 12, },
	[378075]={ class = "SHAMAN", level = 12, },
	[8143]={ class = "SHAMAN", level = 12, },
	[200076]={ class = "SHAMAN", level = 13, },
	[61882]={ class = "SHAMAN", level = 13, },
	[60188]={ class = "SHAMAN", level = 13, },
	[198067]={ class = "SHAMAN", level = 13, },
	[5394]={ class = "SHAMAN", level = 13, },
	[392915]={ class = "SHAMAN", level = 13, },
	[392916]={ class = "SHAMAN", level = 13, },
	[77472]={ class = "SHAMAN", level = 13, },
	[60103]={ class = "SHAMAN", level = 13, },
	[192249]={ class = "SHAMAN", level = 13, },
	[33757]={ class = "SHAMAN", level = 13, },
	[381819]={ class = "SHAMAN", level = 14, },
	[383016]={ class = "SHAMAN", level = 14, },
	[265046]={ class = "SHAMAN", level = 14, },
	[382197]={ class = "SHAMAN", level = 15, },
	[378241]={ class = "SHAMAN", level = 15, },
	[196884]={ class = "SHAMAN", level = 15, },
	[262647]={ class = "SHAMAN", level = 15, },
	[383303]={ class = "SHAMAN", level = 15, },
	[378776]={ class = "SHAMAN", level = 15, },
	[334033]={ class = "SHAMAN", level = 15, },
	[381764]={ class = "SHAMAN", level = 15, },
	[378193]={ class = "SHAMAN", level = 15, },
	[378211]={ class = "SHAMAN", level = 15, },
	[320137]={ class = "SHAMAN", level = 15, },
	[383009]={ class = "SHAMAN", level = 15, },
	[392714]={ class = "SHAMAN", level = 15, },
	[392763]={ class = "SHAMAN", level = 15, },
	[51564]={ class = "SHAMAN", level = 15, },
	[381743]={ class = "SHAMAN", level = 15, },
	[52127]={ class = "SHAMAN", level = 15, },
	[207401]={ class = "SHAMAN", level = 17, },
	[280614]={ class = "SHAMAN", level = 17, },
	[385923]={ class = "SHAMAN", level = 17, },
	[77756]={ class = "SHAMAN", level = 17, },
	[16196]={ class = "SHAMAN", level = 17, },
	[390288]={ class = "SHAMAN", level = 17, },
	[382030]={ class = "SHAMAN", level = 17, },
	[378443]={ class = "SHAMAN", level = 19, },
	[333974]={ class = "SHAMAN", level = 19, },
	[334195]={ class = "SHAMAN", level = 19, },
	[383222]={ class = "SHAMAN", level = 19, },
	[384143]={ class = "SHAMAN", level = 19, },
	[51485]={ class = "SHAMAN", level = 26, },
	[381650]={ class = "SHAMAN", level = 26, },
	[192088]={ class = "SHAMAN", level = 26, },
	[381655]={ class = "SHAMAN", level = 26, },
	[378077]={ class = "SHAMAN", level = 26, },
	[381867]={ class = "SHAMAN", level = 26, },
	[192077]={ class = "SHAMAN", level = 26, },
	[382732]={ class = "SHAMAN", level = 27, },
	[378255]={ class = "SHAMAN", level = 27, },
	[157153]={ class = "SHAMAN", level = 27, },
	[108283]={ class = "SHAMAN", level = 27, },
	[333919]={ class = "SHAMAN", level = 27, },
	[382039]={ class = "SHAMAN", level = 27, },
	[201900]={ class = "SHAMAN", level = 27, },
	[382482]={ class = "SHAMAN", level = 27, },
	[16166]={ class = "SHAMAN", level = 27, },
	[384149]={ class = "SHAMAN", level = 27, },
	[98008]={ class = "SHAMAN", level = 27, },
	[392352]={ class = "SHAMAN", level = 27, },
	[381707]={ class = "SHAMAN", level = 27, },
	[384359]={ class = "SHAMAN", level = 27, },
	[382685]={ class = "SHAMAN", level = 27, },
	[381946]={ class = "SHAMAN", level = 27, },
	[8512]={ class = "SHAMAN", level = 27, },
	[378079]={ class = "SHAMAN", level = 28, },
	[30884]={ class = "SHAMAN", level = 28, },
	[108287]={ class = "SHAMAN", level = 28, },
	[204268]={ class = "SHAMAN", level = 28, },
	[273221]={ class = "SHAMAN", level = 29, },
	[187874]={ class = "SHAMAN", level = 29, },
	[382021]={ class = "SHAMAN", level = 29, },
	[382086]={ class = "SHAMAN", level = 29, },
	[117014]={ class = "SHAMAN", level = 29, },
	[394150]={ class = "SHAMAN", level = 29, },
	[384355]={ class = "SHAMAN", level = 29, },
	[378266]={ class = "SHAMAN", level = 29, },
	[381776]={ class = "SHAMAN", level = 29, },
	[108280]={ class = "SHAMAN", level = 29, },
	[16191]={ class = "SHAMAN", level = 29, },
	[343182]={ class = "SHAMAN", level = 29, },
	[191861]={ class = "SHAMAN", level = 29, },
	[393905]={ class = "SHAMAN", level = 29, },
	[319930]={ class = "SHAMAN", level = 29, },
	[344357]={ class = "SHAMAN", level = 29, },
	[191634]={ class = "SHAMAN", level = 29, },
	[262303]={ class = "SHAMAN", level = 29, },
	[200072]={ class = "SHAMAN", level = 29, },
	[200071]={ class = "SHAMAN", level = 29, },
	[73685]={ class = "SHAMAN", level = 29, },
	[381689]={ class = "SHAMAN", level = 30, },
	[381674]={ class = "SHAMAN", level = 30, },
	[382215]={ class = "SHAMAN", level = 30, },
	[207399]={ class = "SHAMAN", level = 31, },
	[390370]={ class = "SHAMAN", level = 31, },
	[384363]={ class = "SHAMAN", level = 31, },
	[334308]={ class = "SHAMAN", level = 31, },
	[198838]={ class = "SHAMAN", level = 31, },
	[381708]={ class = "SHAMAN", level = 31, },
	[381936]={ class = "SHAMAN", level = 31, },
	[382027]={ class = "SHAMAN", level = 31, },
	[334046]={ class = "SHAMAN", level = 33, },
	[192063]={ class = "SHAMAN", level = 34, },
	[58875]={ class = "SHAMAN", level = 34, },
	[381678]={ class = "SHAMAN", level = 50, },
	[381930]={ class = "SHAMAN", level = 50, },
	[378081]={ class = "SHAMAN", level = 50, },
	[382033]={ class = "SHAMAN", level = 50, },
	[378094]={ class = "SHAMAN", level = 50, },
	[382309]={ class = "SHAMAN", level = 51, },
	[114050]={ class = "SHAMAN", level = 51, },
	[114051]={ class = "SHAMAN", level = 51, },
	[378270]={ class = "SHAMAN", level = 51, },
	[382020]={ class = "SHAMAN", level = 51, },
	[382032]={ class = "SHAMAN", level = 51, },
	[384087]={ class = "SHAMAN", level = 51, },
	[378271]={ class = "SHAMAN", level = 51, },
	[51533]={ class = "SHAMAN", level = 51, },
	[382315]={ class = "SHAMAN", level = 51, },
	[192222]={ class = "SHAMAN", level = 51, },
	[117013]={ class = "SHAMAN", level = 51, },
	[375982]={ class = "SHAMAN", level = 51, },
	[381782]={ class = "SHAMAN", level = 51, },
	[382201]={ class = "SHAMAN", level = 51, },
	[382194]={ class = "SHAMAN", level = 51, },
	[305483]={ class = "SHAMAN", level = 52, },
	[378779]={ class = "SHAMAN", level = 52, },
	[207778]={ class = "SHAMAN", level = 53, },
	[210853]={ class = "SHAMAN", level = 53, },
	[382191]={ class = "SHAMAN", level = 53, },
	[384450]={ class = "SHAMAN", level = 53, },
	[381932]={ class = "SHAMAN", level = 53, },
	[381785]={ class = "SHAMAN", level = 53, },
	[384405]={ class = "SHAMAN", level = 53, },
	[386443]={ class = "SHAMAN", level = 53, },
	[384411]={ class = "SHAMAN", level = 53, },
	[384447]={ class = "SHAMAN", level = 53, },
	[383013]={ class = "SHAMAN", level = 54, },
	[383017]={ class = "SHAMAN", level = 54, },
	[108285]={ class = "SHAMAN", level = 54, },
	[383019]={ class = "SHAMAN", level = 54, },
	[114052]={ class = "SHAMAN", level = 55, },
	[382029]={ class = "SHAMAN", level = 55, },
	[157154]={ class = "SHAMAN", level = 55, },
	[210689]={ class = "SHAMAN", level = 55, },
	[381726]={ class = "SHAMAN", level = 55, },
	[382019]={ class = "SHAMAN", level = 55, },
	[382045]={ class = "SHAMAN", level = 55, },
	[378310]={ class = "SHAMAN", level = 55, },
	[197995]={ class = "SHAMAN", level = 55, },
	[378268]={ class = "SHAMAN", level = 55, },
	[383011]={ class = "SHAMAN", level = 56, },
	[383012]={ class = "SHAMAN", level = 56, },
	[198434]={ class = "SHAMAN", level = 57, },
	[382046]={ class = "SHAMAN", level = 57, },
	[262624]={ class = "SHAMAN", level = 57, },
	[381787]={ class = "SHAMAN", level = 57, },
	[386474]={ class = "SHAMAN", level = 57, },
	[382042]={ class = "SHAMAN", level = 57, },
	[384444]={ class = "SHAMAN", level = 57, },
	[382040]={ class = "SHAMAN", level = 57, },
--++ Shaman PvP Talents ++	
	[204393]={ class = "SHAMAN", level = 20, },
	[204331]={ class = "SHAMAN", level = 20, },
	[289874]={ class = "SHAMAN", level = 20, },
	[204261]={ class = "SHAMAN", level = 20, },
	[355580]={ class = "SHAMAN", level = 20, },
	[204264]={ class = "SHAMAN", level = 20, },
	[204366]={ class = "SHAMAN", level = 20, },
	[356736]={ class = "SHAMAN", level = 20, },
	[290250]={ class = "SHAMAN", level = 21, },
	[236501]={ class = "SHAMAN", level = 21, },
	[204336]={ class = "SHAMAN", level = 30, },
	[206642]={ class = "SHAMAN", level = 39, },
	[204330]={ class = "SHAMAN", level = 40, },
	[210918]={ class = "SHAMAN", level = 42, },
	[290254]={ class = "SHAMAN", level = 44, },
	[355630]={ class = "SHAMAN", level = 44, },
	[193876]={ class = "SHAMAN", level = 48, },
	[353115]={ class = "SHAMAN", level = 49, },
	[204403]={ class = "SHAMAN", level = 49, },
--++ Warlock Abilities ++	
	[137042]={ class = "WARLOCK", level = 1, },
	[23161]={ class = "WARLOCK", level = 1, },
	[5784]={ class = "WARLOCK", level = 1, },
	[93375]={ class = "WARLOCK", level = 1, },
	[686]={ class = "WARLOCK", level = 1, },
	[172]={ class = "WARLOCK", level = 2, },
	[246985]={ class = "WARLOCK", level = 3, },
	[688]={ class = "WARLOCK", level = 3, },
	[104773]={ class = "WARLOCK", level = 4, },
	[6201]={ class = "WARLOCK", level = 7, },
	[755]={ class = "WARLOCK", level = 8, },
	[108370]={ class = "WARLOCK", level = 10, },
	[697]={ class = "WARLOCK", level = 10, },
	[126]={ class = "WARLOCK", level = 17, },
	[366222]={ class = "WARLOCK", level = 19, },
	[1098]={ class = "WARLOCK", level = 21, },
	[691]={ class = "WARLOCK", level = 23, },
	[119898]={ class = "WARLOCK", level = 29, },
	[342601]={ class = "WARLOCK", level = 31, },
	[698]={ class = "WARLOCK", level = 33, },
	[29893]={ class = "WARLOCK", level = 47, },
	[342914]={ class = "WARLOCK", level = 52, },
--++ Warlock Artifact Traits ++	
	[221882]={ class = "WARLOCK", level = 40, },
	[196432]={ class = "WARLOCK", level = 40, },
	[196217]={ class = "WARLOCK", level = 40, },
	[199282]={ class = "WARLOCK", level = 40, },
	[219195]={ class = "WARLOCK", level = 40, },
	[238110]={ class = "WARLOCK", level = 40, },
	[221862]={ class = "WARLOCK", level = 40, },
	[241257]={ class = "WARLOCK", level = 40, },
	[215223]={ class = "WARLOCK", level = 40, },
	[196301]={ class = "WARLOCK", level = 40, },
	[219415]={ class = "WARLOCK", level = 40, },
	[196586]={ class = "WARLOCK", level = 40, },
	[211105]={ class = "WARLOCK", level = 40, },
	[218572]={ class = "WARLOCK", level = 40, },
	[199120]={ class = "WARLOCK", level = 40, },
	[196305]={ class = "WARLOCK", level = 40, },
	[199257]={ class = "WARLOCK", level = 40, },
	[196222]={ class = "WARLOCK", level = 40, },
	[196258]={ class = "WARLOCK", level = 40, },
	[211131]={ class = "WARLOCK", level = 40, },
	[238146]={ class = "WARLOCK", level = 40, },
	[238074]={ class = "WARLOCK", level = 40, },
	[241253]={ class = "WARLOCK", level = 40, },
	[215183]={ class = "WARLOCK", level = 40, },
	[199112]={ class = "WARLOCK", level = 40, },
	[211158]={ class = "WARLOCK", level = 40, },
	[215273]={ class = "WARLOCK", level = 40, },
	[211119]={ class = "WARLOCK", level = 40, },
	[199152]={ class = "WARLOCK", level = 40, },
	[199111]={ class = "WARLOCK", level = 40, },
	[238109]={ class = "WARLOCK", level = 40, },
	[238073]={ class = "WARLOCK", level = 40, },
	[211126]={ class = "WARLOCK", level = 40, },
	[199214]={ class = "WARLOCK", level = 40, },
	[224103]={ class = "WARLOCK", level = 40, },
	[196211]={ class = "WARLOCK", level = 40, },
	[211099]={ class = "WARLOCK", level = 40, },
	[211144]={ class = "WARLOCK", level = 40, },
	[199158]={ class = "WARLOCK", level = 40, },
	[196675]={ class = "WARLOCK", level = 40, },
	[216698]={ class = "WARLOCK", level = 40, },
	[238144]={ class = "WARLOCK", level = 40, },
	[196227]={ class = "WARLOCK", level = 40, },
	[199153]={ class = "WARLOCK", level = 40, },
	[199212]={ class = "WARLOCK", level = 40, },
	[199163]={ class = "WARLOCK", level = 40, },
	[211123]={ class = "WARLOCK", level = 40, },
	[238108]={ class = "WARLOCK", level = 40, },
	[218567]={ class = "WARLOCK", level = 40, },
	[196236]={ class = "WARLOCK", level = 40, },
	[214934]={ class = "WARLOCK", level = 40, },
	[211530]={ class = "WARLOCK", level = 40, },
	[214936]={ class = "WARLOCK", level = 40, },
	[211108]={ class = "WARLOCK", level = 40, },
	[241252]={ class = "WARLOCK", level = 40, },
	[199220]={ class = "WARLOCK", level = 40, },
	[238145]={ class = "WARLOCK", level = 40, },
	[211714]={ class = "WARLOCK", level = 40, },
	[211720]={ class = "WARLOCK", level = 40, },
	[214935]={ class = "WARLOCK", level = 40, },
	[211106]={ class = "WARLOCK", level = 40, },
	[211219]={ class = "WARLOCK", level = 40, },
	[238072]={ class = "WARLOCK", level = 40, },
	[199472]={ class = "WARLOCK", level = 40, },
--++ Warlock Azerite Traits ++	
	[279911]={ class = "WARLOCK", level = 45, },
	[275376]={ class = "WARLOCK", level = 45, },
	[287637]={ class = "WARLOCK", level = 45, },
	[287656]={ class = "WARLOCK", level = 45, },
	[287658]={ class = "WARLOCK", level = 45, },
	[278748]={ class = "WARLOCK", level = 45, },
	[279672]={ class = "WARLOCK", level = 45, },
	[279673]={ class = "WARLOCK", level = 45, },
	[277705]={ class = "WARLOCK", level = 45, },
	[277706]={ class = "WARLOCK", level = 45, },
	[278737]={ class = "WARLOCK", level = 45, },
	[280207]={ class = "WARLOCK", level = 45, },
	[278727]={ class = "WARLOCK", level = 45, },
	[279650]={ class = "WARLOCK", level = 45, },
	[273521]={ class = "WARLOCK", level = 45, },
	[273522]={ class = "WARLOCK", level = 45, },
	[274419]={ class = "WARLOCK", level = 45, },
	[269594]={ class = "WARLOCK", level = 45, },
	[270647]={ class = "WARLOCK", level = 45, },
	[289364]={ class = "WARLOCK", level = 45, },
	[278747]={ class = "WARLOCK", level = 45, },
	[272944]={ class = "WARLOCK", level = 45, },
	[278721]={ class = "WARLOCK", level = 45, },
	[279879]={ class = "WARLOCK", level = 45, },
	[287822]={ class = "WARLOCK", level = 45, },
	[273524]={ class = "WARLOCK", level = 45, },
	[273526]={ class = "WARLOCK", level = 45, },
	[272891]={ class = "WARLOCK", level = 45, },
	[272892]={ class = "WARLOCK", level = 45, },
	[272893]={ class = "WARLOCK", level = 45, },
--++ Warlock Covenant Abilities ++	
	[321792]={ class = "WARLOCK", level = 48, },
	[325289]={ class = "WARLOCK", level = 48, },
--++ Warlock Conduit Abilities ++	
	[339282]={ class = "WARLOCK", level = 60, },
	[339298]={ class = "WARLOCK", level = 60, },
	[339892]={ class = "WARLOCK", level = 60, },
	[339578]={ class = "WARLOCK", level = 60, },
	[339656]={ class = "WARLOCK", level = 60, },
	[340316]={ class = "WARLOCK", level = 60, },
	[339896]={ class = "WARLOCK", level = 60, },
	[339455]={ class = "WARLOCK", level = 60, },
	[339411]={ class = "WARLOCK", level = 60, },
	[340562]={ class = "WARLOCK", level = 60, },
	[339890]={ class = "WARLOCK", level = 60, },
	[340268]={ class = "WARLOCK", level = 60, },
	[339130]={ class = "WARLOCK", level = 60, },
	[339845]={ class = "WARLOCK", level = 60, },
	[339500]={ class = "WARLOCK", level = 60, },
	[340041]={ class = "WARLOCK", level = 60, },
	[339272]={ class = "WARLOCK", level = 60, },
	[339481]={ class = "WARLOCK", level = 60, },
	[339379]={ class = "WARLOCK", level = 60, },
	[340348]={ class = "WARLOCK", level = 60, },
	[340229]={ class = "WARLOCK", level = 60, },
	[339766]={ class = "WARLOCK", level = 60, },
	[339576]={ class = "WARLOCK", level = 60, },
--++ Warlock Specializations ++	
	[137043]={ class = "WARLOCK", level = 1, },
	[137044]={ class = "WARLOCK", level = 1, },
	[137046]={ class = "WARLOCK", level = 1, },
	[231792]={ class = "WARLOCK", level = 1, },
	[267102]={ class = "WARLOCK", level = 1, },
	[334591]={ class = "WARLOCK", level = 1, },
	[105174]={ class = "WARLOCK", level = 1, },
	[348]={ class = "WARLOCK", level = 1, },
	[30146]={ class = "WARLOCK", level = 1, },
	[231791]={ class = "WARLOCK", level = 1, },
	[334315]={ class = "WARLOCK", level = 1, },
	[29722]={ class = "WARLOCK", level = 10, },
	[77220]={ class = "WARLOCK", level = 10, },
	[77219]={ class = "WARLOCK", level = 10, },
	[77215]={ class = "WARLOCK", level = 10, },
	[231811]={ class = "WARLOCK", level = 48, },
--++ Warlock Talents ++	
	[111400]={ class = "WARLOCK", level = 10, },
	[219272]={ class = "WARLOCK", level = 10, },
	[268358]={ class = "WARLOCK", level = 10, },
	[386124]={ class = "WARLOCK", level = 10, },
	[333889]={ class = "WARLOCK", level = 10, },
	[104316]={ class = "WARLOCK", level = 11, },
	[116858]={ class = "WARLOCK", level = 11, },
	[324536]={ class = "WARLOCK", level = 11, },
	[386113]={ class = "WARLOCK", level = 12, },
	[386110]={ class = "WARLOCK", level = 12, },
	[386174]={ class = "WARLOCK", level = 13, },
	[17962]={ class = "WARLOCK", level = 13, },
	[264178]={ class = "WARLOCK", level = 13, },
	[264078]={ class = "WARLOCK", level = 13, },
	[266134]={ class = "WARLOCK", level = 13, },
	[205148]={ class = "WARLOCK", level = 13, },
	[389609]={ class = "WARLOCK", level = 14, },
	[386105]={ class = "WARLOCK", level = 14, },
	[196406]={ class = "WARLOCK", level = 15, },
	[267211]={ class = "WARLOCK", level = 15, },
	[386185]={ class = "WARLOCK", level = 15, },
	[267171]={ class = "WARLOCK", level = 15, },
	[386200]={ class = "WARLOCK", level = 15, },
	[267170]={ class = "WARLOCK", level = 15, },
	[387506]={ class = "WARLOCK", level = 15, },
	[108558]={ class = "WARLOCK", level = 15, },
	[387095]={ class = "WARLOCK", level = 15, },
	[387322]={ class = "WARLOCK", level = 15, },
	[264057]={ class = "WARLOCK", level = 15, },
	[196226]={ class = "WARLOCK", level = 15, },
	[264119]={ class = "WARLOCK", level = 15, },
	[317031]={ class = "WARLOCK", level = 15, },
	[328774]={ class = "WARLOCK", level = 16, },
	[710]={ class = "WARLOCK", level = 16, },
	[288843]={ class = "WARLOCK", level = 16, },
	[386617]={ class = "WARLOCK", level = 16, },
	[386858]={ class = "WARLOCK", level = 16, },
	[386864]={ class = "WARLOCK", level = 16, },
	[386922]={ class = "WARLOCK", level = 17, },
	[386194]={ class = "WARLOCK", level = 17, },
	[152108]={ class = "WARLOCK", level = 17, },
	[196447]={ class = "WARLOCK", level = 17, },
	[387522]={ class = "WARLOCK", level = 17, },
	[388827]={ class = "WARLOCK", level = 17, },
	[387338]={ class = "WARLOCK", level = 17, },
	[201424]={ class = "WARLOCK", level = 17, },
	[196277]={ class = "WARLOCK", level = 17, },
	[231793]={ class = "WARLOCK", level = 17, },
	[387093]={ class = "WARLOCK", level = 17, },
	[270545]={ class = "WARLOCK", level = 17, },
	[387509]={ class = "WARLOCK", level = 17, },
	[205184]={ class = "WARLOCK", level = 17, },
	[32388]={ class = "WARLOCK", level = 17, },
	[196102]={ class = "WARLOCK", level = 17, },
	[111771]={ class = "WARLOCK", level = 26, },
	[386619]={ class = "WARLOCK", level = 26, },
	[389623]={ class = "WARLOCK", level = 26, },
	[386651]={ class = "WARLOCK", level = 26, },
	[386648]={ class = "WARLOCK", level = 26, },
	[386620]={ class = "WARLOCK", level = 26, },
	[387972]={ class = "WARLOCK", level = 26, },
	[196103]={ class = "WARLOCK", level = 27, },
	[387384]={ class = "WARLOCK", level = 27, },
	[387349]={ class = "WARLOCK", level = 27, },
	[205145]={ class = "WARLOCK", level = 27, },
	[387396]={ class = "WARLOCK", level = 27, },
	[388667]={ class = "WARLOCK", level = 27, },
	[387391]={ class = "WARLOCK", level = 27, },
	[387399]={ class = "WARLOCK", level = 27, },
	[196408]={ class = "WARLOCK", level = 27, },
	[108503]={ class = "WARLOCK", level = 27, },
	[111898]={ class = "WARLOCK", level = 27, },
	[334319]={ class = "WARLOCK", level = 27, },
	[267216]={ class = "WARLOCK", level = 27, },
	[264130]={ class = "WARLOCK", level = 27, },
	[387166]={ class = "WARLOCK", level = 27, },
	[387569]={ class = "WARLOCK", level = 27, },
	[6353]={ class = "WARLOCK", level = 27, },
	[199471]={ class = "WARLOCK", level = 27, },
	[387073]={ class = "WARLOCK", level = 27, },
	[278350]={ class = "WARLOCK", level = 27, },
	[386659]={ class = "WARLOCK", level = 28, },
	[108416]={ class = "WARLOCK", level = 28, },
	[317138]={ class = "WARLOCK", level = 28, },
	[387108]={ class = "WARLOCK", level = 29, },
	[387176]={ class = "WARLOCK", level = 29, },
	[387432]={ class = "WARLOCK", level = 29, },
	[387259]={ class = "WARLOCK", level = 29, },
	[387488]={ class = "WARLOCK", level = 29, },
	[387445]={ class = "WARLOCK", level = 29, },
	[386759]={ class = "WARLOCK", level = 29, },
	[387485]={ class = "WARLOCK", level = 29, },
	[386986]={ class = "WARLOCK", level = 29, },
	[388832]={ class = "WARLOCK", level = 29, },
	[386951]={ class = "WARLOCK", level = 29, },
	[386613]={ class = "WARLOCK", level = 30, },
	[264874]={ class = "WARLOCK", level = 30, },
	[386686]={ class = "WARLOCK", level = 30, },
	[386664]={ class = "WARLOCK", level = 30, },
	[386646]={ class = "WARLOCK", level = 30, },
	[384069]={ class = "WARLOCK", level = 30, },
	[387103]={ class = "WARLOCK", level = 31, },
	[386976]={ class = "WARLOCK", level = 31, },
	[387252]={ class = "WARLOCK", level = 33, },
	[196412]={ class = "WARLOCK", level = 33, },
	[387483]={ class = "WARLOCK", level = 33, },
	[389367]={ class = "WARLOCK", level = 50, },
	[108415]={ class = "WARLOCK", level = 50, },
	[385881]={ class = "WARLOCK", level = 50, },
	[387494]={ class = "WARLOCK", level = 51, },
	[264000]={ class = "WARLOCK", level = 51, },
	[387173]={ class = "WARLOCK", level = 51, },
	[267217]={ class = "WARLOCK", level = 51, },
	[387156]={ class = "WARLOCK", level = 51, },
	[205180]={ class = "WARLOCK", level = 51, },
	[265187]={ class = "WARLOCK", level = 51, },
	[1122]={ class = "WARLOCK", level = 51, },
	[389590]={ class = "WARLOCK", level = 52, },
	[171975]={ class = "WARLOCK", level = 52, },
	[389576]={ class = "WARLOCK", level = 52, },
	[389359]={ class = "WARLOCK", level = 52, },
	[215941]={ class = "WARLOCK", level = 52, },
	[387153]={ class = "WARLOCK", level = 53, },
	[387355]={ class = "WARLOCK", level = 53, },
	[387475]={ class = "WARLOCK", level = 53, },
	[387549]={ class = "WARLOCK", level = 53, },
	[387400]={ class = "WARLOCK", level = 53, },
	[389761]={ class = "WARLOCK", level = 53, },
	[387273]={ class = "WARLOCK", level = 53, },
	[387165]={ class = "WARLOCK", level = 53, },
	[387526]={ class = "WARLOCK", level = 53, },
	[387541]={ class = "WARLOCK", level = 53, },
	[387279]={ class = "WARLOCK", level = 53, },
	[267214]={ class = "WARLOCK", level = 53, },
	[387250]={ class = "WARLOCK", level = 53, },
	[334585]={ class = "WARLOCK", level = 53, },
	[389630]={ class = "WARLOCK", level = 53, },
	[387602]={ class = "WARLOCK", level = 53, },
	[387600]={ class = "WARLOCK", level = 53, },
	[387075]={ class = "WARLOCK", level = 53, },
	[387065]={ class = "WARLOCK", level = 53, },
	[386689]={ class = "WARLOCK", level = 56, },
	[386344]={ class = "WARLOCK", level = 56, },
	[385899]={ class = "WARLOCK", level = 56, },
	[386244]={ class = "WARLOCK", level = 56, },
	[387159]={ class = "WARLOCK", level = 57, },
	[387275]={ class = "WARLOCK", level = 57, },
	[387016]={ class = "WARLOCK", level = 57, },
	[387976]={ class = "WARLOCK", level = 57, },
	[389764]={ class = "WARLOCK", level = 57, },
	[389775]={ class = "WARLOCK", level = 57, },
	[387084]={ class = "WARLOCK", level = 57, },
	[389992]={ class = "WARLOCK", level = 57, },
	[386833]={ class = "WARLOCK", level = 57, },
	[387578]={ class = "WARLOCK", level = 57, },
	[387301]={ class = "WARLOCK", level = 57, },
	[266086]={ class = "WARLOCK", level = 57, },
	[390173]={ class = "WARLOCK", level = 57, },
--++ Warlock PvP Talents ++	
	[212459]={ class = "WARLOCK", level = 20, },
	[212619]={ class = "WARLOCK", level = 20, },
	[201996]={ class = "WARLOCK", level = 20, },
	[221711]={ class = "WARLOCK", level = 20, },
	[200586]={ class = "WARLOCK", level = 20, },
	[212295]={ class = "WARLOCK", level = 20, },
	[212618]={ class = "WARLOCK", level = 20, },
	[344566]={ class = "WARLOCK", level = 20, },
	[212371]={ class = "WARLOCK", level = 20, },
	[221703]={ class = "WARLOCK", level = 23, },
	[200546]={ class = "WARLOCK", level = 30, },
	[212282]={ class = "WARLOCK", level = 30, },
	[335052]={ class = "WARLOCK", level = 30, },
	[212628]={ class = "WARLOCK", level = 40, },
	[248855]={ class = "WARLOCK", level = 49, },
	[353753]={ class = "WARLOCK", level = 55, },
	[353601]={ class = "WARLOCK", level = 55, },
	[353294]={ class = "WARLOCK", level = 55, },
--++ Warrior Abilities ++	
	[137047]={ class = "WARRIOR", level = 1, },
	[296087]={ class = "WARRIOR", level = 1, },
	[294184]={ class = "WARRIOR", level = 1, },
	[294189]={ class = "WARRIOR", level = 1, },
	[88163]={ class = "WARRIOR", level = 1, },
	[123829]={ class = "WARRIOR", level = 1, },
	[3127]={ class = "WARRIOR", level = 1, },
	[1464]={ class = "WARRIOR", level = 1, },
	[100]={ class = "WARRIOR", level = 2, },
	[23922]={ class = "WARRIOR", level = 3, },
	[34428]={ class = "WARRIOR", level = 5, },
	[2565]={ class = "WARRIOR", level = 6, },
	[6552]={ class = "WARRIOR", level = 7, },
	[1680]={ class = "WARRIOR", level = 9, },
	[163201]={ class = "WARRIOR", level = 10, },
	[57755]={ class = "WARRIOR", level = 10, },
	[316523]={ class = "WARRIOR", level = 10, },
	[319158]={ class = "WARRIOR", level = 11, },
	[319157]={ class = "WARRIOR", level = 14, },
--++ Warrior Artifact Traits ++	
	[241264]={ class = "WARRIOR", level = 40, },
	[238077]={ class = "WARRIOR", level = 40, },
	[200857]={ class = "WARRIOR", level = 40, },
	[200859]={ class = "WARRIOR", level = 40, },
	[209566]={ class = "WARRIOR", level = 40, },
	[209472]={ class = "WARRIOR", level = 40, },
	[238148]={ class = "WARRIOR", level = 40, },
	[209481]={ class = "WARRIOR", level = 40, },
	[200846]={ class = "WARRIOR", level = 40, },
	[209559]={ class = "WARRIOR", level = 40, },
	[203576]={ class = "WARRIOR", level = 40, },
	[203225]={ class = "WARRIOR", level = 40, },
	[238147]={ class = "WARRIOR", level = 40, },
	[209494]={ class = "WARRIOR", level = 40, },
	[209554]={ class = "WARRIOR", level = 40, },
	[200871]={ class = "WARRIOR", level = 40, },
	[241269]={ class = "WARRIOR", level = 40, },
	[238113]={ class = "WARRIOR", level = 40, },
	[200870]={ class = "WARRIOR", level = 40, },
	[203227]={ class = "WARRIOR", level = 40, },
	[200875]={ class = "WARRIOR", level = 40, },
	[203230]={ class = "WARRIOR", level = 40, },
	[216274]={ class = "WARRIOR", level = 40, },
	[188778]={ class = "WARRIOR", level = 40, },
	[238149]={ class = "WARRIOR", level = 40, },
	[238112]={ class = "WARRIOR", level = 40, },
	[200872]={ class = "WARRIOR", level = 40, },
	[205545]={ class = "WARRIOR", level = 40, },
	[209462]={ class = "WARRIOR", level = 40, },
	[248579]={ class = "WARRIOR", level = 40, },
	[241270]={ class = "WARRIOR", level = 40, },
	[238076]={ class = "WARRIOR", level = 40, },
	[216272]={ class = "WARRIOR", level = 40, },
	[200845]={ class = "WARRIOR", level = 40, },
	[200861]={ class = "WARRIOR", level = 40, },
	[188672]={ class = "WARRIOR", level = 40, },
	[188651]={ class = "WARRIOR", level = 40, },
	[189059]={ class = "WARRIOR", level = 40, },
	[200863]={ class = "WARRIOR", level = 40, },
	[188639]={ class = "WARRIOR", level = 40, },
	[248580]={ class = "WARRIOR", level = 40, },
	[238111]={ class = "WARRIOR", level = 40, },
	[238075]={ class = "WARRIOR", level = 40, },
	[188647]={ class = "WARRIOR", level = 40, },
	[209483]={ class = "WARRIOR", level = 40, },
	[200847]={ class = "WARRIOR", level = 40, },
	[209480]={ class = "WARRIOR", level = 40, },
	[188644]={ class = "WARRIOR", level = 40, },
	[214938]={ class = "WARRIOR", level = 40, },
	[209541]={ class = "WARRIOR", level = 40, },
	[188632]={ class = "WARRIOR", level = 40, },
	[214939]={ class = "WARRIOR", level = 40, },
	[214937]={ class = "WARRIOR", level = 40, },
	[200856]={ class = "WARRIOR", level = 40, },
	[209459]={ class = "WARRIOR", level = 40, },
	[200860]={ class = "WARRIOR", level = 40, },
	[200853]={ class = "WARRIOR", level = 40, },
	[209573]={ class = "WARRIOR", level = 40, },
	[188635]={ class = "WARRIOR", level = 40, },
	[203261]={ class = "WARRIOR", level = 40, },
	[209577]={ class = "WARRIOR", level = 40, },
	[216273]={ class = "WARRIOR", level = 40, },
	[209548]={ class = "WARRIOR", level = 40, },
	[188683]={ class = "WARRIOR", level = 40, },
	[200849]={ class = "WARRIOR", level = 40, },
--++ Warrior Azerite Traits ++	
	[287377]={ class = "WARRIOR", level = 45, },
	[287378]={ class = "WARRIOR", level = 45, },
	[279172]={ class = "WARRIOR", level = 45, },
	[279193]={ class = "WARRIOR", level = 45, },
	[278122]={ class = "WARRIOR", level = 45, },
	[278124]={ class = "WARRIOR", level = 45, },
	[280211]={ class = "WARRIOR", level = 45, },
	[278760]={ class = "WARRIOR", level = 45, },
	[278991]={ class = "WARRIOR", level = 45, },
	[288080]={ class = "WARRIOR", level = 45, },
	[288084]={ class = "WARRIOR", level = 45, },
	[288085]={ class = "WARRIOR", level = 45, },
	[288087]={ class = "WARRIOR", level = 45, },
	[278824]={ class = "WARRIOR", level = 45, },
	[278826]={ class = "WARRIOR", level = 45, },
	[272824]={ class = "WARRIOR", level = 45, },
	[279006]={ class = "WARRIOR", level = 45, },
	[273409]={ class = "WARRIOR", level = 45, },
	[273412]={ class = "WARRIOR", level = 45, },
	[288091]={ class = "WARRIOR", level = 45, },
	[278130]={ class = "WARRIOR", level = 45, },
	[288642]={ class = "WARRIOR", level = 45, },
	[279141]={ class = "WARRIOR", level = 45, },
	[278752]={ class = "WARRIOR", level = 45, },
	[279202]={ class = "WARRIOR", level = 45, },
	[279203]={ class = "WARRIOR", level = 45, },
	[280209]={ class = "WARRIOR", level = 45, },
	[275632]={ class = "WARRIOR", level = 45, },
	[275670]={ class = "WARRIOR", level = 45, },
	[275672]={ class = "WARRIOR", level = 45, },
	[279632]={ class = "WARRIOR", level = 45, },
	[283810]={ class = "WARRIOR", level = 45, },
	[278495]={ class = "WARRIOR", level = 45, },
	[278757]={ class = "WARRIOR", level = 45, },
	[278840]={ class = "WARRIOR", level = 45, },
	[278841]={ class = "WARRIOR", level = 45, },
	[288452]={ class = "WARRIOR", level = 45, },
	[275529]={ class = "WARRIOR", level = 45, },
	[275531]={ class = "WARRIOR", level = 45, },
	[275532]={ class = "WARRIOR", level = 45, },
	[288056]={ class = "WARRIOR", level = 45, },
	[288060]={ class = "WARRIOR", level = 45, },
--++ Warrior Covenant Abilities ++	
	[307865]={ class = "WARRIOR", level = 48, },
	[317349]={ class = "WARRIOR", level = 48, },
--++ Warrior Conduit Abilities ++	
	[335232]={ class = "WARRIOR", level = 60, },
	[335234]={ class = "WARRIOR", level = 60, },
	[335010]={ class = "WARRIOR", level = 60, },
	[335250]={ class = "WARRIOR", level = 60, },
	[335242]={ class = "WARRIOR", level = 60, },
	[337162]={ class = "WARRIOR", level = 60, },
	[339939]={ class = "WARRIOR", level = 60, },
	[339948]={ class = "WARRIOR", level = 60, },
	[347213]={ class = "WARRIOR", level = 60, },
	[337214]={ class = "WARRIOR", level = 60, },
	[339370]={ class = "WARRIOR", level = 60, },
	[336191]={ class = "WARRIOR", level = 60, },
	[335034]={ class = "WARRIOR", level = 60, },
	[335260]={ class = "WARRIOR", level = 60, },
	[339386]={ class = "WARRIOR", level = 60, },
	[339259]={ class = "WARRIOR", level = 60, },
	[335196]={ class = "WARRIOR", level = 60, },
	[339818]={ class = "WARRIOR", level = 60, },
	[334993]={ class = "WARRIOR", level = 60, },
	[337154]={ class = "WARRIOR", level = 60, },
	[339265]={ class = "WARRIOR", level = 60, },
	[337302]={ class = "WARRIOR", level = 60, },
--++ Warrior Specializations ++	
	[137049]={ class = "WARRIOR", level = 1, },
	[137050]={ class = "WARRIOR", level = 1, },
	[137048]={ class = "WARRIOR", level = 1, },
	[325446]={ class = "WARRIOR", level = 1, },
	[386229]={ class = "WARRIOR", level = 1, },
	[20243]={ class = "WARRIOR", level = 10, },
	[231842]={ class = "WARRIOR", level = 10, },
	[184361]={ class = "WARRIOR", level = 10, },
	[5308]={ class = "WARRIOR", level = 10, },
	[397708]={ class = "WARRIOR", level = 10, },
	[76857]={ class = "WARRIOR", level = 10, },
	[262111]={ class = "WARRIOR", level = 10, },
	[76856]={ class = "WARRIOR", level = 10, },
	[161798]={ class = "WARRIOR", level = 10, },
	[231847]={ class = "WARRIOR", level = 10, },
	[71]={ class = "WARRIOR", level = 10, },
	[190411]={ class = "WARRIOR", level = 10, },
	[279423]={ class = "WARRIOR", level = 11, },
	[46917]={ class = "WARRIOR", level = 11, },
	[316403]={ class = "WARRIOR", level = 18, },
	[86101]={ class = "WARRIOR", level = 27, },
	[86110]={ class = "WARRIOR", level = 27, },
	[86535]={ class = "WARRIOR", level = 27, },
	[316428]={ class = "WARRIOR", level = 48, },
--++ Warrior Talents ++	
	[386164]={ class = "WARRIOR", level = 10, },
	[18499]={ class = "WARRIOR", level = 10, },
	[386196]={ class = "WARRIOR", level = 10, },
	[197690]={ class = "WARRIOR", level = 10, },
	[386208]={ class = "WARRIOR", level = 10, },
	[202168]={ class = "WARRIOR", level = 10, },
	[3411]={ class = "WARRIOR", level = 10, },
	[97462]={ class = "WARRIOR", level = 10, },
	[262231]={ class = "WARRIOR", level = 10, },
	[316733]={ class = "WARRIOR", level = 10, },
	[346002]={ class = "WARRIOR", level = 10, },
	[23881]={ class = "WARRIOR", level = 11, },
	[190456]={ class = "WARRIOR", level = 11, },
	[12294]={ class = "WARRIOR", level = 11, },
	[382260]={ class = "WARRIOR", level = 12, },
	[382310]={ class = "WARRIOR", level = 12, },
	[382258]={ class = "WARRIOR", level = 12, },
	[29838]={ class = "WARRIOR", level = 12, },
	[23920]={ class = "WARRIOR", level = 12, },
	[7384]={ class = "WARRIOR", level = 13, },
	[85288]={ class = "WARRIOR", level = 13, },
	[6572]={ class = "WARRIOR", level = 13, },
	[215571]={ class = "WARRIOR", level = 14, },
	[392790]={ class = "WARRIOR", level = 14, },
	[392792]={ class = "WARRIOR", level = 14, },
	[390354]={ class = "WARRIOR", level = 14, },
	[6544]={ class = "WARRIOR", level = 14, },
	[236279]={ class = "WARRIOR", level = 15, },
	[118038]={ class = "WARRIOR", level = 15, },
	[184364]={ class = "WARRIOR", level = 15, },
	[383848]={ class = "WARRIOR", level = 15, },
	[316402]={ class = "WARRIOR", level = 15, },
	[316405]={ class = "WARRIOR", level = 15, },
	[12975]={ class = "WARRIOR", level = 15, },
	[316440]={ class = "WARRIOR", level = 15, },
	[202560]={ class = "WARRIOR", level = 17, },
	[384361]={ class = "WARRIOR", level = 17, },
	[386030]={ class = "WARRIOR", level = 17, },
	[202316]={ class = "WARRIOR", level = 17, },
	[215568]={ class = "WARRIOR", level = 17, },
	[383103]={ class = "WARRIOR", level = 17, },
	[383852]={ class = "WARRIOR", level = 17, },
	[386034]={ class = "WARRIOR", level = 17, },
	[385571]={ class = "WARRIOR", level = 17, },
	[383854]={ class = "WARRIOR", level = 17, },
	[383468]={ class = "WARRIOR", level = 17, },
	[388807]={ class = "WARRIOR", level = 17, },
	[384041]={ class = "WARRIOR", level = 17, },
	[29725]={ class = "WARRIOR", level = 17, },
	[280721]={ class = "WARRIOR", level = 17, },
	[384042]={ class = "WARRIOR", level = 17, },
	[208154]={ class = "WARRIOR", level = 17, },
	[384277]={ class = "WARRIOR", level = 26, },
	[202163]={ class = "WARRIOR", level = 26, },
	[382954]={ class = "WARRIOR", level = 26, },
	[383115]={ class = "WARRIOR", level = 26, },
	[203201]={ class = "WARRIOR", level = 26, },
	[382764]={ class = "WARRIOR", level = 26, },
	[390642]={ class = "WARRIOR", level = 26, },
	[275338]={ class = "WARRIOR", level = 26, },
	[382767]={ class = "WARRIOR", level = 26, },
	[382549]={ class = "WARRIOR", level = 26, },
	[64382]={ class = "WARRIOR", level = 26, },
	[384404]={ class = "WARRIOR", level = 26, },
	[384110]={ class = "WARRIOR", level = 26, },
	[384036]={ class = "WARRIOR", level = 27, },
	[167105]={ class = "WARRIOR", level = 27, },
	[335070]={ class = "WARRIOR", level = 27, },
	[392931]={ class = "WARRIOR", level = 27, },
	[383486]={ class = "WARRIOR", level = 27, },
	[383430]={ class = "WARRIOR", level = 27, },
	[394311]={ class = "WARRIOR", level = 27, },
	[184367]={ class = "WARRIOR", level = 27, },
	[184783]={ class = "WARRIOR", level = 27, },
	[383082]={ class = "WARRIOR", level = 28, },
	[390674]={ class = "WARRIOR", level = 28, },
	[390675]={ class = "WARRIOR", level = 28, },
	[383762]={ class = "WARRIOR", level = 28, },
	[103827]={ class = "WARRIOR", level = 28, },
	[382461]={ class = "WARRIOR", level = 28, },
	[391270]={ class = "WARRIOR", level = 28, },
	[391271]={ class = "WARRIOR", level = 28, },
	[382939]={ class = "WARRIOR", level = 28, },
	[382956]={ class = "WARRIOR", level = 28, },
	[384090]={ class = "WARRIOR", level = 28, },
	[152278]={ class = "WARRIOR", level = 29, },
	[392536]={ class = "WARRIOR", level = 29, },
	[385704]={ class = "WARRIOR", level = 29, },
	[280001]={ class = "WARRIOR", level = 29, },
	[845]={ class = "WARRIOR", level = 29, },
	[383959]={ class = "WARRIOR", level = 29, },
	[383219]={ class = "WARRIOR", level = 29, },
	[335077]={ class = "WARRIOR", level = 29, },
	[383877]={ class = "WARRIOR", level = 29, },
	[12950]={ class = "WARRIOR", level = 29, },
	[281001]={ class = "WARRIOR", level = 29, },
	[871]={ class = "WARRIOR", level = 29, },
	[316834]={ class = "WARRIOR", level = 29, },
	[385843]={ class = "WARRIOR", level = 29, },
	[81099]={ class = "WARRIOR", level = 29, },
	[260643]={ class = "WARRIOR", level = 29, },
	[388004]={ class = "WARRIOR", level = 29, },
	[392966]={ class = "WARRIOR", level = 29, },
	[260708]={ class = "WARRIOR", level = 29, },
	[385840]={ class = "WARRIOR", level = 29, },
	[385888]={ class = "WARRIOR", level = 29, },
	[383885]={ class = "WARRIOR", level = 29, },
	[392936]={ class = "WARRIOR", level = 29, },
	[383287]={ class = "WARRIOR", level = 31, },
	[385703]={ class = "WARRIOR", level = 31, },
	[393950]={ class = "WARRIOR", level = 31, },
	[383442]={ class = "WARRIOR", level = 31, },
	[334779]={ class = "WARRIOR", level = 31, },
	[397103]={ class = "WARRIOR", level = 31, },
	[262150]={ class = "WARRIOR", level = 31, },
	[386027]={ class = "WARRIOR", level = 31, },
	[383605]={ class = "WARRIOR", level = 31, },
	[203177]={ class = "WARRIOR", level = 31, },
	[384072]={ class = "WARRIOR", level = 31, },
	[385573]={ class = "WARRIOR", level = 31, },
	[248621]={ class = "WARRIOR", level = 31, },
	[393967]={ class = "WARRIOR", level = 31, },
	[206315]={ class = "WARRIOR", level = 31, },
	[280392]={ class = "WARRIOR", level = 31, },
	[275334]={ class = "WARRIOR", level = 31, },
	[388049]={ class = "WARRIOR", level = 31, },
	[383293]={ class = "WARRIOR", level = 31, },
	[1719]={ class = "WARRIOR", level = 31, },
	[385512]={ class = "WARRIOR", level = 31, },
	[385008]={ class = "WARRIOR", level = 31, },
	[386357]={ class = "WARRIOR", level = 31, },
	[262161]={ class = "WARRIOR", level = 31, },
	[384124]={ class = "WARRIOR", level = 50, },
	[394855]={ class = "WARRIOR", level = 50, },
	[392777]={ class = "WARRIOR", level = 50, },
	[382900]={ class = "WARRIOR", level = 50, },
	[382940]={ class = "WARRIOR", level = 50, },
	[391997]={ class = "WARRIOR", level = 50, },
	[382896]={ class = "WARRIOR", level = 50, },
	[382946]={ class = "WARRIOR", level = 50, },
	[383297]={ class = "WARRIOR", level = 51, },
	[389306]={ class = "WARRIOR", level = 51, },
	[383295]={ class = "WARRIOR", level = 51, },
	[389308]={ class = "WARRIOR", level = 51, },
	[384063]={ class = "WARRIOR", level = 51, },
	[384067]={ class = "WARRIOR", level = 51, },
	[202603]={ class = "WARRIOR", level = 51, },
	[386011]={ class = "WARRIOR", level = 51, },
	[383459]={ class = "WARRIOR", level = 51, },
	[383338]={ class = "WARRIOR", level = 51, },
	[385952]={ class = "WARRIOR", level = 53, },
	[107574]={ class = "WARRIOR", level = 54, },
	[275339]={ class = "WARRIOR", level = 54, },
	[390725]={ class = "WARRIOR", level = 54, },
	[376079]={ class = "WARRIOR", level = 54, },
	[384318]={ class = "WARRIOR", level = 54, },
	[394312]={ class = "WARRIOR", level = 55, },
	[386630]={ class = "WARRIOR", level = 55, },
	[383154]={ class = "WARRIOR", level = 55, },
	[202743]={ class = "WARRIOR", level = 55, },
	[386328]={ class = "WARRIOR", level = 55, },
	[393965]={ class = "WARRIOR", level = 55, },
	[386634]={ class = "WARRIOR", level = 55, },
	[202095]={ class = "WARRIOR", level = 55, },
	[385059]={ class = "WARRIOR", level = 55, },
	[315720]={ class = "WARRIOR", level = 55, },
	[202751]={ class = "WARRIOR", level = 55, },
	[396749]={ class = "WARRIOR", level = 55, },
	[383341]={ class = "WARRIOR", level = 55, },
	[382953]={ class = "WARRIOR", level = 55, },
	[388903]={ class = "WARRIOR", level = 55, },
	[386477]={ class = "WARRIOR", level = 55, },
	[390123]={ class = "WARRIOR", level = 56, },
	[390138]={ class = "WARRIOR", level = 56, },
	[386285]={ class = "WARRIOR", level = 56, },
	[394307]={ class = "WARRIOR", level = 56, },
	[382948]={ class = "WARRIOR", level = 56, },
	[384969]={ class = "WARRIOR", level = 56, },
	[390135]={ class = "WARRIOR", level = 56, },
	[275336]={ class = "WARRIOR", level = 56, },
	[391572]={ class = "WARRIOR", level = 56, },
	[390140]={ class = "WARRIOR", level = 56, },
	[383916]={ class = "WARRIOR", level = 57, },
	[386394]={ class = "WARRIOR", level = 57, },
	[390713]={ class = "WARRIOR", level = 57, },
	[391683]={ class = "WARRIOR", level = 57, },
	[383922]={ class = "WARRIOR", level = 57, },
	[383703]={ class = "WARRIOR", level = 57, },
	[390563]={ class = "WARRIOR", level = 57, },
	[383292]={ class = "WARRIOR", level = 57, },
	[383317]={ class = "WARRIOR", level = 57, },
	[388933]={ class = "WARRIOR", level = 57, },
	[394329]={ class = "WARRIOR", level = 57, },
	[389603]={ class = "WARRIOR", level = 57, },
	[386628]={ class = "WARRIOR", level = 57, },
--++ Warrior PvP Talents ++	
	[213857]={ class = "WARRIOR", level = 20, },
	[329038]={ class = "WARRIOR", level = 20, },
	[198500]={ class = "WARRIOR", level = 20, },
	[199261]={ class = "WARRIOR", level = 20, },
	[206572]={ class = "WARRIOR", level = 20, },
	[198877]={ class = "WARRIOR", level = 20, },
	[205800]={ class = "WARRIOR", level = 20, },
	[198807]={ class = "WARRIOR", level = 20, },
	[199127]={ class = "WARRIOR", level = 20, },
	[199045]={ class = "WARRIOR", level = 20, },
	[236320]={ class = "WARRIOR", level = 20, },
	[199023]={ class = "WARRIOR", level = 27, },
	[280745]={ class = "WARRIOR", level = 33, },
	[199086]={ class = "WARRIOR", level = 33, },
	[352998]={ class = "WARRIOR", level = 36, },
	[236308]={ class = "WARRIOR", level = 38, },
	[329033]={ class = "WARRIOR", level = 41, },
	[356353]={ class = "WARRIOR", level = 45, },
	[235941]={ class = "WARRIOR", level = 46, },
	[213915]={ class = "WARRIOR", level = 47, },
--++ Shared Artifact Traits ++	
	[226829]={ level = 40, },
	[211309]={ level = 40, },
	[239042]={ level = 40, },
	[213428]={ level = 40, },
--++ Shared Azerite Traits ++	
	[279926]={ level = 45, },
	[264108]={ level = 45, },
	[267665]={ level = 45, },
	[267879]={ level = 45, },
	[279899]={ level = 45, },
	[279902]={ level = 45, },
	[263987]={ level = 45, },
	[271685]={ level = 45, },
	[271686]={ level = 45, },
	[271540]={ level = 45, },
	[271536]={ level = 45, },
	[267671]={ level = 45, },
	[269214]={ level = 45, },
	[267683]={ level = 45, },
	[271546]={ level = 45, },
	[271550]={ level = 45, },
	[271557]={ level = 45, },
	[271559]={ level = 45, },
	[267892]={ level = 45, },
	[267886]={ level = 45, },
	[272572]={ level = 45, },
	[267889]={ level = 45, },
	[267884]={ level = 45, },
	[267882]={ level = 45, },
	[267883]={ level = 45, },
	[267880]={ level = 45, },
	[279955]={ level = 45, },
	[279956]={ level = 45, },
	[279958]={ level = 45, },
	[266937]={ level = 45, },
	[269031]={ level = 45, },
	[263984]={ level = 45, },
	[268953]={ level = 45, },
	[268954]={ level = 45, },
	[268956]={ level = 45, },
	[268955]={ level = 45, },
	[266180]={ level = 45, },
	[271711]={ level = 45, },
	[268599]={ level = 45, },
	[269238]={ level = 45, },
	[269239]={ level = 45, },
	[268596]={ level = 45, },
	[270576]={ level = 45, },
	[268437]={ level = 45, },
	[270117]={ level = 45, },
	[268594]={ level = 45, },
	[263962]={ level = 45, },
	[270568]={ level = 45, },
	[269279]={ level = 45, },
	[268600]={ level = 45, },
	[270661]={ level = 45, },
	[268435]={ level = 45, },
	[268595]={ level = 45, },
	[270657]={ level = 45, },
	[280555]={ level = 50, },
	[280709]={ level = 50, },
	[280559]={ level = 50, },
	[280407]={ level = 45, },
	[280409]={ level = 45, },
	[273834]={ level = 45, },
	[280410]={ level = 45, },
	[280412]={ level = 45, },
	[273790]={ level = 45, },
	[273794]={ level = 45, },
	[273823]={ level = 45, },
	[273150]={ level = 45, },
	[280204]={ level = 45, },
	[280206]={ level = 45, },
	[273825]={ level = 45, },
	[280429]={ level = 45, },
	[280383]={ level = 45, },
	[280385]={ level = 45, },
	[280402]={ level = 45, },
	[280403]={ level = 45, },
	[280404]={ level = 45, },
	[273829]={ level = 45, },
	[273842]={ level = 45, },
	[273682]={ level = 45, },
	[280284]={ level = 45, },
	[280286]={ level = 45, },
	[281841]={ level = 45, },
	[281843]={ level = 45, },
	[281514]={ level = 50, },
	[281515]={ level = 50, },
	[280713]={ level = 45, },
	[287604]={ level = 50, },
	[287471]={ level = 50, },
	[287631]={ level = 50, },
	[287662]={ level = 50, },
	[288839]={ level = 50, },
	[288841]={ level = 50, },
	[288802]={ level = 50, },
	[288804]={ level = 50, },
	[289190]={ level = 50, },
	[288777]={ level = 50, },
	[288784]={ level = 50, },
	[288989]={ level = 50, },
	[288981]={ level = 50, },
	[303007]={ level = 50, },
	[303008]={ level = 50, },
	[303388]={ level = 50, },
	[303389]={ level = 50, },
	[303390]={ level = 50, },
	[303006]={ level = 50, },
	[303211]={ level = 50, },
	[300168]={ level = 50, },
	[300170]={ level = 50, },
	[287700]={ level = 45, },
	[287821]={ level = 45, },
	[287827]={ level = 45, },
	[287825]={ level = 45, },
	[280628]={ level = 45, },
	[280627]={ level = 45, },
	[280855]={ level = 45, },
	[282720]={ level = 45, },
	[280626]={ level = 50, },
	[280851]={ level = 45, },
	[280852]={ level = 45, },
	[280624]={ level = 45, },
	[280625]={ level = 45, },
	[280598]={ level = 45, },
	[280582]={ level = 45, },
	[280581]={ level = 50, },
	[280577]={ level = 45, },
	[280579]={ level = 45, },
	[280848]={ level = 45, },
	[298168]={ level = 50, },
	[299273]={ level = 50, },
	[299275]={ level = 50, },
	[298193]={ level = 50, },
	[299274]={ level = 50, },
	[299277]={ level = 50, },
	[294926]={ level = 50, },
	[300002]={ level = 50, },
	[300003]={ level = 50, },
	[294964]={ level = 50, },
	[294966]={ level = 50, },
	[300004]={ level = 50, },
	[300005]={ level = 50, },
	[302847]={ level = 50, },
	[296094]={ level = 50, },
	[299882]={ level = 50, },
	[299883]={ level = 50, },
	[296081]={ level = 50, },
	[296086]={ level = 50, },
	[299885]={ level = 50, },
	[299887]={ level = 50, },
	[293019]={ level = 50, },
	[298080]={ level = 50, },
	[298081]={ level = 50, },
	[294668]={ level = 50, },
	[298082]={ level = 50, },
	[298083]={ level = 50, },
	[297108]={ level = 50, },
	[298273]={ level = 50, },
	[298277]={ level = 50, },
	[297147]={ level = 50, },
	[297162]={ level = 50, },
	[298274]={ level = 50, },
	[298275]={ level = 50, },
	[295840]={ level = 50, },
	[299355]={ level = 50, },
	[299358]={ level = 50, },
	[295834]={ level = 50, },
	[299354]={ level = 50, },
	[299357]={ level = 50, },
	[295835]={ level = 50, },
	[303823]={ level = 50, },
	[304088]={ level = 50, },
	[304121]={ level = 50, },
	[304056]={ level = 50, },
	[304081]={ level = 50, },
	[304089]={ level = 50, },
	[304123]={ level = 50, },
	[295258]={ level = 50, },
	[299336]={ level = 50, },
	[299338]={ level = 50, },
	[295246]={ level = 50, },
	[295248]={ level = 50, },
	[299335]={ level = 50, },
	[299337]={ level = 50, },
	[293032]={ level = 50, },
	[299943]={ level = 50, },
	[299944]={ level = 50, },
	[296207]={ level = 50, },
	[299939]={ level = 50, },
	[299940]={ level = 50, },
	[298357]={ level = 50, },
	[299372]={ level = 50, },
	[299374]={ level = 50, },
	[298268]={ level = 50, },
	[298318]={ level = 50, },
	[298321]={ level = 50, },
	[298325]={ level = 50, },
	[298327]={ level = 50, },
	[298328]={ level = 50, },
	[298330]={ level = 50, },
	[298343]={ level = 50, },
	[299371]={ level = 50, },
	[299373]={ level = 50, },
	[304632]={ level = 50, },
	[295746]={ level = 50, },
	[300015]={ level = 50, },
	[300016]={ level = 50, },
	[295750]={ level = 50, },
	[300018]={ level = 50, },
	[300020]={ level = 50, },
	[295337]={ level = 50, },
	[299345]={ level = 50, },
	[299347]={ level = 50, },
	[295293]={ level = 50, },
	[299343]={ level = 50, },
	[299346]={ level = 50, },
	[302731]={ level = 50, },
	[302982]={ level = 50, },
	[302983]={ level = 50, },
	[302916]={ level = 50, },
	[302952]={ level = 50, },
	[302984]={ level = 50, },
	[302985]={ level = 50, },
	[293031]={ level = 50, },
	[300009]={ level = 50, },
	[300010]={ level = 50, },
	[294910]={ level = 50, },
	[300012]={ level = 50, },
	[300013]={ level = 50, },
	[295368]={ level = 50, },
	[295373]={ level = 50, },
	[295374]={ level = 50, },
	[295375]={ level = 50, },
	[295378]={ level = 50, },
	[299349]={ level = 50, },
	[299353]={ level = 50, },
	[295365]={ level = 50, },
	[299348]={ level = 50, },
	[299350]={ level = 50, },
	[295367]={ level = 50, },
	[303380]={ level = 50, },
	[296072]={ level = 50, },
	[299875]={ level = 50, },
	[299876]={ level = 50, },
	[296050]={ level = 50, },
	[296059]={ level = 50, },
	[299878]={ level = 50, },
	[299879]={ level = 50, },
	[298452]={ level = 50, },
	[299376]={ level = 50, },
	[299378]={ level = 50, },
	[298407]={ level = 50, },
	[299375]={ level = 50, },
	[299377]={ level = 50, },
	[302917]={ level = 50, },
	[296197]={ level = 50, },
	[299932]={ level = 50, },
	[299933]={ level = 50, },
	[296136]={ level = 50, },
	[299935]={ level = 50, },
	[299936]={ level = 50, },
	[296325]={ level = 50, },
	[299368]={ level = 50, },
	[299370]={ level = 50, },
	[296320]={ level = 50, },
	[296330]={ level = 50, },
	[299367]={ level = 50, },
	[299369]={ level = 50, },
	[296230]={ level = 50, },
	[299958]={ level = 50, },
	[299959]={ level = 50, },
	[303448]={ level = 50, },
	[303474]={ level = 50, },
	[303476]={ level = 50, },
	[295186]={ level = 50, },
	[298628]={ level = 50, },
	[299334]={ level = 50, },
	[295078]={ level = 50, },
	[298627]={ level = 50, },
	[299333]={ level = 50, },
	[312725]={ level = 50, },
	[313921]={ level = 50, },
	[313922]={ level = 50, },
	[312771]={ level = 50, },
	[313919]={ level = 50, },
	[313920]={ level = 50, },
	[310690]={ level = 50, },
	[311194]={ level = 50, },
	[311195]={ level = 50, },
	[311202]={ level = 50, },
	[310712]={ level = 50, },
	[311192]={ level = 50, },
	[311197]={ level = 50, },
	[311198]={ level = 50, },
	[311203]={ level = 50, },
	[311302]={ level = 50, },
	[311303]={ level = 50, },
	[311210]={ level = 50, },
	[311304]={ level = 50, },
	[311306]={ level = 50, },
	[313643]={ level = 50, },
	[295046]={ level = 50, },
	[299984]={ level = 50, },
	[299988]={ level = 50, },
	[295164]={ level = 50, },
	[299989]={ level = 50, },
	[299991]={ level = 50, },
	[310592]={ level = 50, },
	[310601]={ level = 50, },
	[310602]={ level = 50, },
	[310603]={ level = 50, },
	[310607]={ level = 50, },
	[310608]={ level = 50, },
	[312107]={ level = 50, },
	[297375]={ level = 50, },
	[298309]={ level = 50, },
	[298312]={ level = 50, },
	[297411]={ level = 50, },
	[298302]={ level = 50, },
	[298304]={ level = 50, },
	[319919]={ level = 50, },
	[296036]={ level = 50, },
	[310425]={ level = 50, },
	[310442]={ level = 50, },
	[293030]={ level = 50, },
	[310422]={ level = 50, },
	[310426]={ level = 50, },
--++ Shared Covenant Abilities ++	
 	[324739]={ level = 48, },
	[300728]={ level = 48, },
	[324631]={ level = 48, },
	[310143]={ level = 48, },
--++ Shared Covenant Soulbind Abilities ++	
	[331576]={ level = 60, },
	[329776]={ level = 60, },
	[352417]={ level = 60, },
	[329779]={ level = 60, },
	[351146]={ level = 60, },
	[328265]={ level = 60, },
	[352503]={ level = 60, },
	[326513]={ level = 60, },
	[333950]={ level = 60, },
	[332514]={ level = 60, },
	[319973]={ level = 60, },
	[352501]={ level = 60, },
	[324440]={ level = 60, },
	[350899]={ level = 60, },
	[331610]={ level = 60, },
	[328263]={ level = 60, },
	[329784]={ level = 60, },
	[328266]={ level = 60, },
	[328908]={ level = 60, },
	[352782]={ level = 60, },
	[331584]={ level = 60, },
	[352786]={ level = 60, },
	[352188]={ level = 60, },
	[341650]={ level = 60, },
	[323921]={ level = 60, },
	[319213]={ level = 60, },
	[319978]={ level = 60, },
	[328258]={ level = 60, },
	[331580]={ level = 60, },
	[332756]={ level = 60, },
	[336184]={ level = 60, },
	[325068]={ level = 60, },
	[325437]={ level = 60, },
	[319214]={ level = 60, },
	[331582]={ level = 60, },
	[331577]={ level = 60, },
	[331868]={ level = 60, },
	[352373]={ level = 60, },
	[319191]={ level = 60, },
	[325069]={ level = 60, },
	[325381]={ level = 60, },
	[328261]={ level = 60, },
	[326514]={ level = 60, },
	[331609]={ level = 60, },
	[331579]={ level = 60, },
	[325073]={ level = 60, },
	[323919]={ level = 60, },
	[323918]={ level = 60, },
	[322721]={ level = 60, },
	[333935]={ level = 60, },
	[324441]={ level = 60, },
	[326511]={ level = 60, },
	[326572]={ level = 60, },
	[326509]={ level = 60, },
	[325601]={ level = 60, },
	[332754]={ level = 60, },
	[333089]={ level = 60, },
	[351489]={ level = 60, },
	[325067]={ level = 60, },
	[352806]={ level = 60, },
	[352415]={ level = 60, },
	[351747]={ level = 60, },
	[323079]={ level = 60, },
	[352110]={ level = 60, },
	[342156]={ level = 60, },
	[336147]={ level = 60, },
	[328257]={ level = 60, },
	[328900]={ level = 60, },
	[351748]={ level = 60, },
	[336247]={ level = 60, },
	[351491]={ level = 60, },
	[334066]={ level = 60, },
	[350936]={ level = 60, },
	[319982]={ level = 60, },
	[320668]={ level = 60, },
	[351149]={ level = 60, },
	[352366]={ level = 60, },
	[320659]={ level = 60, },
	[320662]={ level = 60, },
	[320660]={ level = 60, },
	[323091]={ level = 60, },
	[351750]={ level = 60, },
	[351147]={ level = 60, },
	[329777]={ level = 60, },
	[323081]={ level = 60, },
	[323090]={ level = 60, },
	[319217]={ level = 60, },
	[329778]={ level = 60, },
	[351094]={ level = 60, },
	[352187]={ level = 60, },
	[336243]={ level = 60, },
	[331726]={ level = 60, },
	[352365]={ level = 60, },
	[331725]={ level = 60, },
	[351093]={ level = 60, },
	[329781]={ level = 60, },
	[326507]={ level = 60, },
	[329786]={ level = 60, },
	[342270]={ level = 60, },
	[342309]={ level = 60, },
	[326512]={ level = 60, },
	[326504]={ level = 60, },
	[340159]={ level = 60, },
	[352405]={ level = 60, },
	[319210]={ level = 60, },
	[351089]={ level = 60, },
	[319216]={ level = 60, },
	[336239]={ level = 60, },
	[319211]={ level = 60, },
	[352186]={ level = 60, },
	[331611]={ level = 60, },
	[331612]={ level = 60, },
	[351488]={ level = 60, },
	[320658]={ level = 60, },
	[323916]={ level = 60, },
	[332753]={ level = 60, },
	[352502]={ level = 60, },
	[320687]={ level = 60, },
	[321527]={ level = 60, },
	[331586]={ level = 60, },
	[331939]={ level = 60, },
	[336245]={ level = 60, },
	[323089]={ level = 60, },
	[323095]={ level = 60, },
	[332755]={ level = 60, },
	[352109]={ level = 60, },
	[329791]={ level = 60, },
	[352108]={ level = 60, },
	[323074]={ level = 60, },
	[352800]={ level = 60, },
	[325072]={ level = 60, },
	[350935]={ level = 60, },
	[352779]={ level = 60, },
	[319983]={ level = 60, },
	[336140]={ level = 60, },
	[352805]={ level = 60, },
	[325066]={ level = 60, },
	[343594]={ level = 60, },
	[325065]={ level = 60, },
--++ Shared PvP Talents ++	
	[377360]={ level = 20, },
--++ Shared Abilities ++	
	[2580]={ level = 1, },
	[8388]={ level = 1, },
	[43308]={ level = 1, },
	[2383]={ level = 1, },
	[131474]={ level = 1, },
	[131490]={ level = 1, },
	[167898]={ level = 1, },
	[195125]={ level = 1, },
	[265831]={ level = 1, },
	[309780]={ level = 1, },
	[225788]={ level = 1, },
	[328136]={ level = 1, },
	[335148]={ level = 1, },
	[335149]={ level = 1, },
	[335150]={ level = 1, },
	[335151]={ level = 1, },
	[335152]={ level = 1, },
	[186406]={ level = 1, },
	[186401]={ level = 1, },
	[359530]={ level = 1, },
	[296777]={ level = 1, },
	[143924]={ level = 1, },
	[115804]={ level = 1, },
	[321519]={ level = 1, },
	[287608]={ level = 1, },
	[216425]={ level = 1, },
	[190780]={ level = 1, },
	[55095]={ level = 1, },
	[56222]={ level = 1, },
	[55078]={ level = 1, },
	[3714]={ level = 1, },
	[311648]={ level = 1, },
	[315443]={ level = 1, },
	[312202]={ level = 1, },
	[383269]={ level = 1, },
	[108194]={ level = 1, },
	[221562]={ level = 1, },
	[207167]={ level = 1, },
	[194844]={ level = 1, },
	[45524]={ level = 1, },
	[206930]={ level = 1, },
	[206940]={ level = 1, },
	[196770]={ level = 1, },
	[211793]={ level = 1, },
	[343294]={ level = 1, },
	[203173]={ level = 1, },
	[47476]={ level = 1, },
	[199642]={ level = 1, },
	[199720]={ level = 1, },
	[324164]={ level = 1, },
	[337989]={ level = 1, },
	[194310]={ level = 1, },
	[51714]={ level = 1, },
	[115994]={ level = 1, },
	[191587]={ level = 1, },
	[185245]={ level = 1, },
	[258920]={ level = 1, },
	[273238]={ level = 1, },
	[329554]={ level = 1, },
	[317009]={ level = 1, },
	[179057]={ level = 1, },
	[258925]={ level = 1, },
	[211881]={ level = 1, },
	[217832]={ level = 1, },
	[205630]={ level = 1, },
	[209426]={ level = 1, },
	[207407]={ level = 1, },
	[106830]={ level = 1, },
	[8936]={ level = 1, },
	[339]={ level = 1, },
	[6795]={ level = 1, },
	[164815]={ level = 1, },
	[279793]={ level = 1, },
	[102351]={ level = 1, },
	[33786]={ level = 1, },
	[202770]={ level = 1, },
	[2637]={ level = 1, },
	[99]={ level = 1, },
	[29166]={ level = 1, },
	[102342]={ level = 1, },
	[33763]={ level = 1, },
	[22570]={ level = 1, },
	[102359]={ level = 1, },
	[5211]={ level = 1, },
	[124974]={ level = 1, },
	[80313]={ level = 1, },
	[200851]={ level = 1, },
	[774]={ level = 1, },
	[1079]={ level = 1, },
	[106898]={ level = 1, },
	[78675]={ level = 1, },
	[202347]={ level = 1, },
	[93402]={ level = 1, },
	[740]={ level = 1, },
	[102793]={ level = 1, },
	[48438]={ level = 1, },
	[201664]={ level = 1, },
	[236181]={ level = 1, },
	[329042]={ level = 1, },
	[200931]={ level = 1, },
	[202246]={ level = 1, },
	[305497]={ level = 1, },
	[326434]={ level = 1, },
	[1126]={ level = 1, },
	[164812]={ level = 1, },
	[145109]={ level = 1, },
	[145110]={ level = 1, },
	[368970]={ level = 1, },
	[357214]={ level = 1, },
	[357210]={ level = 1, },
	[356995]={ level = 1, },
	[357209]={ level = 1, },
	[369416]={ level = 1, },
	[361509]={ level = 1, },
	[361500]={ level = 1, },
	[370898]={ level = 1, },
	[381732]={ level = 1, },
	[381741]={ level = 1, },
	[381746]={ level = 1, },
	[381748]={ level = 1, },
	[381749]={ level = 1, },
	[381750]={ level = 1, },
	[381751]={ level = 1, },
	[381752]={ level = 1, },
	[381753]={ level = 1, },
	[381754]={ level = 1, },
	[381756]={ level = 1, },
	[381757]={ level = 1, },
	[381758]={ level = 1, },
	[390386]={ level = 1, },
	[375087]={ level = 1, },
	[359816]={ level = 1, },
	[364343]={ level = 1, },
	[370960]={ level = 1, },
	[370665]={ level = 1, },
	[366155]={ level = 1, },
	[363534]={ level = 1, },
	[370452]={ level = 1, },
	[369459]={ level = 1, },
	[357170]={ level = 1, },
	[374227]={ level = 1, },
	[372048]={ level = 1, },
	[360806]={ level = 1, },
	[383005]={ level = 1, },
	[370388]={ level = 1, },
	[378441]={ level = 1, },
	[195645]={ level = 1, },
	[257284]={ level = 1, },
	[325037]={ level = 1, },
	[324149]={ level = 1, },
	[354831]={ level = 1, },
	[355596]={ level = 1, },
	[212638]={ level = 1, },
	[53480]={ level = 1, },
	[131894]={ level = 1, },
	[217200]={ level = 1, },
	[186387]={ level = 1, },
	[5116]={ level = 1, },
	[190925]={ level = 1, },
	[19577]={ level = 1, },
	[34477]={ level = 1, },
	[378015]={ level = 1, },
	[257044]={ level = 1, },
	[1513]={ level = 1, },
	[213691]={ level = 1, },
	[271788]={ level = 1, },
	[162487]={ level = 1, },
	[260243]={ level = 1, },
	[61780]={ level = 1, },
	[126819]={ level = 1, },
	[161353]={ level = 1, },
	[161354]={ level = 1, },
	[161355]={ level = 1, },
	[122]={ level = 1, },
	[118]={ level = 1, },
	[120]={ level = 1, },
	[28271]={ level = 1, },
	[28272]={ level = 1, },
	[61305]={ level = 1, },
	[61721]={ level = 1, },
	[161372]={ level = 1, },
	[277787]={ level = 1, },
	[277792]={ level = 1, },
	[321395]={ level = 1, },
	[391622]={ level = 1, },
	[80353]={ level = 1, },
	[224968]={ level = 1, },
	[272970]={ level = 1, },
	[288800]={ level = 1, },
	[288803]={ level = 1, },
	[307443]={ level = 1, },
	[314793]={ level = 1, },
	[314791]={ level = 1, },
	[235313]={ level = 1, },
	[11426]={ level = 1, },
	[2120]={ level = 1, },
	[383121]={ level = 1, },
	[31589]={ level = 1, },
	[157981]={ level = 1, },
	[157997]={ level = 1, },
	[44457]={ level = 1, },
	[114923]={ level = 1, },
	[205021]={ level = 1, },
	[376103]={ level = 1, },
	[31661]={ level = 1, },
	[382440]={ level = 1, },
	[199786]={ level = 1, },
	[390612]={ level = 1, },
	[198158]={ level = 1, },
	[389794]={ level = 1, },
	[23028]={ level = 1, },
	[27127]={ level = 1, },
	[43002]={ level = 1, },
	[321358]={ level = 1, },
	[130]={ level = 1, },
	[117952]={ level = 1, },
	[119381]={ level = 1, },
	[101546]={ level = 1, },
	[209525]={ level = 1, },
	[214326]={ level = 1, },
	[205320]={ level = 1, },
	[273298]={ level = 1, },
	[275673]={ level = 1, },
	[280184]={ level = 1, },
	[325216]={ level = 1, },
	[322729]={ level = 1, },
	[386276]={ level = 1, },
	[116095]={ level = 1, },
	[124682]={ level = 1, },
	[325153]={ level = 1, },
	[394923]={ level = 1, },
	[113656]={ level = 1, },
	[121253]={ level = 1, },
	[116849]={ level = 1, },
	[115078]={ level = 1, },
	[196725]={ level = 1, },
	[116844]={ level = 1, },
	[116847]={ level = 1, },
	[115175]={ level = 1, },
	[392983]={ level = 1, },
	[116841]={ level = 1, },
	[202162]={ level = 1, },
	[233759]={ level = 1, },
	[202335]={ level = 1, },
	[123725]={ level = 1, },
	[196608]={ level = 1, },
	[354540]={ level = 1, },
	[101546]={ level = 1, },
	[107270]={ level = 1, },
	[322729]={ level = 1, },
	[31884]={ level = 1, },
	[200654]={ level = 1, },
	[853]={ level = 1, },
	[26573]={ level = 1, },
	[209202]={ level = 1, },
	[205273]={ level = 1, },
	[273481]={ level = 1, },
	[287280]={ level = 1, },
	[278785]={ level = 1, },
	[278145]={ level = 1, },
	[278147]={ level = 1, },
	[328204]={ level = 1, },
	[31935]={ level = 1, },
	[148039]={ level = 1, },
	[156910]={ level = 1, },
	[200025]={ level = 1, },
	[223306]={ level = 1, },
	[1044]={ level = 1, },
	[1022]={ level = 1, },
	[6940]={ level = 1, },
	[204018]={ level = 1, },
	[388007]={ level = 1, },
	[343527]={ level = 1, },
	[205191]={ level = 1, },
	[387174]={ level = 1, },
	[343721]={ level = 1, },
	[183218]={ level = 1, },
	[20066]={ level = 1, },
	[385728]={ level = 1, },
	[184662]={ level = 1, },
	[10326]={ level = 1, },
	[200652]={ level = 1, },
	[255937]={ level = 1, },
	[210256]={ level = 1, },
	[215652]={ level = 1, },
	[189928]={ level = 1, },
	[211283]={ level = 1, },
	[351292]={ level = 1, },
	[32223]={ level = 1, },
	[465]={ level = 1, },
	[62124]={ level = 1, },
	[197277]={ level = 1, },
	[183435]={ level = 1, },
	[339376]={ level = 1, },
	[383351]={ level = 1, },
	[340007]={ level = 1, },
	[589]={ level = 1, },
	[8122]={ level = 1, },
	[453]={ level = 1, },
	[205065]={ level = 1, },
	[287722]={ level = 1, },
	[325013]={ level = 1, },
	[323673]={ level = 1, },
	[324724]={ level = 1, },
	[15407]={ level = 1, },
	[34914]={ level = 1, },
	[14914]={ level = 1, },
	[335467]={ level = 1, },
	[64843]={ level = 1, },
	[205364]={ level = 1, },
	[47788]={ level = 1, },
	[73325]={ level = 1, },
	[605]={ level = 1, },
	[48045]={ level = 1, },
	[375901]={ level = 1, },
	[33206]={ level = 1, },
	[10060]={ level = 1, },
	[64044]={ level = 1, },
	[47536]={ level = 1, },
	[139]={ level = 1, },
	[214621]={ level = 1, },
	[9484]={ level = 1, },
	[15487]={ level = 1, },
	[64901]={ level = 1, },
	[15286]={ level = 1, },
	[108920]={ level = 1, },
	[263165]={ level = 1, },
	[197268]={ level = 1, },
	[81751]={ level = 1, },
	[346703]={ level = 1, },
	[194384]={ level = 1, },
	[1706]={ level = 1, },
	[21562]={ level = 1, },
	[17]={ level = 1, },
	[204213]={ level = 1, },
	[1833]={ level = 1, },
	[3408]={ level = 1, },
	[315584]={ level = 1, },
	[408]={ level = 1, },
	[8679]={ level = 1, },
	[114018]={ level = 1, },
	[192759]={ level = 1, },
	[286581]={ level = 1, },
	[289467]={ level = 1, },
	[323654]={ level = 1, },
	[328305]={ level = 1, },
	[185763]={ level = 1, },
	[703]={ level = 1, },
	[1943]={ level = 1, },
	[381664]={ level = 1, },
	[381637]={ level = 1, },
	[13877]={ level = 1, },
	[2094]={ level = 1, },
	[121411]={ level = 1, },
	[2818]={ level = 1, },
	[2823]={ level = 1, },
	[360194]={ level = 1, },
	[384631]={ level = 1, },
	[196937]={ level = 1, },
	[1776]={ level = 1, },
	[51690]={ level = 1, },
	[385627]={ level = 1, },
	[137619]={ level = 1, },
	[5761]={ level = 1, },
	[6770]={ level = 1, },
	[385408]={ level = 1, },
	[57934]={ level = 1, },
	[207777]={ level = 1, },
	[212182]={ level = 1, },
	[359053]={ level = 1, },
	[207736]={ level = 1, },
	[2825]={ level = 1, },
	[188389]={ level = 1, },
	[32182]={ level = 1, },
	[210873]={ level = 1, },
	[211004]={ level = 1, },
	[211010]={ level = 1, },
	[211015]={ level = 1, },
	[269352]={ level = 1, },
	[277778]={ level = 1, },
	[277784]={ level = 1, },
	[309328]={ level = 1, },
	[546]={ level = 1, },
	[278082]={ level = 1, },
	[275391]={ level = 1, },
	[108281]={ level = 1, },
	[384352]={ level = 1, },
	[974]={ level = 1, },
	[196840]={ level = 1, },
	[73920]={ level = 1, },
	[51514]={ level = 1, },
	[342240]={ level = 1, },
	[210714]={ level = 1, },
	[61295]={ level = 1, },
	[342243]={ level = 1, },
	[197214]={ level = 1, },
	[51490]={ level = 1, },
	[5782]={ level = 1, },
	[702]={ level = 1, },
	[234153]={ level = 1, },
	[20707]={ level = 1, },
	[5697]={ level = 1, },
	[312321]={ level = 1, },
	[325640]={ level = 1, },
	[980]={ level = 1, },
	[603]={ level = 1, },
	[198590]={ level = 1, },
	[48181]={ level = 1, },
	[80240]={ level = 1, },
	[5484]={ level = 1, },
	[6789]={ level = 1, },
	[205179]={ level = 1, },
	[5740]={ level = 1, },
	[27243]={ level = 1, },
	[17877]={ level = 1, },
	[30283]={ level = 1, },
	[63106]={ level = 1, },
	[386997]={ level = 1, },
	[316099]={ level = 1, },
	[234877]={ level = 1, },
	[199954]={ level = 1, },
	[264106]={ level = 1, },
	[157736]={ level = 1, },
	[115767]={ level = 1, },
	[1715]={ level = 1, },
	[355]={ level = 1, },
	[6673]={ level = 1, },
	[203524]={ level = 1, },
	[278999]={ level = 1, },
	[324143]={ level = 1, },
	[325886]={ level = 1, },
	[384100]={ level = 1, },
	[46924]={ level = 1, },
	[227847]={ level = 1, },
	[1161]={ level = 1, },
	[1160]={ level = 1, },
	[386071]={ level = 1, },
	[5246]={ level = 1, },
	[12323]={ level = 1, },
	[152277]={ level = 1, },
	[228920]={ level = 1, },
	[772]={ level = 1, },
	[394062]={ level = 1, },
	[46968]={ level = 1, },
	[107570]={ level = 1, },
	[6343]={ level = 1, },
	[396719]={ level = 1, },
	[213871]={ level = 1, },
	[236077]={ level = 1, },
	[198817]={ level = 1, },
	[198912]={ level = 1, },
	[236273]={ level = 1, },
	[8690]={ level = 1, },
	[308189]={ level = 10, },
	[72968]={ level = 30, },
	[127230]={ level = 32, },
	[176151]={ level = 35, },
	[242551]={ level = 40, },
	[251839]={ level = 40, },
	[227723]={ level = 45, },
	[264878]={ level = 45, },
	[264877]={ level = 45, },
	[270058]={ level = 50, },
	[317065]={ level = 50, },
	[304606]={ level = 50, },
	[304611]={ level = 50, },
	[268194]={ level = 50, },
	[285496]={ level = 50, },
	[293142]={ level = 50, },
	[298700]={ level = 50, },
	[298703]={ level = 50, },
	[298823]={ level = 50, },
	[285500]={ level = 50, },
	[273992]={ level = 50, },
	[313571]={ level = 50, },
	[284275]={ level = 50, },
	[284277]={ level = 50, },
	[256434]={ level = 50, },
	[256451]={ level = 50, },
	[256452]={ level = 50, },
	[256453]={ level = 50, },
	[256455]={ level = 50, },
	[256456]={ level = 50, },
	[256459]={ level = 50, },
	[256460]={ level = 50, },
	[299661]={ level = 50, },
	[299662]={ level = 50, },
	[299664]={ level = 50, },
};